@@ -88,7 +88,6 @@ int EdStream::close()
         if (m_pMplex)
             m_pMplex->remove(this);
         //::shutdown( getfd(), SHUT_RDWR );
-        clearRevent();
         ::close(getfd());
         setfd(-1);
     }
@@ -119,7 +118,7 @@ int EdStream::handleEvents(short event)
     {
         ret = onRead();
         if (!getAssignedRevent())
-            return 0;
+            goto EVENT_DONE;
     }
     if (event & POLLHUP)
     {
@@ -128,14 +127,19 @@ int EdStream::handleEvents(short event)
         else if (getHupCounter() > 100)
             abort();
         if (!getAssignedRevent())
-            return 0;
-
+            goto EVENT_DONE;
+    }
+    if ((ret != -1) && (event & POLLHUP))
+    {
+        ret = onHangup();
+        if (!getAssignedRevent())
+            return LS_OK;
     }
     if ((ret != -1) && (event & POLLOUT))
     {
         ret = onWrite();
         if (!getAssignedRevent())
-            return 0;
+            goto EVENT_DONE;
     }
     if ((ret != -1) && (event & POLLERR))
     {
@@ -143,8 +147,9 @@ int EdStream::handleEvents(short event)
         if (!getAssignedRevent())
             return LS_OK;
     }
+EVENT_DONE:
     if (ret != -1)
-        onEventDone();
+        onEventDone(event);
     return LS_OK;
 }
 
