@@ -98,6 +98,8 @@ public:
             }
             if (ret < len)
                 resetRevent(POLLOUT);
+            else
+                setRevent(POLLOUT);
             return ret;
         }
     }
@@ -118,6 +120,8 @@ public:
                     ret = 0;
                 }
             }
+            else
+                setRevent(POLLOUT);
             return ret;
         }
     }
@@ -132,12 +136,12 @@ public:
 
     int write(LoopBuf *pBuf);
 
-    Multiplexer *getCurMplex() const
+    Multiplexer *getMultiplexer() const
     {   return m_pMplex;  }
 
     virtual int onHangup();
     virtual int onError() = 0;
-    virtual int onEventDone() = 0;
+    virtual int onEventDone(short event) = 0;
 //    virtual bool wantRead() = 0;
 //    virtual bool wantWrite() = 0;
 //    void updateEvents();
