@@ -50,6 +50,7 @@ CgidWorker::CgidWorker(const char *pName)
     : ExtWorker(HandlerType::HT_CGI)
     , m_pid(-1)
     , m_fdCgid(-1)
+    , m_lve(1)
 {
     setConfigPointer(new CgidConfig(pName));
 }
@@ -152,10 +153,7 @@ int CgidWorker::spawnCgid(int fd, char *pData, const char *secret)
     //in child
     if (pid == 0)
     {
-        char lve_env[16];
         CloseUnusedFd(fd);
-        snprintf(lve_env, sizeof(lve_env) -1, "LVE_ENABLE=%d", getLVE());
-        putenv(lve_env);
         int ret = lscgid_main(fd, argv0, secret, pData);
         exit(ret);
     }
@@ -243,7 +241,7 @@ int CgidWorker::config(const XmlNode *pNode1)
 
     if (!pValue)
     {
-        snprintf(achSocket, 128, "uds:/%s%scgid/cgid.sock",
+        snprintf(achSocket, 128, "uds:/%s%sadmin/cgid/cgid.sock",
                  (iChrootlen) ? psChroot : "",
                  MainServerConfig::getInstance().getServerRoot());
     }
@@ -284,13 +282,14 @@ int CgidWorker::config(const XmlNode *pNode1)
 
     char achMIME[] = "application/x-httpd-cgi";
     HttpMime::getMime()->addMimeHandler("", achMIME,
-                                        HandlerFactory::getInstance(HandlerType::HT_CGI, NULL), NULL,
-                                        TmpLogId::getLogId());
+                    HandlerFactory::getInstance(HandlerType::HT_CGI, NULL),
+                    NULL, TmpLogId::getLogId());
 
 
-//    char achMIME_SSI[] = "application/x-httpd-shtml";
-//    HttpMime::getMime()->addMimeHandler( "", achMIME_SSI,
-//                                            HandlerFactory::getInstance( HandlerType::HT_SSI, NULL ), NULL,  LogIdTracker::getLogId() );
+   char achMIME_SSI[] = "application/x-httpd-shtml";
+   HttpMime::getMime()->addMimeHandler("", achMIME_SSI,
+                    HandlerFactory::getInstance(HandlerType::HT_SSI, NULL),
+                    NULL, TmpLogId::getLogId());
 
     CgidWorker::setCgidWorkerPid(
         start(MainServerConfig::getInstance().getServerRoot(), psChroot,
@@ -299,10 +298,6 @@ int CgidWorker::config(const XmlNode *pNode1)
     return CgidWorker::getCgidWorkerPid();
 }
 
-int  CgidWorker::getLVE() const
-{
-    return HttpServerConfig::getInstance().getEnableLve();
-}
 
 void CgidWorker::closeFdCgid()
 {
