@@ -16,7 +16,6 @@
 *    along with this program. If not, see http://www.gnu.org/licenses/.      *
 *****************************************************************************/
 #include <signal.h>
-#include <config.h>
 
 #ifndef _XPG4_2
 # define _XPG4_2
@@ -51,22 +50,13 @@
 #define uint32_t unsigned long
 
 static uid_t        s_uid;
-#define HAS_CLOUD_LINUX
 #ifdef HAS_CLOUD_LINUX
 #if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
-
+#include <lve/lve-ctl.h>
 static int s_enable_lve = 0;
 static struct liblve *s_lve = NULL;
 
 static void *s_liblve;
-typedef int (*lve_is_available)(void);
-typedef int (*lve_instance_init)(struct liblve *);
-typedef int (*lve_destroy)(struct liblve *);
-typedef int (*lve_enter)(struct liblve *, uint32_t, int32_t, int32_t,
-                           uint32_t *);
-typedef int (*lve_leave)(struct liblve *, uint32_t *);
-typedef int (*lve_jail)(struct passwd *, char *);
-
 static int (*fp_lve_is_available)(void) = NULL;
 static int (*fp_lve_instance_init)(struct liblve *) = NULL;
 static int (*fp_lve_destroy)(struct liblve *) = NULL;
@@ -79,7 +69,7 @@ static int load_lve_lib()
     s_liblve = dlopen("liblve.so.0", RTLD_LAZY);
     if (s_liblve)
     {
-        fp_lve_is_available = (lve_is_available)dlsym(s_liblve, "lve_is_available");
+        fp_lve_is_available = dlsym(s_liblve, "lve_is_available");
         if (dlerror() == NULL)
         {
             if (!(*fp_lve_is_available)())
@@ -106,17 +96,17 @@ static int init_lve()
     int rc;
     if (!s_liblve)
         return LS_FAIL;
-    fp_lve_instance_init = (lve_instance_init)dlsym(s_liblve, "lve_instance_init");
-    fp_lve_destroy = (lve_destroy)dlsym(s_liblve, "lve_destroy");
-    fp_lve_enter = (lve_enter)dlsym(s_liblve, "lve_enter");
-    fp_lve_leave = (lve_leave)dlsym(s_liblve, "lve_leave");
+    fp_lve_instance_init = dlsym(s_liblve, "lve_instance_init");
+    fp_lve_destroy = dlsym(s_liblve, "lve_destroy");
+    fp_lve_enter = dlsym(s_liblve, "lve_enter");
+    fp_lve_leave = dlsym(s_liblve, "lve_leave");
     if (s_enable_lve >= 2)
-        fp_lve_jail = (lve_jail)dlsym(s_liblve, "jail");
+        fp_lve_jail = dlsym(s_liblve, "jail");
 
     if (s_lve == NULL)
     {
         rc = (*fp_lve_instance_init)(NULL);
-        s_lve = (struct liblve *)malloc(rc);
+        s_lve = malloc(rc);
     }
     rc = (*fp_lve_instance_init)(s_lve);
     if (rc != 0)
@@ -336,7 +326,7 @@ static int execute_cgi(lscgid_t *pCGI)
     {
         uint32_t cookie;
         int ret = -1;
-        //int count;
+        int count;
         //for( count = 0; count < 10; ++count )
         {
             ret = (*fp_lve_enter)(s_lve, pCGI->m_data.m_uid, -1, -1, &cookie);
@@ -384,10 +374,7 @@ static int execute_cgi(lscgid_t *pCGI)
     }
     ch = *(pCGI->m_argv[0]);
     * pCGI->m_argv[0] = 0;
-    const char *dir = pCGI->m_cwdPath;
-    if (!dir)
-        dir = pCGI->m_pCGIDir;
-    if (chdir(dir) == -1)
+    if (chdir(pCGI->m_pCGIDir) == -1)
     {
         int error = errno;
         log_cgi_error("lscgid: chdir()", pCGI->m_pCGIDir, NULL);
@@ -492,15 +479,6 @@ static int process_req_data(lscgid_t *cgi_req)
         p += sizeof(short);
 #endif
         cgi_req->m_env[i] = p;
-        if (*p == 'L')
-        {
-            if (strncasecmp(p, "LS_CWD=", 7) == 0)
-            {
-                --i;
-                --cgi_req->m_data.m_nenv;
-                cgi_req->m_cwdPath = p + 7;
-            }
-        }
         p += len;
         if (p > pEnd)
             return 500;
@@ -634,7 +612,6 @@ static int processreq(int fd)
     lscgid_t cgi_req;
     int ret;
 
-    memset(&cgi_req, 0, sizeof(cgi_req));
     ret = recv_req(fd, &cgi_req, 10);
     if (ret)
         cgiError(fd, ret);
@@ -662,7 +639,7 @@ static void child_main(int fd)
         dup2(fd, STDOUT_FILENO);
     else
         closeit = 0;
-    if (closeit && fd != STDOUT_FILENO)
+    if (closeit)
         close(fd);
     processreq(STDOUT_FILENO);
     exit(0);
@@ -683,6 +660,11 @@ static int new_conn(int fd)
     return pid;
 }
 
+static int s_got_sigchild = 0;
+
+
+static void processSigchild();
+
 
 static int run(int fdServerSock)
 {
@@ -706,6 +688,8 @@ static int run(int fdServerSock)
             if (getppid() != s_parent)
                 return 1;
         }
+        if (s_got_sigchild)
+            processSigchild();
     }
     return 0;
 }
@@ -727,6 +711,13 @@ static void sigusr1(int sig)
 
 static void sigchild(int sig)
 {
+    s_got_sigchild = 1;
+}
+
+
+static void processSigchild()
+{
+    s_got_sigchild = 0;
     int status[2];
     while (1)
     {
@@ -831,12 +822,7 @@ int lscgid_main(int fd, char *argv0, const char *secret, char *pSock)
     //setproctitle( "%s", "httpd" );
 #else
     memset(argv0, 0, strlen(argv0));
-    
-#ifdef IS_LSCPD    
-    strcpy(argv0, "lscpd (lscgid)");
-#else
     strcpy(argv0, "openlitespeed (lscgid)");
-#endif    
 #endif
 
     ret = run(fd);
