@@ -137,6 +137,8 @@ int SUExec::spawnChild(const char *pAppCmd, int fdIn, int fdOut,
         dup2(fdOut, STDOUT_FILENO);
         close(fdOut);
     }
+    else
+        close(STDOUT_FILENO);
 
     if (pLimits)
     {
@@ -217,9 +219,9 @@ int SUExec::checkLScgid(const char *path)
     return 0;
 }
 
-#define _HAS_LVE_
+
 static char sDefaultPath[] = "PATH=/bin:/usr/bin:/usr/local/bin";
-static char sLVE[] = "LVE_ENABLE=1";
+//static char sLVE[] = "LVE_ENABLE=1";
 
 
 int SUExec::suEXEC(const char *pServerRoot, int *pfd, int listenFd,
