@@ -31,7 +31,7 @@
 
 ExtConn::ExtConn()
     : m_iState(0)
-    , m_iToClose(0)
+    , m_iToStop(0)
     , m_iInProcess(0)
     , m_iCPState(0)
     , m_tmLastAccess(0)
@@ -94,13 +94,15 @@ int ExtConn::assignReq(ExtRequest *pReq)
     if (getState() == PROCESSING)
     {
         ret = doWrite();
-        onEventDone();
+        onEventDone(-1);
         //pConn->continueWrite();
     }
     else if (getState() != CONNECTING)
         ret = reconnect();
     if (ret == -1)
         return connError(errno);
+    if (ret < -1)
+        return -ret;
     return 0;
 
 }
@@ -108,10 +110,13 @@ int ExtConn::assignReq(ExtRequest *pReq)
 
 int ExtConn::close()
 {
-    LS_DBG_L(this, "[ExtConn] close()");
-    EdStream::close();
-    m_iState = DISCONNECTED;
-    m_iInProcess = 0;
+    if (m_iState != DISCONNECTED)
+    {
+        LS_DBG_L(this, "[ExtConn] close()");
+        EdStream::close();
+        m_iState = DISCONNECTED;
+        m_iInProcess = 0;
+    }
     return 0;
 }
 
@@ -143,7 +148,7 @@ int ExtConn::connectEx(Multiplexer *pMplx)
                               &fd, 1);
     m_iReqProcessed = 0;
     m_iCPState = 0;
-    m_iToClose = 0;
+    m_iToStop = 0;
     if ((fd == -1) && (errno == ECONNREFUSED))
         ret = CoreSocket::connect(m_pWorker->getServerAddr(), pMplx->getFLTag(),
                                   &fd, 1);
@@ -181,7 +186,7 @@ int ExtConn::onInitConnected()
     {
         char        achSockAddr[128];
         char        achAddr[128]    = "";
-        unsigned    port            = 0;
+        int         port            = 0;
         socklen_t   len             = 128;
 
         if (getsockname(getfd(), (struct sockaddr *)achSockAddr, &len) == 0)
@@ -190,7 +195,7 @@ int ExtConn::onInitConnected()
             port = GSockAddr::getPort((struct sockaddr *)achSockAddr);
         }
 
-        LS_DBG_L(this, "Connected to [%s] on local address [%s:%u]!",
+        LS_DBG_L(this, "Connected to [%s] on local address [%s:%d]!",
                  m_pWorker->getURL(), achAddr, port);
     }
     return 0;
@@ -224,6 +229,16 @@ int ExtConn::onRead()
 }
 
 
+int ExtConn::onHangup()
+{
+    //When connection is used, but there are pending data to read,
+    //POLLIN is off, then POLLHUP will be returned in tight loop.
+    LS_DBG_L(this, "ExtConn::onHangup(), state: %d, treat as onRead()",
+             (int)m_iState);
+    return onRead();
+}
+
+
 int ExtConn::onWrite()
 {
     LS_DBG_L(this, "ExtConn::onWrite()");
@@ -273,27 +288,6 @@ int ExtConn::onError()
 }
 
 
-int ExtConn::markToClose()
-{
-    if (getReq())
-    {
-        if (!isToClose())
-        {
-            setToClose(1);
-            m_pWorker->incLingerConn();
-            return 0;
-        }
-    }
-    else
-    {
-        close();
-        m_pWorker->removeConn(this);
-        return 1;
-    }
-    return 0;
-}
-
-
 void ExtConn::onSecTimer()
 {
     int secs = DateTime::s_curTime - m_tmLastAccess;
@@ -330,6 +324,7 @@ void ExtConn::onSecTimer()
     {
         LS_DBG_L(this, "Idle connection timed out, close!");
         close();
+        m_pWorker->getConnPool().removeConn(this);
     }
 
 }
@@ -368,8 +363,11 @@ int ExtConn::connError(int errCode)
 }
 
 
-int ExtConn::onEventDone()
+int ExtConn::onEventDone(short event)
 {
+    LS_DBG_L(this,
+             "ExtConn::onEventDone(), fd: %d, state: %d, event: %hd, revents: %hd.",
+             getfd(), (int)m_iState, event, getRevents());
     switch (m_iState)
     {
     case ABORT:
