@@ -32,13 +32,13 @@
 #include <http/clientinfo.h>
 
 #include <http/requestvars.h>
+#include <lsiapi/lsiapi_const.h>
 #include <log4cxx/logger.h>
 #include <lsr/ls_hash.h>
 #include <lsr/ls_str.h>
 #include <lsr/ls_strtool.h>
 #include <sslpp/hiocrypto.h>
-#include <sslpp/sslcert.h>
-#include <sslpp/sslutil.h>
+// #include <sslpp/sslcert.h>
 #include <util/autostr.h>
 #include <util/datetime.h>
 #include <util/ienv.h>
@@ -63,11 +63,54 @@ int HttpCgiTool::processContentType(HttpSession *pSession,
     const AutoStr2 *pCharset = NULL;
     if (pReq->getStatusCode() == SC_304)
         return 0;
+    const MimeSetting *pMIME = NULL;
+    p = (char *)memchr(pValue, ';', valLen);
+    int gzipAccept = pReq->gzipAcceptable();
+    HttpContext *pContext = &(pReq->getVHost()->getRootContext());
+    //const ExpiresCtrl *pExpireDefault = pReq->shouldAddExpires();
+    int enbale = pContext->getExpires().isEnabled();
+    
+    if (gzipAccept || enbale)
+    {
+        char *pEnd;
+        if (p)
+            pEnd = (char *)p;
+        else
+            pEnd = (char *)pValue + valLen;
+        char ch = *pEnd;
+        *pEnd = 0;
+        
+        pMIME = pContext->lookupMimeSetting((char *)pValue);
+        LS_DBG_L(pReq->getLogSession(), "content type: [%s], pMIME: %p\n",
+                    pValue, pMIME);
+        *pEnd = ch;
+
+    }
+    if (gzipAccept)
+    {
+        if (!pMIME || !pMIME->getExpires()->compressible())
+            pReq->andGzip(~GZIP_ENABLED);
+    }
+    
+    if (enbale)
+    {
+        ExpiresCtrl *pExpireDefault = NULL;
+        if (pMIME && pMIME->getExpires()->getBase())
+            pExpireDefault = (ExpiresCtrl *)pMIME->getExpires();
+        if (pExpireDefault == NULL)
+            pExpireDefault = &pContext->getExpires();
+
+        if (pExpireDefault->getBase())
+            pResp->addExpiresHeader(DateTime::s_curTime, pExpireDefault);
+    }
+
+    if (pReq->isKeepAlive())
+        pReq->smartKeepAlive(pValue);
     
     if (HttpMime::needCharset(pValue))
     {
         pCharset = pReq->getDefaultCharset();
-        if (pCharset && (p = (char *)memchr(pValue, ';', valLen)) != NULL)
+        if (pCharset && p)
         {
             while (isspace(*(++p)))
                 ;
@@ -359,31 +402,6 @@ static char DEFAULT_PATH[] =
     "/bin:/usr/bin:/usr/ucb:/usr/bsd:/usr/local/bin";
 static int DEFAULT_PATHLEN = sizeof(DEFAULT_PATH) - 1;
 #define CGI_FWD_HEADERS 12
-static const char *CGI_HEADERS[HttpHeader::H_TRANSFER_ENCODING ] =
-{
-    "HTTP_ACCEPT", "HTTP_ACCEPT_CHARSET", "HTTP_ACCEPT_ENCODING",
-    "HTTP_ACCEPT_LANGUAGE", "HTTP_AUTHORIZATION", "HTTP_CONNECTION",
-    "CONTENT_TYPE", "CONTENT_LENGTH", "HTTP_COOKIE", "HTTP_COOKIE2",
-    "HTTP_HOST", "HTTP_PRAGMA", "HTTP_REFERER", "HTTP_USER_AGENT",
-    "HTTP_CACHE_CONTROL",
-    "HTTP_IF_MODIFIED_SINCE", "HTTP_IF_MATCH",
-    "HTTP_IF_NONE_MATCH",
-    "HTTP_IF_RANGE",
-    "HTTP_IF_UNMODIFIED_SINCE",
-    "HTTP_KEEPALIVE",
-    "HTTP_RANGE",
-    "HTTP_X_FORWARDED_FOR",
-    "HTTP_VIA",
-
-    //"HTTP_TRANSFER_ENCODING"
-};
-static int CGI_HEADER_LEN[HttpHeader::H_TRANSFER_ENCODING ] =
-{
-    11, 19, 20, 20, 18, 15, 12, 14, 11, 12, 9, 11, 12, 15, 18,
-    22, 13, 18, 13, 24, 14, 10, 20, 8
-};
-
-
 int HttpCgiTool::buildEnv(IEnv *pEnv, HttpSession *pSession)
 {
     HttpReq *pReq = pSession->getReq();
@@ -499,6 +517,22 @@ int HttpCgiTool::addSpecialEnv(IEnv *pEnv, HttpReq *pReq)
 }
 
 
+static int lookup_ssl_cert_serial(X509 *pCert, char *pBuf, int len)
+{
+    BIO *bio;
+    int n;
+
+    if ((bio = BIO_new(BIO_s_mem())) == NULL)
+        return LS_FAIL;
+    i2a_ASN1_INTEGER(bio, X509_get_serialNumber(pCert));
+    //n = BIO_pending(bio);
+    n = BIO_read(bio, pBuf, len);
+    pBuf[n] = '\0';
+    BIO_free(bio);
+    return n;
+}
+
+
 static int addEnv(void *pObj, void *pUData, const char *pKey, int iKeyLen)
 {
     IEnv *pEnv = (IEnv *)pUData;
@@ -545,7 +579,7 @@ int HttpCgiTool::buildCommonEnv(IEnv *pEnv, HttpSession *pSession)
 
     pEnv->add("SERVER_NAME", 11, pReq->getHostStr(),  pReq->getHostStrLen());
     count += 5 - isPython;
-    
+
     pStr = pReq->getVHost()->getAdminEmails();
     if (pStr->c_str())
     {
@@ -714,7 +748,7 @@ int HttpCgiTool::buildCommonEnv(IEnv *pEnv, HttpSession *pSession)
                                  X509_get_version(pClientCert) + 1);
                     pEnv->add("SSL_CLIENT_M_VERSION", 20, achBuf, n);
                     ++count;
-                    n = SslUtil::lookupCertSerial(pClientCert, achBuf, 4096);
+                    n = lookup_ssl_cert_serial(pClientCert, achBuf, 4096);
                     if (n != -1)
                     {
                         pEnv->add("SSL_CLIENT_M_SERIAL", 19, achBuf, n);
@@ -764,7 +798,9 @@ int HttpCgiTool::addHttpHeaderEnv(IEnv *pEnv, HttpReq *pReq)
 {
     int i, n;
     const char *pTemp;
-    for (i = 0; i < HttpHeader::H_TRANSFER_ENCODING; ++i)
+    LsiApiConst lsiApiConst;
+    int headers = lsiApiConst.get_cgi_header_count();
+    for (i = 0; i < headers; ++i)
     {
         pTemp = pReq->getHeader(i);
         if (*pTemp)
@@ -775,7 +811,8 @@ int HttpCgiTool::addHttpHeaderEnv(IEnv *pEnv, HttpReq *pReq)
             if ((i == HttpHeader::H_AUTHORIZATION)
                 && (pReq->getAuthUser()))
                 continue;
-            pEnv->add(CGI_HEADERS[i], CGI_HEADER_LEN[i],
+            pEnv->add(lsiApiConst.get_cgi_header(i), 
+                      lsiApiConst.get_cgi_header_len(i),
                       pTemp, pReq->getHeaderLen(i));
         }
     }
