@@ -32,12 +32,13 @@
 int HttpHeader::s_iHeaderLen[H_HEADER_END + 1] =
 {
     6, 14, 15, 15, 13, 10, 12, 14, 6, 7, 4, 6, 7, 10, //user-agent
-    13, 17, 8, 13, 8, 19, 10, 5, 15, 3, 17, 2, 17, 6, 12, 19, 4, //date
+    13, 17, 8, 13, 8, 19, 10, 5, 15, 3, 17, 2, 6, 12, 19, 4, //date
     7, 7, 7, 5, 16, 16, 16, 11, 13, 7, 13, //last-modified
     //13,3,4,8,18,16,11,6,4,16,10,11,6,20,19,25,
     0
 };
 
+
 const char *HttpHeader::s_pHeaderNames[H_HEADER_END + 1] =
 {
     //Most common headers
@@ -67,7 +68,6 @@ const char *HttpHeader::s_pHeaderNames[H_HEADER_END + 1] =
 
     // request-header
     "TE",
-    "X-LiteSpeed-Purge",
     "Expect",
     "Max-Forwards",
     "Proxy-Authorization",
@@ -121,7 +121,6 @@ const char *HttpHeader::s_pHeaderNamesLowercase[H_HEADER_END + 1] =
 
     // request-header
     "te",
-    "x-litespeed-purge"
     "expect",
     "max-forwards",
     "proxy-authorization",
@@ -146,34 +145,39 @@ const char *HttpHeader::s_pHeaderNamesLowercase[H_HEADER_END + 1] =
 };
 
 
-// static void normalizeHeader(const char *pSrc, char *pDest)
-// {
-//     int i, len;
-//     const char *pTotal, *pDash, *p = pSrc;
-//     char *pDestPtr = pDest;
-//     if (s_iMaxHdrLen == 0)
-//     {
-//         for (i = 0; i < HttpHeader::H_HEADER_END + 1; ++i)
-//             if (HttpHeader::getHeaderStringLen(i) > s_iMaxHdrLen)
-//                 s_iMaxHdrLen = HttpHeader::getHeaderStringLen(i);
-//     }
-//     pTotal = pSrc + s_iMaxHdrLen;
-//     while ((pDash = (const char *)memchr(p, '_', pTotal - p)) != NULL)
-//     {
-//         len = pDash - p;
-//         StringTool::strLower(p, pDestPtr, len);
-//         pDestPtr += len;
-//         *pDestPtr++ = '-';
-//         p += len + 1;
-//     }
-//     len = pTotal - p;
-//     StringTool::strLower(p, pDestPtr, len);
-// }
+/* not used
+static void normalizeHeader(const char *pSrc, char *pDest)
+{
+    int i, len;
+    const char *pTotal, *pDash, *p = pSrc;
+    char *pDestPtr = pDest;
+    if (s_iMaxHdrLen == 0)
+    {
+        for (i = 0; i < HttpHeader::H_HEADER_END + 1; ++i)
+            if (HttpHeader::getHeaderStringLen(i) > s_iMaxHdrLen)
+                s_iMaxHdrLen = HttpHeader::getHeaderStringLen(i);
+    }
+    pTotal = pSrc + s_iMaxHdrLen;
+    while ((pDash = (const char *)memchr(p, '_', pTotal - p)) != NULL)
+    {
+        len = pDash - p;
+        StringTool::strLower(p, pDestPtr, len);
+        pDestPtr += len;
+        *pDestPtr++ = '-';
+        p += len + 1;
+    }
+    len = pTotal - p;
+    StringTool::strLower(p, pDestPtr, len);
+}
+*/
 
 
 size_t HttpHeader::getIndex(const char *pHeader)
 {
+    //char achHdr[0x100];
     size_t idx = H_HEADER_END;
+    //normalizeHeader(pHeader, achHdr);
+    //pHeader = achHdr;
     switch (*pHeader++ | 0x20)
     {
     case 'a':
@@ -262,8 +266,6 @@ size_t HttpHeader::getIndex(const char *pHeader)
     case 'x':
         if (strncasecmp(pHeader, "-forwarded-for", 14) == 0)
             idx = H_X_FORWARDED_FOR;
-        else if (strncasecmp(pHeader, "-litespeed-purge", 16) == 0)
-            idx = H_X_LITESPEED_PURGE;
         break;
     }
 
