@@ -19,7 +19,6 @@
 
 #include <http/handlerfactory.h>
 #include <http/httphandler.h>
-#include <http/handlertype.h>
 #include <http/httplog.h>
 #include <http/httpvhost.h>
 #include <log4cxx/logger.h>
@@ -92,12 +91,13 @@ static AutoStr2 *getMIME(const char *pMIME)
 //}
 
 
-// static const char SEPARATORS[] =
-// {
-//     '(', ')', '<', '>', '@', ',', ';', ':', '\\', '"', '/', '[', ']', '?', '=',
-//     '{', '}', ' ', '\t'
-// };
-
+/* not used?
+static const char SEPARATORS[] =
+{
+    '(', ')', '<', '>', '@', ',', ';', ':', '\\', '"', '/', '[', ']', '?', '=',
+    '{', '}', ' ', '\t'
+};
+*/
 
 static bool isValidToken(const char *pToken, int len)
 {
@@ -830,13 +830,16 @@ int HttpMime::loadMime(const char *pPropertyPath)
     int lineNo = 0;
     m_pSuffixMap->release_objects();
 
-    while (fgets(pBuf, TEMP_BUF_LEN, fpMime))
+    while (! feof(fpMime))
     {
         lineNo ++ ;
-        char *p = strchr(pBuf, '#');
-        if (p)
-            *p = 0;
-        processOneLine(pPropertyPath, pBuf, lineNo);
+        if (fgets(pBuf, TEMP_BUF_LEN, fpMime))
+        {
+            char *p = strchr(pBuf, '#');
+            if (p)
+                *p = 0;
+            processOneLine(pPropertyPath, pBuf, lineNo);
+        }
     }
 
     fclose(fpMime);
@@ -1155,19 +1158,23 @@ int HttpMime::addMimeHandler(const char *pSuffix, char *pMime,
     return 0;
 }
 
-
-int HttpMime::_configScriptHandler(ConfigCtx& currentCtx, const char *value,
-                                   AutoStr *psuffix, AutoStr *psType,
-                                   char *achHandler, int max_len)
+int HttpMime::configScriptHandler(const XmlNodeList *pList, HttpMime *pHttpMime,
+                                    HttpVHost *vhost)
 {
+    ConfigCtx currentCtx("scripthandler", "add");
+    XmlNodeList::const_iterator iter;
+
+    for (iter = pList->begin(); iter != pList->end(); ++iter)
+    {
+        const char *value = (char *)(*iter)->getValue();
         const char *pSuffixByTab = strchr(value, '\t');
         const char *pSuffixBySpace = strchr(value, ' ');
-        const char *suffix;
+        const char *suffix  = NULL;
 
         if (pSuffixByTab == NULL && pSuffixBySpace == NULL)
         {
             currentCtx.logErrorInvalTag("ScriptHandler", value);
-            return -1;
+            continue;
         }
         else if (pSuffixByTab == NULL)
             suffix = pSuffixBySpace;
@@ -1178,317 +1185,68 @@ int HttpMime::_configScriptHandler(ConfigCtx& currentCtx, const char *value,
 
         const char *type = strchr(value, ':');
 
-        if (!suffix || !type || strchr(suffix, '.') || type > suffix)
+        if (suffix == NULL || type == NULL || strchr(suffix, '.') || type > suffix)
         {
             currentCtx.logErrorInvalTag("suffix", suffix);
-            return -1;
+            continue;
 
         }
 
-        while(isspace(*suffix))
-            ++ suffix; //should all spaces be handled here?? Now only one white space handled.
+        ++ suffix; //should all spaces be handled here?? Now only one white space handled.
 
-        psType->setStr(value, type - value);
+        char pType[256] = {0};
+        memcpy(pType, value, type - value);
 
         char handler[256] = {0};
         memcpy(handler, type + 1, suffix - type - 2);
-        
-        /**
-         * trim tail space
-         */
-        int len = strlen(handler);
-        while(len > 0 && isspace(handler[len-1]))
-            handler[--len] = 0x00;
 
-        if (currentCtx.expandVariable(handler, achHandler, max_len) < 0)
+        char achHandler[256] = {0};
+
+        if (currentCtx.expandVariable(handler, achHandler, 256) < 0)
         {
             LS_NOTICE(&currentCtx,
                       "add String is too long for scripthandler, value: %s",
                       handler);
-            return -1;
+            continue;
         }
-        
-        psuffix->setStr(suffix, strlen(suffix));
-        return 0;
-}
 
-
-void HttpMime::releaseHandlerData(scriptHanlderData *pData, int dataCount)
-{
-    for (int i=0; i<dataCount; ++i)
-    {
-        free(pData[i].handler);
-        free(pData[i].suffix);
-        free(pData[i].type);
-    }
-    delete [] pData;
-}
-
-
-/**
- * return NULL not find, otherwise return the item
- */
-static scriptHanlderData* lookSuffixInArr(scriptHanlderData *pData,
-                          int count, const char *suffix)
-{
-    for (int i=0; i<count; ++i)
-    {
-        if (strcasecmp(pData[i].suffix, suffix) == 0)
-            return &pData[i];
-    }
-    return NULL;
-}
-
-/**
- * Merge is by suffix, if the suffix is not defined in list then need to merge 
- * from parentData
- */
-void HttpMime::mergeHandlerList(ConfigCtx& currentCtx,
-                                scriptHanlderData *parentData,
-                                int parentDataCount,
-                                const XmlNodeList  *pList,
-                                scriptHanlderData *pdata,
-                                int *count)
-{
-    int n = 0;
-    /**
-     * Always clear the state of parent level data first
-     */
-    for (int i=0; i<parentDataCount; ++i)
-        parentData[i].state = 0;
-
-    if (pList)
-    {
-        XmlNodeList::const_iterator iter;
-        for (iter = pList->begin(); iter != pList->end(); ++iter)
+        if (vhost)
         {
-            const char *value = (char *)(*iter)->getValue();
-            char achHandler[256] = {0};
-            AutoStr sSuffix;
-            AutoStr sType;
-            int ret = _configScriptHandler(currentCtx, value, &sSuffix, &sType,
-                                           achHandler, 256);
-            if (ret)
-                continue;
-
-            /**
-             * sSuffix can be a list
-             */
-            
-            StringList strList;
-            const char *pSuffix = sSuffix.c_str();
-            int size = strList.split(pSuffix, pSuffix + strlen(pSuffix), ",");
-            for (int i=0; i<size; ++i)
+            app_node_st *app_node_ptr = MainServerConfig::getInstance().
+                                            getExtAppXmlNode(achHandler);
+            if (app_node_ptr)
             {
-                pSuffix = strList[i]->c_str();
-                pdata[n].handler = strdup(achHandler);
-                pdata[n].suffix = strdup(pSuffix);
-                pdata[n].type = strdup(sType.c_str());
-                pdata[n].state = 0;  //vhost own
-                ++n;
-
-                scriptHanlderData* parentDataItem = lookSuffixInArr(parentData,
-                                                                parentDataCount,
-                                                                pSuffix);
-                if (parentDataItem)
-                    parentDataItem->state = 1;
-            }
-        }
-    }
-
-    /**
-     * Now check if any undefined in vhost but defined in server level
-     */
-    for (int i=0; i<parentDataCount; ++i)
-    {
-        if (parentData[i].state == 0)
-        {
-            pdata[n].handler = strdup(parentData[i].handler);
-            pdata[n].suffix =  strdup(parentData[i].suffix);
-            pdata[n].type = strdup(parentData[i].type);
-            pdata[n].state = 1;  //copy from server
-            ++n;
-        }
-    }
-    *count = n;
-}
-
-/***
- * Comments:
- * Since the server level cannot be too many suffix, we use array to store
- * and loop search instead of hashtable
- * And we do not release this buffer for we may use it ion future just
- * as the XML tree
- */
-static scriptHanlderData  *s_pSvrScriptHanlderData = NULL;
-static int s_nSvrScriptHanlderData = 0;
-
-
-/**
- * The return value should be equal or larger than real count to make
- * enough space 
- */
-int HttpMime::getSuffixCount(const XmlNodeList *pList)
-{
-    int count = 0;
-    if (pList)
-    {
-        XmlNodeList::const_iterator iter;
-        for (iter = pList->begin(); iter != pList->end(); ++iter)
-        {
-            const char *value = (char *)(*iter)->getValue();
-            ++count;
-            while( value && *value && (value = strchr(value, ',')) != NULL)
-            {
-                ++value;
-                ++count;
-            }
-        }
-    }
-    return count;
-}
-
-
-int HttpMime::configScriptHandler(const XmlNodeList *pList,
-                                  HttpMime *pHttpMime,
-                                  HttpVHost *vhost)
-{
-    ConfigCtx currentCtx("scripthandler", "add");
-    scriptHanlderData  *pData = NULL;
-    int nData = 0;
-    int listSize = getSuffixCount(pList);
-    
-    if (!vhost)
-    {
-        if (s_pSvrScriptHanlderData == NULL && listSize > 0)
-            s_pSvrScriptHanlderData = new scriptHanlderData[listSize];
-        
-        if (s_pSvrScriptHanlderData)
-        {
-            mergeHandlerList(currentCtx, NULL, 0, pList, s_pSvrScriptHanlderData,
-                             &s_nSvrScriptHanlderData);
-        }
-
-        pData = s_pSvrScriptHanlderData;
-        nData = s_nSvrScriptHanlderData;
-    }
-    else
-    {
-        pData = new scriptHanlderData[listSize + s_nSvrScriptHanlderData];
-        if (pData)
-        {
-            mergeHandlerList(currentCtx, s_pSvrScriptHanlderData,
-                             s_nSvrScriptHanlderData, pList, pData, &nData);
-        }
-    }
-
-    if (!pData)
-    {
-        LS_ERROR(&currentCtx, "It seems out of memory in configScriptHandler()!!! ");
-        return -1;
-    }
-
-
-    for (int i=0; i<nData; ++i)
-    {
-        const HttpHandler *pHdlr = NULL;
-        char *suffix = pData[i].suffix;
-        char *handler = pData[i].handler;
-        char *type = pData[i].type;
-        
-        /**
-         * Server level need fill in the array
-         */
-        if (!vhost)
-        {
-            pHdlr = HandlerFactory::getHandler(type, handler);
-            LS_DBG_H(&currentCtx, "HttpMime::addMimeHandler(server) getHandler with"
-                " name %s (for suffix %s) ret %p", handler, suffix, pHdlr);
-        }
-
-        else
-        {
-            /**
-             * First check if VHost have this configged, if yes, use it
-             * otherewise, will use server level, but if server level guid is 
-             * different, create a vhost owned extapp
-             */
-            char sHanlderVh[256];
-            vhost->getUniAppName(handler, sHanlderVh, 256);
-            pHdlr = HandlerFactory::getHandler(type, sHanlderVh);
-            LS_DBG_H(&currentCtx, "HttpMime::addMimeHandler(vhost) getHandler with"
-                    " name %s (for suffix %s) ret %p",
-                     sHanlderVh, suffix, pHdlr);
-            
-            if (!pHdlr)
-            {
-                app_node_st *app_node_ptr = MainServerConfig::getInstance().
-                                            getExtAppXmlNode(handler);
-                if (app_node_ptr)
+                LocalWorker *pApp = static_cast<LocalWorker *>(app_node_ptr->worker);
+                if (vhost->getUid() != pApp->getConfig().getUid() ||
+                    vhost->getGid() != pApp->getConfig().getGid())
                 {
-                    LocalWorker *pApp = static_cast<LocalWorker *>(app_node_ptr->worker);
-                    
                     /**
-                     * If the APP has own user/group, do not inherit with
-                     * vhost level setting
+                     * Since the uid /gid not match with the setting in
+                     * server level, need to set up an own extApp and connect
+                     * to the suffix
                      */
-                    XmlNode *pNode = (XmlNode*)app_node_ptr->xml_node;
-                    const char *pUser = pNode->getChildValue("extUser");
-                    const char *pGroup = pNode->getChildValue("extGroup");
-                    if (!pUser && !pGroup &&
-                        (vhost->getUid() != pApp->getConfig().getUid() ||
-                        vhost->getGid() != pApp->getConfig().getGid()))
+                    int ret = vhost->addPhpXmlNodeSSize((char *)suffix,
+                                   (XmlNode*)app_node_ptr->xml_node);
+                    if (ret == -1)
                     {
-                        /**
-                        * Since the uid /gid not match with the setting in
-                        * server level, need to set up an own extApp and connect
-                        * to the suffix
-                        */
-                        int ret = vhost->addPhpXmlNodeSSize((char *)suffix,
-                                    (char *)handler,
-                                    (XmlNode*)app_node_ptr->xml_node);
-                        if (ret == -1)
-                        {
-                            LS_NOTICE(&currentCtx,
-                                    "Failed to addPhpXmlNodeSSize() due to too "
-                                    "many items > %d defined as MAX_VHOST_PHP_NUM.",
-                                    MAX_VHOST_PHP_NUM);
-                            LS_NOTICE(&currentCtx, "and will use SEREVR defined "
-                                        "user/group for this extApp.");
-                        }
-                        else
-                        {
-                            LS_DBG(&currentCtx, "addPhpXmlNodeSSize() for %s due"
-                                    " to diff user/group for this extApp.",
-                                   handler);
-                            continue;
-                        }
+                        LS_NOTICE(&currentCtx,
+                                  "Failed to addPhpXmlNodeSSize() due to too "
+                                  "many items > %d defined as"
+                                  " MAX_VHOST_PHP_NUM.",
+                                  MAX_VHOST_PHP_NUM);
+                        LS_NOTICE(&currentCtx, "and will use SEREVR defined "
+                                    "user/group for this extApp.");
                     }
-                }
-            }
-
-            if (!pHdlr)
-            {
-                pHdlr = HandlerFactory::getHandler(type, handler);
-                if (pHdlr)
-                {
-                    LS_DBG_H(&currentCtx, "HttpMime::addMimeHandler getHandler"
-                             " with name %s ret %p", handler, pHdlr);
-                }
-                else
-                {
-                    LS_ERROR(&currentCtx, "HttpMime::addMimeHandler getHandler"
-                             " with name %s ret %p", handler, pHdlr);
+                    else
+                        continue;
                 }
             }
         }
 
+        const HttpHandler *pHdlr = HandlerFactory::getHandler(pType, achHandler);
         addMimeHandler(pHdlr, NULL, pHttpMime, suffix);
     }
 
-    if (vhost && pData)
-        releaseHandlerData(pData, nData);
-
     return 0;
 }
 
@@ -1500,7 +1258,8 @@ void HttpMime::addMimeHandler(const HttpHandler *pHdlr, char *pMime,
     if (!pHdlr)
     {
         LS_ERROR(ConfigCtx::getCurConfigCtx(),
-                 "use static file handler for suffix [%s]", pSuffix);
+                 "use static file handler for suffix [%s]",
+                 pSuffix);
         pHdlr = HandlerFactory::getInstance(0, NULL);
     }
     HttpMime *pParent = NULL;
@@ -1510,8 +1269,8 @@ void HttpMime::addMimeHandler(const HttpHandler *pHdlr, char *pMime,
     else
         pHttpMime = HttpMime::getMime();
 
-    pHttpMime->addMimeHandler(pSuffix, pMime, pHdlr, pParent,
-                              TmpLogId::getLogId());
+    pHttpMime->addMimeHandler(pSuffix, pMime,
+                              pHdlr, pParent, TmpLogId::getLogId());
 }
 
 
