@@ -33,6 +33,7 @@ enum
 #include "httpvhost.h"
 #include <lsr/ls_str.h>
 #include <lsr/ls_types.h>
+#include <lsr/ls_atomic.h>
 #include <util/autobuf.h>
 #include <util/autostr.h>
 #include <log4cxx/logsession.h>
@@ -87,6 +88,12 @@ enum
 #define BR_REQUIRED             (BR_ENABLED | REQ_BR_ACCEPT)
 #define UPSTREAM_BR             4
 
+
+#define SUB_REQ_DETACHED        1
+#define SUB_REQ_NOABORT         2
+#define SUB_REQ_SETREFERER      4
+
+
 struct AAAData;
 class AuthRequired;
 class ClientInfo;
@@ -102,8 +109,7 @@ class HttpVHost;
 class IOVec;
 class MimeSetting;
 class RadixNode;
-class SSIConfig;
-class SSIRuntime;
+class SsiConfig;
 class StaticFileCacheData;
 class VHostMap;
 class VMemBuf;
@@ -111,7 +117,7 @@ class UnpackedHeaders;
 class HioCrypto;
 
 typedef struct ls_hash_s ls_hash_t;
-
+struct ls_subreq_s;
 
 typedef struct
 {
@@ -184,6 +190,8 @@ private:
     int                 m_iReqHeaderBufFinished;
     int                 m_iReqHeaderBufRead;
 
+    key_value_pair      m_curURL;
+
     const MimeSetting  *m_pMimeType;
 
     ls_xpool_t         *m_pPool;
@@ -201,12 +209,6 @@ private:
     int                 m_reqLineLen;
     int                 m_reqURLOff;
     int                 m_reqURLLen;
-    
-    /***
-     * The below two array to store the headers other than the common
-     */
-    uint16_t            m_otherHeaderLen[HttpHeader::H_HEADER_END - HttpHeader::H_TE];
-    int                 m_otherHeaderOffset[HttpHeader::H_HEADER_END - HttpHeader::H_TE];
     ls_str_t            m_location;
     ls_str_t            m_pathInfo;
     ls_str_t            m_newHost;
@@ -219,8 +221,10 @@ private:
     short               m_iCfIpHeader;
     short               m_method;
     int                 m_iEnvCount;
+
     unsigned short      m_ver;
     short               m_iRedirects;
+
     
     char                m_iReqFlag;
     char                 m_iAcceptGzip;
@@ -242,7 +246,6 @@ private:
     const char         *m_pForcedType;
     const HTAuth       *m_pHTAuth;
     const AuthRequired *m_pAuthRequired;
-    SSIRuntime         *m_pSSIRuntime;
     int                 m_iHostOff;
     int                 m_iHostLen;
     const AutoStr2     *m_pRealPath;
@@ -257,8 +260,13 @@ private:
     struct stat         m_fileStat;
     int                 m_iScriptNameLen;
     short               m_iBodyType;
+
+    LogSession         *m_pLogSession;
     LogSession         *m_pILog;
     CookieList          m_cookies;
+    AutoStr2            m_lastStatPath;
+    struct stat         m_lastStat;
+    int                 m_lastStatRes;
 
     static_file_data_t *m_pUrlStaticFileData;
 
@@ -283,6 +291,7 @@ private:
 
     int checkSuffixHandler(const char *pURI, int len, int &cacheable);
 
+    
 
 
     //parse headers
@@ -310,7 +319,7 @@ private:
     key_value_pair *getUnknHeaderByKey(const AutoBuf &buf, const char *pName,
                                        int namelen) const;
 
-    key_value_pair *getUnknHeaderPair(int index)
+    key_value_pair *getUnknHeaderPair(int index) const
     {   return m_unknHeaders.getObj(index); }
 
     int appendIndexToUri(const char *pIndex, int indexLen);
@@ -364,13 +373,13 @@ public:
 
     int processHeader();
     int processNewReqData(const struct sockaddr *pAddr);
-    void reset();
-    void reset2();
+    void reset(int discard = 0);
+//     void reset2();
 
-    void setILog(LogSession *pILog)         {   m_pILog = pILog;            }
-    LOG4CXX_NS::Logger *getLogger() const   {   return m_pILog->getLogger();}
-    const char   *getLogId()                {   return m_pILog->getLogId(); }
-    LogSession *getLogSession() const       {   return m_pILog;             }
+    void setILog(LogSession *pILog)         {   m_pLogSession = pILog;            }
+    LOG4CXX_NS::Logger *getLogger() const   {   return m_pLogSession->getLogger();}
+    const char   *getLogId()                {   return m_pLogSession->getLogId(); }
+    LogSession *getLogSession() const       {   return m_pLogSession;             }
 
     void setVHostMap(const VHostMap *pMap)  {   m_pVHostMap = pMap;         }
     const VHostMap *getVHostMap() const     {   return m_pVHostMap;         }
@@ -379,6 +388,7 @@ public:
 
     char getStatus() const                  {   return m_iHeaderStatus;     }
     int getMethod() const                   {   return m_method;            }
+    void setMethod(int method)              {   m_method = method;      }
 
     unsigned int getVersion() const         {   return m_ver;               }
 
@@ -418,12 +428,7 @@ public:
     //request header
 
     const char *getHeader(size_t index) const
-    {
-        int offset = (index < HttpHeader::H_TE ?
-                         m_commonHeaderOffset[index] :
-                         m_otherHeaderOffset[index - HttpHeader::H_TE]);
-        return m_headerBuf.begin() + offset;
-    }
+    {   return m_headerBuf.begin() + m_commonHeaderOffset[ index];  }
 
     const char *getHeader(const char *pName, int namelen, int &valLen) const
     {
@@ -439,11 +444,7 @@ public:
     int isHeaderSet(size_t index) const
     {   return m_commonHeaderOffset[index];     }
     int getHeaderLen(size_t index) const
-    {
-        return (index < HttpHeader::H_TE ?
-                 m_commonHeaderLen[ index ] :
-                 m_otherHeaderLen[ index - HttpHeader::H_TE]);
-    }
+    {   return m_commonHeaderLen[ index ];      }
 
     int dropReqHeader(int index);
     
@@ -495,7 +496,7 @@ public:
     int  redirect(const char *pURL, int len, int alloc = 0);
     int  postRewriteProcess(const char *pURI, int len);
     int  processContextPath();
-    int  processContext(const HttpContext *&pOldCtx);
+    int  processContext();
     int  checkPathInfo(const char *pURI, int iURILen, int &pathLen,
                        short &scriptLen, short &pathInfoLen,
                        const HttpContext *pContext);
@@ -524,20 +525,20 @@ public:
 
     const AutoStr2 *getRealPath() const     {   return m_pRealPath;         }
 
-    int  getLocationLen()
+    int  getLocationLen() const
     {   return ls_str_len(&m_location); }
     int  setLocation(const char *pLoc, int len);
-    const char *getLocation()
+    const char *getLocation() const
     {   return ls_str_cstr(&m_location);    }
     void clearLocation()
     {   ls_str_set(&m_location, NULL, 0); }
 
     int  appendRedirHdr(const char *pDisp, int len);
-    int  getRedirHdrsLen() const      
+    int  getRedirHdrsLen() const
     {   return ls_str_len(&m_redirHdrs);   }
     const char *getRedirHdrs() const
     {  return ls_str_cstr(&m_redirHdrs);   }
-    
+
     int  addWWWAuthHeader(HttpRespHeaders &buf) const;
     const AuthRequired *getAuthRequired() const
     {   return m_pAuthRequired; }
@@ -563,11 +564,11 @@ public:
     int prepareReqBodyBuf();
     void replaceBodyBuf(VMemBuf *pBuf);
     void updateBodyType(const char *buf);
-    
 
-    char gzipAcceptable() const             {   return m_iAcceptGzip;       }
-    void andGzip(char b)                    {   m_iAcceptGzip &= b;         }
-    void orGzip(char b)                     {   m_iAcceptGzip |= b;         }
+
+    char gzipAcceptable() const             {   return ls_atomic_fetch_or((volatile char*)&m_iAcceptGzip, 0);       }
+    void andGzip(char b)                    {   (void) ls_atomic_fetch_and(&m_iAcceptGzip, b);      }
+    void orGzip(char b)                     {   (void) ls_atomic_fetch_or(&m_iAcceptGzip, b);       }
 
     char brAcceptable() const               {   return m_iAcceptBr;       }
     void andBr(char b)                      {   m_iAcceptBr &= b;         }
@@ -587,7 +588,7 @@ public:
 
 
     void processReqBodyInReqHeaderBuf();
-    void resetHeaderBuf();
+    void resetHeaderBuf(int discard);
     int  pendingHeaderDataLen() const
     {   return m_iReqHeaderBufRead - m_iReqHeaderBufFinished;  }
 
@@ -607,8 +608,10 @@ public:
     void pendingDataProcessed(int len)
     {   m_iReqHeaderBufFinished += len; }
 
-    void setStatusCode(int code)            {   m_code = code;              }
-    int  getStatusCode() const              {   return m_code;              }
+    void setStatusCode(int code)
+    {   ls_atomic_setint(&m_code, code);        }
+    int  getStatusCode() const
+    {   return ls_atomic_add_fetch((volatile int *)&m_code, 0); }
     void tranEncodeToContentLen();
 
     const AutoStr2 *getDocRoot() const;
@@ -631,20 +634,20 @@ public:
 
     int checkSymLink(const char *pPath, int pathLen, const char *pBegin);
 
-    const char *findEnvAlias(const char *pKey, int keyLen, int &aliasKeyLen) const;
+    const char *findEnvAlias(const char *pKey, int keyLen, int &aliasKeyLen);
     ls_strpair_t *addEnv(const char *pKey, int keyLen, const char *pValue,
                          int valLen);
-    const char *getEnv(const char *pKey, int keyLen, int &valLen) const;
+    const char *getEnv(const char *pKey, int keyLen, int &valLen);
     const RadixNode *getEnvNode() const;
     int  getEnvCount();
     void unsetEnv(const char *pKey, int keyLen);
 
-    int  getUnknownHeaderCount()
+    int  getUnknownHeaderCount() const
     {
         return m_unknHeaders.getSize();
     }
     const char *getUnknownHeaderByIndex(int idx, int &keyLen,
-                                        const char *&pValue, int &valLen);
+                                        const char *&pValue, int &valLen) const;
     char isCfIpSet() const                      {   return m_iCfIpHeader;   }
     const char *getCfIpHeader(int &len);
 
@@ -678,7 +681,12 @@ public:
     int getContextState(int s) const    {   return m_iContextState & s; }
     int detectLoopRedirect(const char *pURI, int uriLen,
                            const char *pArg, int qsLen, int isSSL);
-    int detectLoopRedirect();
+    int detectLoopRedirect(int cmpCurUrl, const char *pUri, int uriLen,
+                           const char *pArg, int argLen);
+
+    int detectLoopRedirect()
+    {    return detectLoopRedirect(0, getURI(), getURILen(),
+                                   getQueryString(), getQueryStringLen());   }
     int saveCurURL();
     const char *getOrgURI()
     {
@@ -701,7 +709,6 @@ public:
     off_t getTotalLen() const
     {   return m_lEntityFinished + getHttpHeaderLen();  }
 
-    void addContentLenHeader(size_t len);
     void popHeaderEndCrlf();
     int  applyHeaderOps(HttpSession *pSession, HttpRespHeaders *pRespHeader);
 
@@ -723,15 +730,30 @@ public:
     char isGeoIpOn() const;
     uint32_t isIpToLocOn() const;
     int getDecodedOrgReqURI(char *&pValue);
-    SSIRuntime *getSSIRuntime() const       {   return m_pSSIRuntime;       }
-    void setSSIRuntime(SSIRuntime *p)       {   m_pSSIRuntime = p;          }
-    SSIConfig *getSSIConfig();
+    SsiConfig *getSsiConfig();
     uint32_t isXbitHackFull() const;
     uint32_t isIncludesNoExec() const;
+
     long getLastMod() const
     {   return m_fileStat.st_mtime;    }
-    void backupPathInfo();
-    void restorePathInfo();
+
+    void backupRealPath()
+    {
+        if (m_pRealPath)
+        {
+            if ((m_pRealPath->len() != m_lastStatPath.len())
+                || (memcmp(m_lastStatPath.c_str(), m_pRealPath->c_str(),
+                           m_pRealPath->len()) != 0))
+            {
+                m_lastStatPath.setStr(m_pRealPath->c_str(), m_pRealPath->len());
+            }
+        }
+    }
+
+    void restoreRealPath()
+    {
+        m_pRealPath = &m_lastStatPath;
+    }
     void setRealPath(const char *pRealPath, int len)
     {
         m_sRealPathStore.setStr(pRealPath, len);
@@ -771,6 +793,8 @@ public:
 
     int locationToUrl(const char *pLocation, int len);
 
+    int fileStat(const char *pPath, struct stat *st);
+
     int internalRedirectURI(const char *pURI, int len, int resetPathInfo = 1,
                             int no_escape = 1);
 //     void setErrorPage( )
@@ -790,6 +814,13 @@ public:
     ls_xpool_t *getPool()
     {   return m_pPool; }
 
+    void setNewOrgUrl(const char *pUrl, int len, const char *pQS, int qsLen);
+    int cloneReqBody(const char *pBuf, int32_t len);
+    int clone(HttpReq *getReq, struct lsi_subreq_s *pSubSessInfo);
+    void addContentLenHeader(size_t len);
+    void updateReqHeader(int index, const char *pNewValue, int newValueLen);
+    void setReferer(const char *getOrgReqURL, int getOrgReqURLLen);
+
     int removeCookie(const char *pName, int nameLen);
     cookieval_t *setCookie(const char *pName, int nameLen, const char *pValue,
                            int valLen);
@@ -811,9 +842,7 @@ public:
     int createHeaderValue(HttpSession *pSession, const char *pFmt, int len,
                           char *pBuf, int maxLen);
     void eraseHeader(key_value_pair * pHeader);
-    
-    void updateReqHeader(int index, const char *pNewValue,
-                         int newValueLen);
+
     void appendReqHeader( const char *pName, int iNameLen,
                           const char *pValue, int iValLen);
 
