@@ -19,11 +19,10 @@
 #define HTTPRESOURCEMANAGER_H
 
 #include <lsdef.h>
-#include <http/httpdefs.h>
 #include <util/objpool.h>
 #include <util/tsingleton.h>
 
-#define GLOBAL_BUF_SIZE MAX_BUF_SIZE
+#define GLOBAL_BUF_SIZE 16384
 
 class Aiosfcb;
 class ChunkInputStream;
@@ -43,9 +42,6 @@ typedef ObjPool<HttpSession>            HttpSessionPool;
 typedef ObjPool<NtwkIOLink>             NtwkIoLinkPool;
 typedef ObjPool<Aiosfcb>                AiosfcbPool;
 
-#define SESSION_POOL_VG_DEBUG 1
-
-
 class HttpResourceManager : public TSingleton<HttpResourceManager>
 {
     friend class TSingleton<HttpResourceManager>;
@@ -75,16 +71,16 @@ public:
     void recycleGunzip(GzipBuf *pBuf)
     {   m_poolGunzipBuf.recycle(pBuf);      }
 
-    MMapVMemBuf *getVMemBuf()
-    {   return m_poolVMemBuf.get();         }
+    MMapVMemBuf *getVMemBuf();
+    //{   return m_poolVMemBuf.get();         }
 
     int getVMemBufPoolSize()
     {   return m_poolVMemBuf.getPoolSize();         }
     int getVMemBufPoolCapacity()
     {   return m_poolVMemBuf.getPoolCapacity();     }
 
-    void recycle(VMemBuf *pBuf)
-    {   m_poolVMemBuf.recycle((MMapVMemBuf *) pBuf);    }
+    void recycle(VMemBuf *pBuf);
+    //{   m_poolVMemBuf.recycle((MMapVMemBuf *) pBuf);    }
 
     ChunkInputStream *getChunkInputStream()
     {   return m_poolChunkInputStream.get();    }
@@ -114,13 +110,21 @@ public:
 
 
 
-    void recycle(HttpSession *pSession);
+    void recycle(HttpSession *pSession)
+    ;
+//    {   m_poolHttpSession.recycle(pSession);    }
+        
+    HttpSession *getConnection()
+    ;
+ //   {    return m_poolHttpSession.get();   }
+ 
+    void recycle(HttpSession **pSession, int n)
+    ;
+//    {   m_poolHttpSession.recycle((void **)pSession, n);    }
 
-    HttpSession *getHttpSession();
-
-    void recycle(HttpSession **pSession, int n);
-
-    int getConnections(HttpSession **pSession, int n);
+    int getConnections(HttpSession **pSession, int n)
+    ;
+//    {   return m_poolHttpSession.get(pSession, n);          }
 
     int initAiosfcbPool();
     void recycle(Aiosfcb *pAiosfcb)
