@@ -32,10 +32,10 @@
 /*******************************************************************************
  *          Some comments about the resp_kvpair
  * keyOff is the real offset of the key/name,  valOff is the real offset of the value
- * next_index is 0 for sigle line case
+ * next_index is 0 for single line case
  * FOR MULTIPLE LINE CASE, next_index is relative with the next kvpair position
  * The next_index of the first KVpair of the multiple line is (the next kvpair position + 1)
- * Then in all the chlidren KVPair, the next_index is (the next kvpair position + 1) | 0x80000000
+ * Then in all the children KVPair, the next_index is (the next kvpair position + 1) | 0x80000000
  * The last one (does not have a child) is 0x80000000
  * ****************************************************************************/
 
@@ -48,16 +48,13 @@
 char HttpRespHeaders::s_sDateHeaders[30] = "Tue, 09 Jul 2013 13:43:01 GMT";
 int             HttpRespHeaders::s_commonHeadersCount = 2;
 http_header_t       HttpRespHeaders::s_commonHeaders[2];
-http_header_t       HttpRespHeaders::s_gzipHeaders;
-http_header_t       HttpRespHeaders::s_brHeaders;
-http_header_t       HttpRespHeaders::s_varyHeaders;
+http_header_t       HttpRespHeaders::s_gzipHeaders[2];
+http_header_t       HttpRespHeaders::s_brHeaders[2];
 http_header_t       HttpRespHeaders::s_keepaliveHeader;
 http_header_t       HttpRespHeaders::s_chunkedHeader;
 http_header_t       HttpRespHeaders::s_concloseHeader;
 http_header_t       HttpRespHeaders::s_acceptRangeHeader;
 
-static char s_sTurboCharged[66] = "X-Turbo-Charged-By: ";
-
 const char *HttpRespHeaders::m_sPresetHeaders[H_HEADER_END] =
 {
     "Accept-Ranges",
@@ -108,10 +105,34 @@ HttpRespHeaders::HttpRespHeaders(ls_xpool_t *pool)
     : m_buf()
     , m_aKVPairs()
     , m_iHttpCode(SC_200)
+    , m_hLastHeaderKVPairIndex(0) // NOTICE: set to 0 first so reset works.
 {
     m_pool = pool;
     incKVPairs(16); //init 16 kvpair spaces
-    memset(&m_flags, 0, &m_iKeepAlive + 1 - &m_flags);
+    reset();
+}
+
+void HttpRespHeaders::reset2()
+{
+    if (m_KVPairindex[H_SET_COOKIE] == 0xFF)
+    {
+        reset();
+        return;
+    }
+    if (m_iHeaderUniqueCount == 1)
+        return;
+
+    struct iovec iov[100], *pIov, *pIovEnd;
+    int max = 100;
+    max = getHeader(H_SET_COOKIE, iov, 100);
+    AutoBuf tmp;
+    tmp.swap(m_buf);
+    reset();
+    pIovEnd = &iov[max];
+    for (pIov = iov; pIov < pIovEnd; ++pIov)
+        add(H_SET_COOKIE, "Set-Cookie", 10, (char *)pIov->iov_base,
+            pIov->iov_len, LSI_HEADEROP_ADD);
+
 }
 
 
@@ -140,13 +161,7 @@ void HttpRespHeaders::updateEtag(int compress_type)
     pUpdate = (char *)pETag + etagLen - 4;
     if (*pUpdate++ == ';')
     {
-        /*if (compress_type == 0)
-        {
-            *pUpdate++ = ';';
-            *pUpdate++ = ';';
-        }
-        else */
-        if (compress_type == 1)
+        if (compress_type == 0)
         {
             *pUpdate++ = 'g';
             *pUpdate++ = 'z';
@@ -191,13 +206,15 @@ void HttpRespHeaders::replaceHeader(resp_kvpair *pKv, const char *pVal,
 }
 
 
+#define HRH_SVR_RESERVE 127
+
 int HttpRespHeaders::appendHeader(resp_kvpair *pKv, const char *pName,
                                   unsigned int nameLen, const char *pVal,
                                   unsigned int valLen, int method)
 {
     if (nameLen + valLen > MAX_RESP_HEADER_LEN
-        || m_buf.size() >=
-        HttpServerConfig::getInstance().getMaxDynRespHeaderLen())
+        || (!m_isFinalize && m_buf.size() + nameLen + valLen + HRH_SVR_RESERVE >=
+            HttpServerConfig::getInstance().getMaxDynRespHeaderLen()))
         return LS_FAIL;
 
     if (method == LSI_HEADEROP_SET)
@@ -288,17 +305,39 @@ static int hasValue(const char *existVal, int existValLen, const char *val,
 
 
 //method: 0 replace,1 append, 2 merge, 3 add
-//headerIndex may be a invalid index, so just for compare with Set-cookie,
-//              Can not use to retrive name and nameLen
-int HttpRespHeaders::_add(int kvOrderNum, const char *pName, int nameLen,
-                          const char *pVal, unsigned int valLen, int method,
-                          INDEX headerIndex)
+int HttpRespHeaders::add(INDEX index, const char *pName, int nameLen,
+                          const char *pVal, unsigned int valLen, int method)
 {
-    assert(kvOrderNum >= 0);
-    resp_kvpair *pKv;
+    if ((nameLen <= 0) || (index > H_HEADER_END))
+        return -1;
+
+    int kvOrderNum = -1;
+    resp_kvpair *pKv = NULL;
+
+    if (index != H_HEADER_END)
+    {
+        if ((int)nameLen != getHeaderStringLen(index))
+            index = H_HEADER_END;
+    }
+    if (index == H_HEADER_END)   // || index == H_UNKNOWN )
+    {
+        int ret = getHeaderKvOrder(pName, nameLen);
+        if (ret != -1)
+            kvOrderNum = ret;
+        else
+            kvOrderNum = getTotalCount();
+    }
+    else
+    {
+        verifyHeaderLength(index,  pName, nameLen);
+        if (m_KVPairindex[index] == 0xFF)
+            m_KVPairindex[index] = getTotalCount();
+        kvOrderNum = m_KVPairindex[index];
+    }
+
     if (kvOrderNum == getTotalCount())
     {
-        //Add a new header
+        // Add a new header
         if (getFreeSpaceCount() == 0)
             incKVPairs(10);
         pKv = getNewKV();
@@ -307,7 +346,8 @@ int HttpRespHeaders::_add(int kvOrderNum, const char *pName, int nameLen,
     else
         pKv = getKV(kvOrderNum);
 
-    //enough space for replace, use the same keyoff, and update valoff, add padding, make it is the same length as before
+    // enough space for replace, use the same keyoff, and update valoff,
+    // add padding, make it the same length as before
     if (method == LSI_HEADEROP_SET && pKv->keyLen == (int)nameLen
         && pKv->valLen >= (int)valLen)
     {
@@ -318,14 +358,14 @@ int HttpRespHeaders::_add(int kvOrderNum, const char *pName, int nameLen,
     if ((method == LSI_HEADEROP_MERGE || method == LSI_HEADEROP_ADD) 
         && (pKv->valLen > 0))
     {
-        if ( (headerIndex != H_SET_COOKIE || method != LSI_HEADEROP_ADD)
+        if ( (index != H_SET_COOKIE || method != LSI_HEADEROP_ADD)
             && hasValue(getVal(pKv), pKv->valLen, pVal, valLen))
             return 0;//if exist when merge, ignor, otherwise same as append
     }
 
     m_hLastHeaderKVPairIndex = kvOrderNum;
 
-    //Under append situation, if has existing key and valLen > 0, then makes a hole
+    // Under append situation, if has existing key and valLen > 0, then makes a hole
     if (pKv->valLen > 0 && method != LSI_HEADEROP_ADD)
     {
         assert(pKv->keyLen > 0);
@@ -341,56 +381,28 @@ int HttpRespHeaders::add(INDEX headerIndex, const char *pVal,
 {
     if ((int)headerIndex < 0 || headerIndex >= H_HEADER_END)
         return LS_FAIL;
-
     if (headerIndex == H_LINK)
     {
         if (memmem(pVal, valLen, "preload", 7) != NULL)
             m_flags |= HRH_F_HAS_PUSH;
     }
-    if (m_KVPairindex[headerIndex] == 0xFF)
-        m_KVPairindex[headerIndex] = getTotalCount();
-    return _add(m_KVPairindex[headerIndex], m_sPresetHeaders[headerIndex],
-                s_iHeaderLen[headerIndex], pVal, valLen, method, headerIndex);
+    return add(headerIndex, m_sPresetHeaders[headerIndex],
+               s_iHeaderLen[headerIndex], pVal, valLen, method);
 }
 
 int HttpRespHeaders::addWithUnknownHeader(const char *pName, int nameLen, const char *pVal,
                          unsigned int valLen, int method)
 
 {
-    int kvOrderNum = -1;
-    INDEX headerIndex = H_HEADER_END;
-    int ret = getHeaderKvOrder(pName, nameLen);
-    if (ret != -1)
-        kvOrderNum = ret;
-    else
-        kvOrderNum = getTotalCount();
-
-    return _add(kvOrderNum, pName, nameLen, pVal, valLen, method, headerIndex);
+    return add(H_HEADER_END, pName, nameLen, pVal, valLen, method);
 }
 
 
 int HttpRespHeaders::add(const char *pName, int nameLen, const char *pVal,
                          unsigned int valLen, int method)
 {
-    int kvOrderNum = -1;
     INDEX headerIndex = getIndex(pName);
-    if (headerIndex != H_HEADER_END)
-    {
-        if (s_iHeaderLen[headerIndex] == nameLen)
-        {
-            //assert(strncasecmp(m_sPresetHeaders[headerIndex], pName, nameLen) == 0);
-            return add(headerIndex, pVal, valLen, method);
-        }
-        headerIndex = H_HEADER_END;
-    }
-
-    int ret = getHeaderKvOrder(pName, nameLen);
-    if (ret != -1)
-        kvOrderNum = ret;
-    else
-        kvOrderNum = getTotalCount();
-
-    return _add(kvOrderNum, pName, nameLen, pVal, valLen, method, headerIndex);
+    return add(headerIndex, pName, nameLen, pVal, valLen, method);
 }
 
 
@@ -507,7 +519,7 @@ char *HttpRespHeaders::getContentTypeHeader(int &len)
 }
 
 
-//The below calling will not maintance the kvpaire when regular case
+//The below calling will not maintain the kvpaire when regular case
 int HttpRespHeaders::parseAdd(const char *pStr, int len, int method)
 {
     //When SPDY format, we need to parse it and add one by one
@@ -521,9 +533,12 @@ int HttpRespHeaders::parseAdd(const char *pStr, int len, int method)
     const char *pLineEnd = NULL;
     const char *pLineBegin  = pStr;
 
-    while ((pLineEnd  = (const char *)memchr(pLineBegin, '\n',
-                        pBEnd - pLineBegin)) != NULL)
+    while (pBEnd > pLineBegin)
     {
+        pLineEnd  = (const char *)memchr(pLineBegin, '\n',
+                        pBEnd - pLineBegin);
+        if (pLineEnd == NULL)
+            pLineEnd = pBEnd;
         pMark = (const char *)memchr(pLineBegin, ':', pLineEnd - pLineBegin);
         if (pMark != NULL)
         {
@@ -903,18 +918,17 @@ int HttpRespHeaders::mergeAll()
 }
 
 
-void HttpRespHeaders::dump(LogSession *pILog, int dump_header) const
+void HttpRespHeaders::dump(LogSession *pILog, int dump_header)
 {
-    LS_DBG_H(pILog, "Resp headers, status: %d, total: %d, removed: %d, unique:%d, "
+    LS_DBG_H(pILog, "Resp headers, total: %d, removed: %d, unique:%d, " 
                     "has hole: %d, buffer size: %d",
-             (int)m_iHttpCode,
         (int)getTotalCount(), (int)m_iHeaderRemovedCount,
         (int)m_iHeaderUniqueCount, (int)m_flags,
         (int)m_buf.size() );
     resp_kvpair *pKv = getKV(0);
-    resp_kvpair *pKvEnd = getKV(getTotalCount() - 1);
+    resp_kvpair *pKvEnd = pKv + getTotalCount();
 
-    while (pKv <= pKvEnd)
+    while (pKv < pKvEnd)
     {
         if (pKv->keyLen > 0)
         {
@@ -926,8 +940,6 @@ void HttpRespHeaders::dump(LogSession *pILog, int dump_header) const
 }
 
 
-
-
 int HttpRespHeaders::appendToIov(IOVec *iovec, int &addCrlf)
 {
     int total;
@@ -997,23 +1009,29 @@ void HttpRespHeaders::buildCommonHeaders()
         HttpServerVersion::getVersionLen();
 
 
-    HttpRespHeaders::s_gzipHeaders.index    =
+    HttpRespHeaders::s_gzipHeaders[0].index    =
         HttpRespHeaders::H_CONTENT_ENCODING;
-    HttpRespHeaders::s_gzipHeaders.val      = "gzip";
-    HttpRespHeaders::s_gzipHeaders.valLen   = 4;
+    HttpRespHeaders::s_gzipHeaders[0].val      = "gzip";
+    HttpRespHeaders::s_gzipHeaders[0].valLen   = 4;
 
-    HttpRespHeaders::s_brHeaders.index    =
+    HttpRespHeaders::s_gzipHeaders[1].index    = HttpRespHeaders::H_VARY;
+    HttpRespHeaders::s_gzipHeaders[1].val      = "Accept-Encoding";
+    HttpRespHeaders::s_gzipHeaders[1].valLen   = 15;
+
+
+    HttpRespHeaders::s_brHeaders[0].index    =
         HttpRespHeaders::H_CONTENT_ENCODING;
-    HttpRespHeaders::s_brHeaders.val      = "br";
-    HttpRespHeaders::s_brHeaders.valLen   = 2;
+    HttpRespHeaders::s_brHeaders[0].val      = "br";
+    HttpRespHeaders::s_brHeaders[0].valLen   = 2;
 
-    HttpRespHeaders::s_varyHeaders.index    = HttpRespHeaders::H_VARY;
-    HttpRespHeaders::s_varyHeaders.val      = "Accept-Encoding";
-    HttpRespHeaders::s_varyHeaders.valLen   = 15;
+    HttpRespHeaders::s_brHeaders[1].index    = HttpRespHeaders::H_VARY;
+    HttpRespHeaders::s_brHeaders[1].val      = "Accept-Encoding";
+    HttpRespHeaders::s_brHeaders[1].valLen   = 15;
 
-    HttpRespHeaders::s_keepaliveHeader.index   = HttpRespHeaders::H_CONNECTION;
-    HttpRespHeaders::s_keepaliveHeader.val     = "Keep-Alive";
-    HttpRespHeaders::s_keepaliveHeader.valLen  = 10;
+    HttpRespHeaders::s_keepaliveHeader.index    =
+        HttpRespHeaders::H_CONNECTION;
+    HttpRespHeaders::s_keepaliveHeader.val      = "Keep-Alive";
+    HttpRespHeaders::s_keepaliveHeader.valLen   = 10;
 
     HttpRespHeaders::s_concloseHeader.index    = HttpRespHeaders::H_CONNECTION;
     HttpRespHeaders::s_concloseHeader.val      = "close";
@@ -1056,16 +1074,6 @@ void HttpRespHeaders::hideServerSignature(int hide)
 
 }
 
-void HttpRespHeaders::addTruboCharged()
-{
-    if (s_commonHeadersCount > 1)
-    {
-        addWithUnknownHeader(s_sTurboCharged, 18,
-                             HttpServerVersion::getVersion(),
-                             HttpServerVersion::getVersionLen(),
-                             LSI_HEADEROP_SET);
-    }
-}
 
 void HttpRespHeaders::dropConnectionHeaders()
 {
