@@ -23,22 +23,15 @@
 #include <util/iovec.h>
 #include <ls.h>
 
-// namespace RespHeader {
-//     enum ADD_METHOD {
-//         REPLACE = LSI_ADD_RESPHEADER_REPLACE,
-//         APPEND = LSI_ADD_RESPHEADER_APPEND, //Add with a comma to seperate
-//         MERGE = LSI_ADD_RESPHEADER_MERGE,   //append unless exist
-//         ADD = LSI_ADD_RESPHEADER_ADD,       //add a new line
-//     };
-// };
+// enum LSI_HEADER_OP is in ls.h
 
 typedef struct
 {
-    int         keyOff;
-    int         valOff;
-    short       keyLen;
-    uint16_t    valLen;
-    int32_t     next_index;  //For the multiple line case, this will indicate the next KVPair index, first valid value is 1 since default is 0
+    int     keyOff;
+    int     valOff;
+    short   keyLen;
+    short   valLen;
+    int32_t next_index;  //For the multiple line case, this will indicate the next KVPair index, first valid value is 1 since default is 0
 } resp_kvpair;
 
 
@@ -117,12 +110,15 @@ public:
     ~HttpRespHeaders() {};
 
     void reset();
+    void reset2();
 
     
     int addWithUnknownHeader(const char *pName, int nameLen, const char *pVal,
                              unsigned int valLen, int method);
     int add(INDEX headerIndex, const char *pVal, unsigned int valLen,
             int method = LSI_HEADEROP_SET);
+    int add(INDEX headerIndex, const char *pName, int nameLen,
+            const char *pVal, unsigned int valLen, int method = LSI_HEADEROP_SET);
     int add(const char *pName, int nameLen, const char *pVal,
             unsigned int valLen, int method = LSI_HEADEROP_SET);
 
@@ -174,6 +170,9 @@ public:
     int  getHeader(int pos, char **pName, int *nameLen, struct iovec *iov,
                    int maxIovCount)
     {   return _getHeader(pos, pName, nameLen, iov, maxIovCount); }
+    
+    void prepareFinalize()
+    {   m_isFinalize = 1;    }
 
 public:
 
@@ -183,7 +182,7 @@ public:
     int getTotalLen()       { return m_iHeadersTotalLen; }
     int appendToIov(IOVec *iovec, int &addCrlf);
     int appendToIovExclude(IOVec *iovec, const char *pName, int nameLen) const;
-    void dump(LogSession *pILog, int dump_header) const;
+    void dump(LogSession *pILog, int dump_header);
 
     static INDEX getIndex(const char *pHeader);
     static int getHeaderStringLen(INDEX index)  {    return s_iHeaderLen[(int)index];  }
@@ -191,23 +190,19 @@ public:
     static void buildCommonHeaders();
     static void updateDateHeader();
     static void hideServerSignature(int hide);
-    
 
     void addGzipEncodingHeader()
     {
-        add(&s_gzipHeaders, 1);
-        add(&s_varyHeaders, 1, LSI_HEADEROP_APPEND);
-        updateEtag(1);
+        add(s_gzipHeaders, 2);
+        updateEtag(0);
     }
 
     void addBrotliEncodingHeader()
     {
-        add(&s_brHeaders, 1);
-        add(&s_varyHeaders, 1, LSI_HEADEROP_APPEND);
-        updateEtag(2);
+        add(s_brHeaders, 2);
+        updateEtag(1);
     }
 
-    //compress_type 0: no gzip, 1:gzip, 2: br
     void updateEtag(int compress_type);
 
     void appendChunked()
@@ -220,14 +215,17 @@ public:
         add(&s_acceptRangeHeader, 1);
     }
 
-    void addTruboCharged();
     void addCommonHeaders()
     {   add(s_commonHeaders, s_commonHeadersCount);     }
 
     void dropConnectionHeaders();
 
+    void clearSetCookieIndex()
+    {   m_KVPairindex[H_SET_COOKIE] = 0xff;    }
+
     unsigned char hasPush() const   {   return m_flags & HRH_F_HAS_PUSH;    }
 
+
 public:
     static const char *m_sPresetHeaders[H_HEADER_END];
     static int m_iPresetHeaderLen[H_HEADER_END];
@@ -246,6 +244,7 @@ private:
     short           m_hLastHeaderKVPairIndex;
     int             m_iHeadersTotalLen;
 
+    unsigned char   m_isFinalize;
     char            m_iHttpVersion;
     char            m_iKeepAlive;
 
@@ -263,9 +262,6 @@ private:
     int  _getHeader(int kvOrderNum, char **pName, int *nameLen,
                     struct iovec *iov, int maxIovCount);
 
-    int _add(int kvOrderNum, const char *pName, int nameLen, const char *pVal,
-             unsigned int valLen, int method, INDEX headerIndex);
-
     void            _del(int kvOrderNum);
     void            replaceHeader(resp_kvpair *pKv, const char *pVal,
                                   unsigned int valLen);
@@ -281,9 +277,8 @@ private:
 
     static char s_sDateHeaders[30];
     static http_header_t   s_commonHeaders[2];
-    static http_header_t   s_gzipHeaders;
-    static http_header_t   s_brHeaders;
-    static http_header_t   s_varyHeaders;
+    static http_header_t   s_gzipHeaders[2];
+    static http_header_t   s_brHeaders[2];
     static http_header_t   s_keepaliveHeader;
     static http_header_t   s_chunkedHeader;
     static http_header_t   s_concloseHeader;
