@@ -36,7 +36,7 @@ class HttpServerConfig : public TSingleton<HttpServerConfig>
     int32_t         m_iMaxHeaderBufLen;
     int64_t         m_iMaxReqBodyLen;
     int64_t         m_iMaxDynRespLen;
-    int32_t         m_iMaxDynRespHeaderLen;
+    uint32_t        m_iMaxDynRespHeaderLen;
     int16_t         m_iMaxKeepAliveRequests;
     int8_t          m_iSmartKeepAlive;
     int8_t          m_iAutoLoadHtaccess;
@@ -46,7 +46,6 @@ class HttpServerConfig : public TSingleton<HttpServerConfig>
     int8_t          m_iDynGzipCompress;
     int8_t          m_iCompressLevel;
     int8_t          m_iBrCompress;
-    int8_t          m_iEnableLve;
 
     int32_t         m_iCheckDeniedSymLink;
 
@@ -60,7 +59,6 @@ class HttpServerConfig : public TSingleton<HttpServerConfig>
     int32_t         m_iScriptForbiddenBits;
     int32_t         m_iDirForbiddenBits;
     int32_t         m_iRestartTimeout;
-    int32_t         m_nCpuAffinity;
 
     int             m_iDnsLookup;
     int             m_iUseProxyHeader;
@@ -84,9 +82,6 @@ public:
     void setRestartTimeOut(int32_t timeout) {   m_iRestartTimeout = timeout;}
     int32_t getRestartTimeout() const       {   return m_iRestartTimeout;   }
 
-    void setEnableLve(int32_t v) {   m_iEnableLve = v;}
-    int32_t getEnableLve() const       {   return m_iEnableLve;   }
-
     void setKeepAliveTimeout(int32_t t)     {   m_iKeepAliveTimeout = t;    }
     int32_t getKeepAliveTimeout() const     {   return m_iKeepAliveTimeout; }
 
@@ -134,13 +129,13 @@ public:
     void setMaxHeaderBufLen(int len);
     void setMaxReqBodyLen(int64_t len);
     void setMaxDynRespLen(int64_t len);
-    void setMaxDynRespHeaderLen(int len);
+    void setMaxDynRespHeaderLen(uint32_t len);
 
     int32_t getMaxURLLen() const            {   return m_iMaxURLLen;        }
     int32_t getMaxHeaderBufLen() const      {   return m_iMaxHeaderBufLen;  }
     int64_t getMaxReqBodyLen() const        {   return m_iMaxReqBodyLen;    }
     int64_t getMaxDynRespLen() const        {   return m_iMaxDynRespLen;    }
-    int32_t getMaxDynRespHeaderLen() const
+    uint32_t getMaxDynRespHeaderLen() const
     {   return m_iMaxDynRespHeaderLen;  }
 
     int32_t getMaxFcgiInstances() const     {   return m_iMaxFcgiInstances; }
@@ -195,9 +190,6 @@ public:
 
     int getSpdyKeepaliveTimeout();
 
-    int getCpuAffinity() const              {   return m_nCpuAffinity;      }
-    void setCpuAffinity( int count)         {   m_nCpuAffinity = count;     }
-
 };
 
 #endif
