@@ -34,8 +34,6 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <extensions/registry/extappregistry.h>
-
 
 BEGIN_LOG4CXX_NS
 class Logger;
@@ -87,7 +85,7 @@ class LsiApiHooks;
 class ModUserdir;
 class RewriteMapList;
 class RLimits;
-class SSITagConfig;
+class SsiTagConfig;
 class SslContext;
 class UserDir;
 class XmlNodeList;
@@ -97,13 +95,10 @@ template< class T >
 class THash;
 class StaticFileCacheData;
 
-#define MAX_ACCESS_LOG    4
-
 
 struct php_xml_st
 {
     AutoStr suffix;
-    AutoStr app_name;
     XmlNode *xml_node;
 };
 
@@ -144,7 +139,7 @@ class HttpVHost : public RefCounter, public HttpLogSource
 {
 private:
     ReqStats            m_reqStats;
-    AccessLog          *m_pAccessLog[MAX_ACCESS_LOG];
+    AccessLog          *m_pAccessLog;
     LOG4CXX_NS::Logger *m_pLogger;
     LOG4CXX_NS::Appender *m_pBytesLog;
 
@@ -179,9 +174,8 @@ private:
     AutoStr2            m_sChroot;
     RewriteMapList     *m_pRewriteMaps;
     SslContext         *m_pSSLCtx;
-    SSITagConfig       *m_pSSITagConfig;
+    SsiTagConfig       *m_pSSITagConfig;
     LsiModuleData       m_moduleData;
-    AccessLog          *m_lastAccessLog;
 
     UrlStxFileHash     *m_pUrlStxFileHash;
     php_xml_st          m_pPhpXmlNodeS[MAX_VHOST_PHP_NUM];
@@ -262,8 +256,7 @@ public:
     virtual int  setErrorLogFile(const char *pFileName);
     virtual void setErrorLogRollingSize(off_t size, int keep_days);
 
-    virtual AccessLog *getAccessLog() const
-    {   return m_lastAccessLog ? m_lastAccessLog : m_pAccessLog[0];    }
+    virtual AccessLog *getAccessLog() const  {   return m_pAccessLog;    }
 
     void offsetChroot(const char *pChroot, int len);
 
@@ -336,25 +329,16 @@ public:
         else
             return NULL;
     }
-    int addPhpXmlNodeSSize(char *suffix, char *appName, XmlNode *pNode)
+    int addPhpXmlNodeSSize(char *suffix, XmlNode *pNode)
     {
         if(m_PhpXmlNodeSSize >= MAX_VHOST_PHP_NUM - 1)
             return -1;
         m_pPhpXmlNodeS[m_PhpXmlNodeSSize].suffix.setStr(suffix);
-        m_pPhpXmlNodeS[m_PhpXmlNodeSSize].app_name.setStr(appName);
         m_pPhpXmlNodeS[m_PhpXmlNodeSSize].xml_node = pNode;
         ++m_PhpXmlNodeSSize;
         return 0;
     }
     
-    /**
-     * For the VHost UniqueAppName and UniqueAppUri we do the same way
-     * add ".$uid" to the end of the string
-     */
-    
-    void getUniAppName(const char *app_name, char *dst, int dst_len) const
-    {    ExtAppRegistry::getUniAppUri(app_name, dst, dst_len, getUid()); }
-
     void setUid(uid_t uid)    {   m_uid = uid;    }
     uid_t getUid() const        {   return m_uid;   }
 
@@ -423,10 +407,10 @@ public:
         len = m_sName.len();
         return m_sName.c_str();
     }
-    void setSSITagConfig(SSITagConfig *pConfig)
+    void setSsiTagConfig(SsiTagConfig *pConfig)
     {   m_pSSITagConfig = pConfig;  }
 
-    SSITagConfig *getSSITagConfig() const
+    SsiTagConfig *getSsiTagConfig() const
     {   return m_pSSITagConfig;     }
     void setSslContext(SslContext *pCtx);
 
@@ -477,8 +461,7 @@ public:
                                    const char *appPath,
                                    int maxConns, const char *pRailsEnv,
                                    int maxIdle, const Env *pEnv,
-                                   const char *pBinPath,
-                                   HttpContext *pOldCtx);
+                                   const char *pBinPath);
 
     HttpContext *addRailsContext(const char *pURI, const char *pLocation,
                                         ExtWorker *pWorker,
@@ -537,17 +520,12 @@ public:
 
     int config(const XmlNode *pVhConfNode, int is_uid_set);
     int getExtAppGUid(const XmlNode *pExtAppNode);
-    
+    void getAppName(const char *suffix, char *appName, int maxLen);
     int configVHScriptHandler2();
     int configVHScriptHandler(const XmlNode *pVhConfNode);
     const HttpHandler *isHandlerAllowed(const HttpHandler *pHdlr, int type,
                                         const char *pHandler);
     void configVHChrootMode(const XmlNode *pNode);
-    
-    int configListenerMappings(const char *pListeners,
-                               const char *pDomain,
-                               const char *pAliases);
-
     static HttpVHost *configVHost(const XmlNode *pNode, const char *pName,
                                   const char *pDomain, const char *pAliases, const char *pVhRoot,
                                   const XmlNode *pConfigNode);
