@@ -51,6 +51,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <netinet/tcp.h>
+#include <openssl/ssl.h>
 
 #if !defined(NO_SENDFILE)
 #include <util/gsendfile.h>
@@ -405,7 +406,7 @@ int NtwkIOLink::handleEvents(short evt)
         (*m_pFpList->m_onWrite_fp)(this);
     m_iInProcess = 0;
 
-    switch (getState())
+    switch(getState())
     {
     case HIOS_CLOSING:
         onPeerClose();
@@ -462,19 +463,18 @@ void NtwkIOLink::continueWrite()
     //if( getFlag( HIO_FLAG_WANT_WRITE ) )
     //    return;
     setFlag(HIO_FLAG_WANT_WRITE, 1);
-    ThrottleUnit *pThrottle = getClientInfo()->getThrottleCtrl().getThrottleOut();
-    if (!pThrottle->getAvail())
+    if (allowWrite())
     {
-        if (pThrottle->isUnlimited())
-            pThrottle->reset();
-        else
-        {
-            LS_DBG_L(this, "NtwkIOLink::continueWrite() - THROTTLING!!!");
-            return;
-        }
+        LS_DBG_L(this, "Write resumed!");
+        /*        short revents = getRevents();
+                if ( revents & POLLOUT )
+                    handleEvents( revents );
+                else*/
+        MultiplexerFactory::getMultiplexer()->continueWrite(this);
     }
-    LS_DBG_L(this, "write resumed!");
-    MultiplexerFactory::getMultiplexer()->continueWrite(this);
+    else
+        LS_DBG_L(this, "Throttled!");
+
 }
 
 
@@ -603,6 +603,7 @@ int NtwkIOLink::writevExSSL(LsiSession *pOS, const iovec *vector,
         }
         else if (!written)
         {
+            // lslb uses commented out version.
             if (pThis->m_ssl.wantRead())
                 MultiplexerFactory::getMultiplexer()->continueRead(pThis);
             //pThis->setSSLAgain();
@@ -1005,7 +1006,7 @@ off_t NtwkIOLink::sendfileSetUp(off_t size)
     }
     ThrottleControl *pCtrl = getThrottleCtrl();
 
-    if (pCtrl && !pCtrl->getThrottleOut()->isUnlimited())
+    if (pCtrl)
     {
         int Quota = pCtrl->getOSQuota();
         if (size > (unsigned int)Quota + (Quota >> 3))
@@ -1528,15 +1529,12 @@ int NtwkIOLink::get_url_from_reqheader(char *buf, int length, char **puri,
     return 0;
 }
 
-
 void NtwkIOLink::handle_acceptSSL_EIO_Err()
 {
     //The buf is null terminated string
     char buf[8192 + 1] = {0};
     unsigned int length = 0;
-    char *p = NULL;
-
-    p = m_ssl.getRawBuffer((int *)&length);
+    char *p = m_ssl.getRawBuffer((int *)&length);
 
     if (p)
     {
@@ -1821,10 +1819,9 @@ void NtwkIOLink::resumeEventNotify()
 static const char *s_pProtoString[] = { "", ":SPDY2", ":SPDY3", ":SPDY31", ":HTTP2" };
 const char *NtwkIOLink::buildLogId()
 {
-    m_logId.len = ls_snprintf(m_logId.ptr, MAX_LOGID_LEN, "%s:%u%s",
-                              getClientInfo()->getAddrString(),
-                              getConnInfo()->m_remotePort,
-                              s_pProtoString[(int)getProtocol() ]);
+    m_logId.len = ls_snprintf(m_logId.ptr, MAX_LOGID_LEN, "%s:%hu%s",
+                      getClientInfo()->getAddrString(), getRemotePort(),
+                      s_pProtoString[(int)getProtocol() ]);
     return m_logId.ptr;
 }
 
