@@ -157,10 +157,12 @@ private:
     int doWrite()
     {
         if (isWantWrite())
+        {
             if (getHandler())
                 return getHandler()->onWriteEx();
             else
                 return 0;
+        }
         else
         {
             suspendWrite();
@@ -234,6 +236,14 @@ public:
     static int getToken()
     {   return s_iTmToken;        }
 
+    void setRemotePort(unsigned short port)
+    {
+        m_iRemotePort = port;
+        clearLogId();
+    };
+
+    unsigned short getRemotePort() const  {   return m_iRemotePort;       };
+
     int sendRespHeaders(HttpRespHeaders *pHeaders, int isNoBody);
 
     const char *buildLogId();
