@@ -313,7 +313,7 @@ int ReqParser::initMutlipart(const char *pContentType, int len)
     }
     m_last_char = 0;
     m_multipartBuf.clear();
-    const char *p = (const char *)memmem(pContentType, len, "boundary=", 9);
+    const char *p = strstr(pContentType, "boundary=");
     if (p && *(p + 9))
     {
         len = len - ((p + 9) - pContentType);
@@ -424,7 +424,7 @@ int ReqParser::multipartParseHeader(char *pBegin, char *pLineEnd)
                     fileStrType = 1;
 
                     ret = appendArgKey(pName, nameLen);
-                    if (ret == 0)
+                    if (ret == 0 && m_pFileUploadConfig)
                     {
                         m_decodeBuf.append(fileStr, fileStrLen);
                         fileStrLen = normalisePath(m_pArgs[m_args - 1].valueOffset, fileStrLen);
