@@ -37,6 +37,7 @@
 #include <util/datetime.h>
 #include <util/httputil.h>
 #include <util/stringtool.h>
+#include <http/mtsessdata.h>
 
 #include <ctype.h>
 #include <grp.h>
@@ -578,15 +579,63 @@ int RequestVars::getReqVar(HttpSession *pSession, int type, char *&pValue,
                     return snprintf(pValue, bufLen, "%o", st.st_mode);
                 else if (type == REF_SCRIPT_USERNAME)
                 {
-                    struct passwd *pw = getpwuid(st.st_uid);
-                    if (pw)
-                        return snprintf(pValue, bufLen, "%s", pw->pw_name);
+                    struct passwd pw;
+                    char *buffer;
+                    struct passwd *ppw;
+                    ssize_t bufsize;
+                    int    retry;
+                    bufsize = sysconf(_SC_GETPW_R_SIZE_MAX);
+                    if (bufsize == -1)          /* Value was indeterminate */
+                        bufsize = 16384;        /* Should be more than enough */
+                    do {
+                        retry = 0;
+                        buffer = (char *)malloc(bufsize);
+                        if (buffer != NULL) {                    
+                            errno = 0;
+                            if ((getpwuid_r(st.st_uid, &pw, buffer, bufsize, &ppw) == -1) &&
+                                (errno == ERANGE)) {
+                                bufsize *= 2;
+                                retry = 1;
+                            }
+                            else if (ppw) {
+                                int ret_len;
+                                ret_len = snprintf(pValue, bufLen, "%s", pw.pw_name);
+                                free(buffer);
+                                return ret_len;
+                            }
+                            free(buffer);
+                        }
+                    } while (retry);
                 }
                 else
                 {
-                    struct group *gr = getgrgid(st.st_gid);
-                    if (gr)
-                        return snprintf(pValue, bufLen, "%s", gr->gr_name);
+                    struct group gr;
+                    char *buffer;        
+                    struct group *pgr;
+                    ssize_t bufsize;
+                    int retry = 0;
+                    bufsize = sysconf(_SC_GETGR_R_SIZE_MAX);
+                    if (bufsize == -1)
+                        bufsize = 16384;
+                    do {
+                        retry = 0;
+                        buffer = (char *)malloc(bufsize);
+                        if (buffer != NULL) {
+                            errno = 0;
+                            if ((getgrgid_r(st.st_gid, &gr, buffer, sizeof(buffer), &pgr) == -1) &&
+                                (errno == ERANGE)) {
+                                bufsize *= 2;
+                                retry = 1;
+                            }
+                            else if (pgr) {
+                                int ret_len;
+                                ret_len = snprintf(pValue, bufLen, "%s", gr.gr_name);
+                                free(buffer);
+                                return ret_len;
+                            }
+                            free(buffer);
+                        }
+                    } while (retry);
                 }
             }
             return 0;
@@ -611,15 +660,11 @@ int RequestVars::getReqVar(HttpSession *pSession, int type, char *&pValue,
             p += 7;
         }
         i = pReq->getHeaderLen(HttpHeader::H_HOST);
-        if (i > pValue + bufLen - p)
-            i = pValue + bufLen - p;
         memmove(p, pReq->getHeader(HttpHeader::H_HOST),
                 i);
         p += i;
 
         i = pReq->getOrgURILen();
-        if (i > pValue + bufLen - p)
-            i = pValue + bufLen - p;
         memmove(p, pReq->getOrgURI(), i);
         p += i;
         return p - pValue;
@@ -731,18 +776,19 @@ int RequestVars::getReqVar(HttpSession *pSession, int type, char *&pValue,
     case REF_LAST_MODIFIED:
         {
             time_t mtime = DateTime::s_curTime;
-            struct tm *tm;
+            struct tm tstm;
+            struct tm *tm = &tstm;
             if (type == REF_LAST_MODIFIED)
             {
-                if (pReq->getSSIRuntime() && pReq->getSSIRuntime()->getCurrentScript())
-                    mtime = pReq->getSSIRuntime()->getCurrentScript()->getLastMod();
+                if (pSession->getSsiStack() && pSession->getSsiStack()->getScript())
+                    mtime = pSession->getSsiStack()->getScript()->getLastMod();
                 else
                     mtime = pReq->getFileStat().st_mtime;
             }
             if (type == REF_DATE_GMT)
-                tm = gmtime(&mtime);
+                gmtime_r(&mtime,tm);
             else
-                tm = localtime(&mtime);
+                localtime_r(&mtime,tm);
             char fmt[101];
             memccpy(fmt, pValue, 0, 100);
             fmt[100] = 0;
@@ -796,7 +842,9 @@ int RequestVars::getReqVar(HttpSession *pSession, int type, char *&pValue,
         if (type >= REF_TIME)
         {
             time_t t = time(NULL);
-            struct tm *tm = localtime(&t);
+            struct tm tstm;
+            struct tm *tm = &tstm;
+            localtime_r(&t,tm);
             switch (type)
             {
             case REF_TIME:
@@ -937,11 +985,17 @@ const char *RequestVars::getEnv(HttpSession *pSession, const char *pKey,
         }
     }
 #endif
-    return pSession->getReq()->getEnv(pKey, keyLen, valLen);
+    MtSessData * p = pSession->getMtSessData();
+    if (p)
+        ls_mutex_lock(&p->m_respHeaderLock);
+    const char * ret = pSession->getReq()->getEnv(pKey, keyLen, valLen);
+    if (p)
+        ls_mutex_unlock(&p->m_respHeaderLock);
+    return ret;
 }
 
 
-int RequestVars::getCookieCount(HttpReq *pReq)
+int RequestVars::getCookieCount(const HttpReq *pReq)
 {
     const char *pCookie = pReq->getHeader(HttpHeader::H_COOKIE);
     if (!*pCookie)
@@ -1085,6 +1139,10 @@ int RequestVars::getSubstValue(const SubstItem *pItem,
         pValue = (char *)pItem->getStr()->c_str();
         return pItem->getStr()->len();
 
+    case REF_SSI_VAR:
+        while (pSession->getParent())
+            pSession = pSession->getParent();
+    //fall through
     case REF_ENV:
         pValue = (char *)RequestVars::getEnv(pSession, pItem->getStr()->c_str(),
                                              pItem->getStr()->len(), i);
@@ -1192,6 +1250,7 @@ int RequestVars::setEnv(HttpSession *pSession, const char *pName,
                         int nameLen,
                         const char *pValue, int valLen)
 {
+    MtSessData * p = pSession->getMtSessData();
     if (*pName == '!')
     {
         ++pName;
@@ -1202,7 +1261,11 @@ int RequestVars::setEnv(HttpSession *pSession, const char *pName,
             pSession->getReq()->andGzip(~GZIP_OFF);
             return 0;
         }
+        if (p)
+            ls_mutex_lock(&p->m_respHeaderLock);
         pSession->getReq()->unsetEnv(pName, nameLen);
+        if (p)
+            ls_mutex_unlock(&p->m_respHeaderLock);
         LS_DBG_M(pSession->getLogSession(), "Remove ENV: '%s' ", pName);
         return 0;
     }
@@ -1245,9 +1308,20 @@ int RequestVars::setEnv(HttpSession *pSession, const char *pName,
                 pSession->getReq()->andGzip(~GZIP_OFF);
             return 0;
         }
+        else if (strcasecmp(pName, "noabort") == 0)
+        {
+            LS_DBG_M(pSession->getLogSession(),
+                     "do not abort external app for this requst.");
+            pSession->setFlag(HSF_NO_ABORT);
+
+        }
     }
 
+    if (p)
+        ls_mutex_lock(&p->m_respHeaderLock);
     pSession->addEnv(pName, nameLen, pValue, valLen);
+    if (p)
+        ls_mutex_unlock(&p->m_respHeaderLock);
 
     LS_DBG_M(pSession->getLogSession(), "Add ENV: '%s:%.*s' ", pName, valLen, pValue);
     return 0;
