@@ -22,6 +22,7 @@
 #include <http/httpcontext.h>
 #include <http/httpresourcemanager.h>
 #include <http/httpsession.h>
+#include <http/mtsessdata.h>
 #include <http/httpstatuscode.h>
 #include <http/requestvars.h>
 #include <http/rewritemap.h>
@@ -80,13 +81,13 @@ int RewriteEngine::loadRewriteFile(char *path, RewriteRuleList *pRuleList,
     int fd = open(path, O_RDONLY);
     if (fd == -1)
     {
-        LS_INFO("Rewrite file [%s] can not open.", path);
+        LS_ERROR("Rewrite file [%s] can not open.", path);
         return LS_FAIL;
     }
 
     struct stat sb;
     if (fstat(fd, &sb) == -1) {
-        LS_INFO("Rewrite file [%s] cannot be open.", path);
+        LS_ERROR("Rewrite file [%s] cannot be open.", path);
         return LS_FAIL;
     }
 
@@ -179,12 +180,7 @@ int RewriteEngine::parseRules(char *&pRules, RewriteRuleList *pRuleList,
                 while (isspace(*pRules))
                     ++pRules;
                 
-                int len = 0;
-                if (pLineEnd)
-                    len = pLineEnd - pRules;
-                else
-                    len = strlen(pRules);
-
+                int len = pLineEnd - pRules;
                 if (len >= 2 && strncasecmp(pRules, "on", 2) == 0)
                 {
                     pContext->enableRewrite(1);
@@ -200,7 +196,7 @@ int RewriteEngine::parseRules(char *&pRules, RewriteRuleList *pRuleList,
                      strncasecmp(pRules, "</IfModule>", 11) == 0)
                 LS_INFO("Rewrite directive: %s bypassed.", pRules);
             else if (*pRules != '#')
-                LS_INFO("Invalid rewrite directive: %s", pRules);
+                LS_ERROR("Invalid rewrite directive: %s", pRules);
 
             if (pLineEnd)
                 *pLineEnd = '\n';
@@ -607,7 +603,7 @@ int RewriteEngine::processCond(const RewriteCond *pCond,
     else if ((code >= COND_OP_DIR) && (code <= COND_OP_FILE_ACC))
     {
         if (m_noStat == 1)
-            m_noStat = ls_fio_stat(pTest, &m_st);
+            m_noStat = pSession->getReq()->fileStat(pTest, &m_st);
         if (m_noStat == 0)
         {
             switch (code)
@@ -862,9 +858,16 @@ int RewriteEngine::setCookie(char *pBuf, int len, HttpSession *pSession)
                     || (strncasecmp("HttpOnly", p, 8) == 0));
     }
     pSession->getReq()->setCookie(pName, strlen(pName), pVal, strlen(pVal));
-    return pSession->getResp()->addCookie(pName, pVal, pPath, pDomain, age,
-                                          secure, httponly);
+    MtSessData * psd = pSession->getMtSessData();
+    if (psd)
+        ls_mutex_lock(&psd->m_respHeaderLock);
 
+    int ret = pSession->getResp()->addCookie(pName, pVal, pPath, pDomain, age,
+                                          secure, httponly);
+    if (psd)
+        ls_mutex_unlock(&psd->m_respHeaderLock);
+
+    return ret;
 }
 
 
@@ -1179,6 +1182,8 @@ int RewriteEngine::processRuleSet(const RewriteRuleList *pRuleList,
 //            ret = -1;
 //        else
         ret = processRule(pRule, pSession, cacheCtlStr);
+        if (pSession->isDropConnection())
+            return SC_403;
         if (ret)
         {
             pRule = getNextRule(pRule, pContext, pRootContext);
