@@ -319,8 +319,7 @@ int StaticFileCacheData::testMod(HttpReq *pReq)
         if (pReq->isHeaderSet(HttpHeader::H_IF_MODIFIED_SINCE))
         {
             pNonMatch = pReq->getHeader(HttpHeader::H_IF_MODIFIED_SINCE);
-            long IMS = DateTime::parseHttpTime(pNonMatch,
-                pReq->getHeaderLen(HttpHeader::H_IF_MODIFIED_SINCE));
+            long IMS = DateTime::parseHttpTime(pNonMatch);
             if (IMS >= m_fileData.getLastMod())
                 return SC_304;
         }
@@ -342,7 +341,7 @@ int StaticFileCacheData::testIfRange(const char *pMatch, int len)
     }
     else
     {
-        long IUMS = DateTime::parseHttpTime(pMatch, len);
+        long IUMS = DateTime::parseHttpTime(pMatch);
         if (IUMS < m_fileData.getLastMod())
             return SC_412;
     }
@@ -372,8 +371,7 @@ int StaticFileCacheData::testUnMod(HttpReq *pReq)
     if (pReq->isHeaderSet(HttpHeader::H_IF_UNMOD_SINCE))
     {
         pMatch = pReq->getHeader(HttpHeader::H_IF_UNMOD_SINCE);
-        long IMS = DateTime::parseHttpTime(pMatch,
-            pReq->getHeaderLen(HttpHeader::H_IF_UNMOD_SINCE));
+        long IMS = DateTime::parseHttpTime(pMatch);
         if (IMS < m_fileData.getLastMod())
             return SC_412;
     }
@@ -540,7 +538,7 @@ int StaticFileCacheData::tryCreateCompressed(char useBrotli)
     off_t size = m_fileData.getFileSize();
     if ((size > s_iMaxFileSize) || (size < s_iMinFileSize))
     {
-        LS_DBG_H("Cannot compress file %s, file size %ld!",
+        LS_DBG_H("Cannot compress file %s, file size %d!",
                     m_real.c_str(), size);
         return LS_FAIL;
     }
@@ -559,7 +557,7 @@ int StaticFileCacheData::tryCreateCompressed(char useBrotli)
 
         long ret = compressFile(useBrotli);
         if (ret == -1)
-            LS_WARN("Failed to compress file %s, file size %ld!",
+            LS_WARN("Failed to compress file %s, file size %d!",
                     m_real.c_str(), size);
         
         *p = 'l';
@@ -584,7 +582,7 @@ int StaticFileCacheData::tryCreateCompressed(char useBrotli)
 
         long ret = compressFile(useBrotli);
         if (ret == -1)
-            LS_WARN("Failed to compress file %s, file size %ld!",
+            LS_WARN("Failed to compress file %s, file size %d!",
                     m_real.c_str(), size);
 
         *p = 'l';
@@ -832,7 +830,7 @@ int StaticFileCacheData::readyCompressed(char compressMode)
 
     if (tm == m_tmLastCheck)
         return setReadiedCompressData(compressMode);
-    
+
     int statBr = -1, retGz = -1, statGz = -1;
     struct stat stGzip;
     struct stat stBr;
@@ -868,7 +866,7 @@ int StaticFileCacheData::readyCompressed(char compressMode)
         {
             // use br
         }
-        else if (!(compressMode & SFCD_MODE_GZIP) || retGz)
+        if (!(compressMode & SFCD_MODE_GZIP) || retGz)
         {
             // update br
             if ((statBr = compressHelper(m_bredPath, m_pBrotli, stBr, statBr, 1)))
