@@ -374,6 +374,7 @@ int processH264Stream(HttpSession *pSession, double start)
 
 
 
+#define RANGES_TOO_BIG_RET          100000
 static int processRange(HttpSession *pSession, HttpReq *pReq,
                         const char *pRange);
 
@@ -391,7 +392,7 @@ int StaticFileHandler::process(HttpSession *pSession,
     struct stat &st = pReq->getFileStat();
     int code = pReq->getStatusCode();
 
-    int isSSI = (pReq->getSSIRuntime() != NULL);
+    int isSSI = (pSession->getSsiRuntime() != NULL);
 
 //     if (pReq->getMethod() >= HttpMethod::HTTP_POST)
 //         return SC_405;
@@ -482,7 +483,13 @@ int StaticFileHandler::process(HttpSession *pSession,
                 }
             }
         }
-        if (pReq->isHeaderSet(HttpHeader::H_RANGE))
+        if (pCache->testMod(pReq))
+        {
+            pReq->setStatusCode(SC_304);
+            pReq->setNoRespBody();
+            code = SC_304;
+        }
+        else if (pReq->isHeaderSet(HttpHeader::H_RANGE))
         {
             const char *pRange = pReq->getHeader(HttpHeader::H_RANGE);
             if (pReq->isHeaderSet(HttpHeader::H_IF_RANGE))
@@ -499,16 +506,9 @@ int StaticFileHandler::process(HttpSession *pSession,
             }
             if (!ret && pInfo->getFileData()->getFileSize() > 0)
             {
-                return processRange(pSession, pReq, pRange);
-            }
-        }
-        else
-        {
-            if (pCache->testMod(pReq))
-            {
-                pReq->setStatusCode(SC_304);
-                pReq->setNoRespBody();
-                code = SC_304;
+                int ret = processRange(pSession, pReq, pRange);
+                if (ret != RANGES_TOO_BIG_RET)
+                    return ret;
             }
         }
     }
@@ -792,10 +792,10 @@ static int processRange(HttpSession *pSession, HttpReq *pReq,
     }
     else
     {
-        pReq->setStatusCode(SC_206);
-        if (pReq->getRange())
-            delete pReq->getRange();
-        pReq->setRange(range);
+        //range too big, return whole content
+        if (range->isRangesTooBig())
+            return RANGES_TOO_BIG_RET; //a big unused return valus
+            
         ret = pData->readyCacheData(0);
         if (!ret)
         {
