@@ -28,6 +28,7 @@
 #include <log4cxx/logger.h>
 #include <log4cxx/logrotate.h>
 #include <lsiapi/lsiapihooks.h>
+#include <lsiapi/modulehandler.h>
 #include <lsr/ls_time.h>
 #include <lsr/ls_fileio.h>
 #include <lsr/ls_strtool.h>
@@ -37,7 +38,6 @@
 #include <main/mainserverconfig.h>
 #include <main/plainconf.h>
 #include <main/serverinfo.h>
-#include <shm/lsshmpool.h>
 #include <socket/coresocket.h>
 #include <util/datetime.h>
 #include <util/daemonize.h>
@@ -47,9 +47,6 @@
 #include <util/stringlist.h>
 #include <util/signalutil.h>
 #include <util/vmembuf.h>
-#include <util/httpfetch.h>
-#include <socket/gsockaddr.h>
-
 #include <sys/sysctl.h>
 
 #include <extensions/cgi/cgidworker.h>
@@ -74,11 +71,6 @@
 #include <unistd.h>
 #include <config.h>
 
-/***
- * Do not change the below format, it will be set correctly while packing the code
- */
-#define BUILDTIME  " (built: Tue Jul  9 16:51:28 UTC 2019)"
-
 #define GlobalServerSessionHooks (LsiApiHooks::getServerSessionHooks())
 
 static char s_iRunning = 0;
@@ -90,13 +82,12 @@ LshttpdMain::LshttpdMain()
     , m_pBuilder(NULL)
     , m_noDaemon(0)
     , m_noCrashGuard(0)
-    , m_iConfTestMode(0)
     , m_pProcState(NULL)
     , m_curChildren(0)
     , m_fdAdmin(-1)
 {
     m_pServer = &HttpServer::getInstance();
-    
+
 #ifndef IS_LSCPD
     m_pBuilder = new HttpConfigLoader();
 #endif
@@ -163,30 +154,9 @@ int LshttpdMain::childSignaled(pid_t pid, int signal, int coredump)
     LS_NOTICE("[AutoRestarter] child process with pid=%d received signal=%d, %s!",
               (int)pid, signal, pCoreFile[ coredump != 0 ]);
     //cleanUp();
-    
 
-#if 1
-//#ifdef LS_ENABLE_DEBUG
-    LS_NOTICE("[*****] Debug version running, will create core file.");
     //We are in middle of graceful shutdown, do not restart another copy
     SendCrashNotification(pid, signal, coredump, pCoreFile[coredump != 0]);
-#else
-    
-    //Since it is not DEBUG version, I will download the DEBUG version to run.
-    const char *pVer = PACKAGE_VERSION;
-    AutoStr2 sCmd;
-    sCmd.setStr(MainServerConfig::getInstance().getServerRoot());
-    sCmd.append("/admin/misc/testbeta.sh -d ", 27);
-    sCmd.append(pVer, strlen(pVer));
-    
-    LS_NOTICE("[*****] non-debug version running, run cmd \"%s\".",
-              sCmd.c_str());
-    
-    if (fork() == 0)  // run it in child process
-        ::system(sCmd.c_str());
-    
-#endif    
-    
     if (coredump)
     {
 
@@ -573,7 +543,7 @@ int LshttpdMain::getServerRootFromExecutablePath(const char *command,
         left_len -= strlen(achBuf);
     }
     
-    if (left_len >= (int)strlen(command))
+    if (left_len >= strlen(command))
         strcat(achBuf, command);
     else
     {
@@ -661,10 +631,6 @@ int LshttpdMain::config()
         m_pBuilder->releaseConfigXmlTree();
     if (ret != 0)
         return 1;
-    
-    if (m_iConfTestMode)
-        return 0;
-    
     if (m_pServer->isServerOk())
         return 2;
 //    if ( ServerProcessConfig::getInstance.getChroot != NULL )
@@ -709,7 +675,7 @@ const char *LshttpdMain::getPidFile()
     const char *pidFile = getenv("OLS_PID_FILE");
     if (!pidFile)
         pidFile = PID_FILE;
-    
+
     return pidFile;
 }
 
@@ -734,7 +700,7 @@ int LshttpdMain::testRunningServer()
             }
             else
             {
-                fprintf(stderr, "[ERROR] Failed to write to pid file:%s!\n", 
+                fprintf(stderr, "[ERROR] Failed to write to pid file:%s!\n",
                     getPidFile());
                 return ret;
             }
@@ -749,20 +715,13 @@ int LshttpdMain::testRunningServer()
 
 void LshttpdMain::printVersion()
 {
-    printf("%s%s%s\n\tmodule versions:\n%s\n",
-           HttpServerVersion::getVersion(), BUILDTIME, 
-           
-#ifdef LS_ENABLE_DEBUG
-           " (DEBUG)",
-#else
-           " ",
-#endif
-           LS_MODULE_VERSION_INFO);
+    printf("%s\n\tmodule versions:\n%s\n",
+           HttpServerVersion::getVersion(), LS_MODULE_VERSION_INFO);
 }
 
 void LshttpdMain::parseOpt(int argc, char *argv[])
 {
-    const char *opts = "cdntv";
+    const char *opts = "cdnv";
     int c;
     char achCwd[512];
     getServerRootFromExecutablePath(argv[0], achCwd, 512);
@@ -781,11 +740,6 @@ void LshttpdMain::parseOpt(int argc, char *argv[])
         case 'n':
             m_noDaemon = 1;
             break;
-        case 't':
-            m_noDaemon = 1;
-            m_noCrashGuard = 1;
-            m_iConfTestMode = 1;
-            break;
         case 'v':
             printVersion();
             exit(0);
@@ -852,7 +806,6 @@ int LshttpdMain::init(int argc, char *argv[])
     ServerProcessConfig &procConfig = ServerProcessConfig::getInstance();
     if (argc > 1)
         parseOpt(argc, argv);
-
     if (getServerRoot(argc, argv) != 0)
     {
         //LS_ERROR("Failed to determine the root directory of server!" ));
@@ -861,22 +814,15 @@ int LshttpdMain::init(int argc, char *argv[])
         return 1;
     }
 
+    mkdir(DEFAULT_TMP_DIR,  0755);
 
-    if (!m_iConfTestMode)
-    {
-        mkdir(DEFAULT_TMP_DIR,  0755);
+    if (testRunningServer() != 0)
+        return 2;
 
-        if (testRunningServer() != 0)
-            return 2;
-    }
-    else
-        MainServerConfig::getInstance().setConfTestMode(1);
-    
 #ifndef IS_LSCPD
 
     //load the config
     m_pBuilder->loadConfigFile();
-
 //    m_pBuilder->loadPlainConfigFile();
     if (m_pServer->configServerBasics(0, m_pBuilder->getRoot()))
         return 1;
@@ -885,7 +831,7 @@ int LshttpdMain::init(int argc, char *argv[])
     if (m_pServer->initLscpd())
         return 1;
 #endif
-    
+
     if (!MainServerConfig::getInstance().getDisableLogRotateAtStartup())
         LOG4CXX_NS::LogRotate::roll(HttpLog::getErrorLogger()->getAppender(),
                                     procConfig.getUid(),
@@ -909,11 +855,9 @@ int LshttpdMain::init(int argc, char *argv[])
     plainconf::flushErrorLog();
 #endif
 
-  
-    LS_NOTICE("Loading %s%s ...", HttpServerVersion::getVersion(), BUILDTIME);
+    LS_NOTICE("Loading %s ...", HttpServerVersion::getVersion());
     LS_NOTICE("Using [%s]", SSLeay_version(SSLEAY_VERSION));
 
-
     if (!m_noDaemon)
     {
         if (Daemonize::daemonize(1, 1))
@@ -924,37 +868,29 @@ int LshttpdMain::init(int argc, char *argv[])
 #endif
     }
 
-    if (!m_iConfTestMode)
-    {
-        enableCoreDump();
-
-        if (testRunningServer() != 0)
-            return 2;
-        m_pid = getpid();
-        if (m_pidFile.writePid(m_pid))
-            return 2;
+    enableCoreDump();
 
 
-        if (!MainServerConfig::getInstance().getDisableWebAdmin())
-            startAdminSocket();
-    }
-        
+    if (testRunningServer() != 0)
+        return 2;
+    m_pid = getpid();
+    if (m_pidFile.writePid(m_pid))
+        return 2;
+
+
+    if (!MainServerConfig::getInstance().getDisableWebAdmin())
+        startAdminSocket();
+
 #ifndef IS_LSCPD
     ret = config();
-    if (ret && !m_iConfTestMode)
+    if (ret)
     {
         LS_ERROR("Fatal error in configuration, exit!");
         fprintf(stderr, "[ERROR] Fatal error in configuration, shutdown!\n");
         return ret;
     }
-
 #endif
 
-    if (m_iConfTestMode)
-    {
-        return 0;
-    }
-
     removeOldRtreport();
     {
         char achBuf[8192];
@@ -996,6 +932,9 @@ int LshttpdMain::init(int argc, char *argv[])
         allocatePidTracker();
         m_pServer->initAdns();
         m_pServer->enableAioLogging();
+        cleanEnvVars();
+        WorkCrew * pGWC = ModuleHandler::getGlobalWorkCrew();
+        pGWC->startProcessing();
         if ((HttpServerConfig::getInstance().getUseSendfile() == 2)
             && (m_pServer->initAioSendFile() != 0))
             return LS_FAIL;
@@ -1046,47 +985,12 @@ int LshttpdMain::main(int argc, char *argv[])
         if (ret != 0)
             return ret;
 
-        if (!m_iConfTestMode)
-        {
-            m_pServer->start();
+        m_pServer->start();
 
-            //If HttpServerConfig::s_iProcNo is 0, is main process
-            if (GlobalServerSessionHooks->isEnabled(LSI_HKPT_WORKER_ATEXIT))
-                GlobalServerSessionHooks->runCallbackNoParam(LSI_HKPT_WORKER_ATEXIT, NULL);
-        }
+        //If HttpServerConfig::s_iProcNo is 0, is main process
+        if (GlobalServerSessionHooks->isEnabled(LSI_HKPT_WORKER_ATEXIT))
+            GlobalServerSessionHooks->runCallbackNoParam(LSI_HKPT_WORKER_ATEXIT, NULL);
         m_pServer->releaseAll();
-        
-        if (m_iConfTestMode)
-        {
-            int ret = 0;
-            int fd = ::open(TEST_CONF_LOG, O_RDONLY);
-            if (fd != -1)
-            {
-                struct stat st;
-                if (fstat(fd, &st) == 0 && st.st_size > 0)
-                {
-                    ret = 1;
-                    unsigned char *buff  = (unsigned char *)mmap((caddr_t)0,
-                                                                 st.st_size,
-                                                                 PROT_READ,
-                                                                 MAP_SHARED,
-                                                                 fd,
-                                                                 0);
-                    if (buff != (unsigned char *)(-1))
-                    {
-                        printf("%.*s", (int)st.st_size, buff);
-                        
-                        if (strstr((const char *)buff, "[ERROR]") != NULL)
-                            ret = 2;
-                    }
-                    munmap((caddr_t)buff, st.st_size);
-                }
-                
-                close(fd);
-                unlink(TEST_CONF_LOG);
-            }
-            return ret;
-        }
     }
     return 0;
 }
@@ -1183,49 +1087,6 @@ void LshttpdMain::setChildSlot(int num, int val)
 }
 
 
-#ifdef _PROFILE_
-#include <sys/gmon.h>
-#endif
-void LshttpdMain::onNewChildStart(ChildProc * pProc)
-{
-#ifdef _PROFILE_
-    extern char __executable_start;
-    extern char __etext;
-    monstartup ((u_long) &__executable_start, (u_long) &__etext);
-#endif
-
-    int cpu_count = HttpServerConfig::getInstance().getCpuAffinity();
-    if (cpu_count > 0)
-    {
-        cpu_set_t       cpu_affinity;
-
-        PCUtil::getAffinityMask(s_iCpuCount, pProc->m_iProcNo - 1, cpu_count,
-                                &cpu_affinity);
-        PCUtil::setCpuAffinity(&cpu_affinity);
-    }
-    setpgid(0, 0);
-    m_pServer->setBlackBoard(pProc->m_pBlackBoard);
-    m_pServer->setProcNo(pProc->m_iProcNo);
-    //setAffinity( 0, pProc->m_iProcNo);  //TEST: need uncomment and debug
-    releaseExcept(pProc);
-    m_pServer->reinitMultiplexer();
-    m_pServer->enableAioLogging();
-    if ((HttpServerConfig::getInstance().getUseSendfile() == 2)
-        && (m_pServer->initAioSendFile() != 0))
-    {
-        HttpServerConfig::getInstance().setUseSendfile(1);
-    }
-    close(m_fdAdmin);
-
-#ifdef IS_LSCPD
-    snprintf(argv0, 80, "lscpd (lscpd - #%02d)", pProc->m_iProcNo);
-#else
-    snprintf(argv0, 80, "openlitespeed (lshttpd - #%02d)", pProc->m_iProcNo);
-#endif
-
-    LsShmPool::setPid(pProc->m_pid);
-}
-
 int LshttpdMain::startChild(ChildProc *pProc)
 {
     if (!pProc->m_pBlackBoard)
@@ -1247,8 +1108,32 @@ int LshttpdMain::startChild(ChildProc *pProc)
     if (pProc->m_pid == 0)
     {
         //child process
-        pProc->m_pid = getpid();
-        onNewChildStart(pProc);
+        cpu_set_t       cpu_affinity;
+
+        cleanEnvVars();
+
+        PCUtil::getAffinityMask(s_iCpuCount, pProc->m_iProcNo - 1, 1,
+                                &cpu_affinity);
+        PCUtil::setCpuAffinity(&cpu_affinity);
+        m_pServer->setBlackBoard(pProc->m_pBlackBoard);
+        m_pServer->setProcNo(pProc->m_iProcNo);
+        //setAffinity( 0, pProc->m_iProcNo);  //TEST: need uncomment and debug
+        releaseExcept(pProc);
+        m_pServer->reinitMultiplexer();
+        m_pServer->enableAioLogging();
+        WorkCrew * pGWC = ModuleHandler::getGlobalWorkCrew();
+        pGWC->startProcessing();
+        if ((HttpServerConfig::getInstance().getUseSendfile() == 2)
+            && (m_pServer->initAioSendFile() != 0))
+            return LS_FAIL;
+        close(m_fdAdmin);
+
+#ifdef IS_LSCPD
+        snprintf(argv0, 80, "lscpd (lscpd - #%02d)", pProc->m_iProcNo);
+#else
+        snprintf(argv0, 80, "openlitespeed (lshttpd - #%02d)", pProc->m_iProcNo);
+#endif
+
         return 0;
     }
 
@@ -1415,16 +1300,19 @@ void LshttpdMain::broadcastSig(int sig, int changeState)
 }
 
 
-void LshttpdMain::stopAllChildren()
+void LshttpdMain::stopAllChildren(int nowait)
 {
     ChildProc *pProc;
     broadcastSig(SIGTERM, 0);
 
     long tmBeginWait = time(NULL);
-    long tmEndWait = tmBeginWait + 300 +
-                     HttpServerConfig::getInstance().getRestartTimeout();
-
-    while ((s_iRunning != -1) && (m_childrenList.size() > 0) &&
+    long tmEndWait;
+    if (nowait)
+        tmEndWait = tmBeginWait + 10;
+    else
+        tmEndWait = tmBeginWait + 300 +
+                    HttpServerConfig::getInstance().getRestartTimeout();
+    while ((m_childrenList.size() > 0) &&
            (time(NULL) < tmEndWait))
     {
         sleep(1);
@@ -1511,7 +1399,7 @@ int LshttpdMain::guardCrash()
     }
     else
         m_fdAdmin = -1;
-    
+
     pfds[0].fd = m_fdAdmin;
     pfds[0].events = POLLIN;
     pfds[1].fd = -1;
@@ -1569,7 +1457,7 @@ int LshttpdMain::guardCrash()
             processSignal();
     }
     if (m_childrenList.size() > 0)
-        stopAllChildren();
+        stopAllChildren(s_iRunning < 0);
 
     //Server Exit hookpoint called here
     if (GlobalServerSessionHooks->isEnabled(LSI_HKPT_MAIN_ATEXIT))
@@ -1610,6 +1498,34 @@ void LshttpdMain::processSignal()
 }
 
 
+int LshttpdMain::getNumCores()
+{
+#ifdef LSWS_NO_SET_AFFINITY
+    return 2;
+#else
+#if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
+    return sysconf(_SC_NPROCESSORS_ONLN);
+#else
+    int nm[2];
+    size_t len = 4;
+    uint32_t count = 0;
+
+#ifdef HW_AVAILCPU
+    nm[0] = CTL_HW;
+    nm[1] = HW_AVAILCPU;
+    sysctl(nm, 2, &count, &len, NULL, 0);
+#endif
+
+    if (count < 1)
+    {
+        nm[1] = HW_NCPU;
+        sysctl(nm, 2, &count, &len, NULL, 0);
+        if (count < 1)  count = 1;
+    }
+    return count;
+#endif
+#endif
+}
 /*
 void LshttpdMain::setAffinity( pid_t pid, int cpuId )
 {
@@ -1627,3 +1543,42 @@ void LshttpdMain::setAffinity( pid_t pid, int cpuId )
 #endif
 }
 */
+
+
+#if defined(macintosh) || defined(__APPLE__) || defined(__APPLE_CC__)
+#include <crt_externs.h>
+#else
+extern char ** environ;
+#endif
+void LshttpdMain::cleanEnvVars()
+{
+    char **env;
+#if defined(macintosh) || defined(__APPLE__) || defined(__APPLE_CC__)
+    env = *_NSGetEnviron();
+#else
+    env = environ;
+#endif
+    while( env != NULL && *env != NULL )
+    {
+        if (
+                !strncmp( *env, "PATH=", sizeof("PATH=") - 1)
+            // ||  !strncmp( *env, "HOME=", sizeof("HOME=") - 1 )
+            ||  !strncmp( *env, "CWD=", sizeof("CWD=") - 1 )
+            // ||  !strncmp( *env, "IFS=", sizeof("IFS=") - 1 )
+            ||  !strncmp( *env, "LD_LIBRARY_PATH=", sizeof("LD_LIBRARY_PATH=") - 1)
+            )
+        {
+            ++env;
+        }
+        else {
+            char ** del = env;
+            do
+                *del = del[1];
+            while( *del++ );
+        }
+        if (-1 == setenv("IFS", " \t\n", 1))
+        {
+                LS_ERROR("Could not reset IFS!");
+        }
+    }
+}
