@@ -69,7 +69,6 @@ class LshttpdMain
     pid_t               m_pid;
     int                 m_noDaemon;
     int                 m_noCrashGuard;
-    int                 m_iConfTestMode;
     AutoStr             m_gdbPath;
 
     int                *m_pProcState;
@@ -123,9 +122,8 @@ class LshttpdMain
     void deallocateBlackBoard(char *pBuf);
 
     int             startChild(ChildProc *pProc);
-    void            onNewChildStart(ChildProc * pProc);
     int             childDead(int pid);
-    void            stopAllChildren();
+    void            stopAllChildren(int nowait);
     void            waitChildren();
     void            broadcastSig(int sig, int changeState);
     void            releaseExcept(ChildProc *pCurProc);
@@ -143,7 +141,9 @@ class LshttpdMain
 
     void            processSignal();
 
+    int             getNumCores();
     void            setAffinity(pid_t pid, int cpuId);
+    void            cleanEnvVars();
 
     LshttpdMain(const LshttpdMain &rhs);
     void operator=(const LshttpdMain &rhs);
