@@ -38,7 +38,6 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include "mainserverconfig.h"
 
 //#define TEST_OUTPUT_PLAIN_CONF
 
@@ -407,9 +406,7 @@ plainconfKeywords plainconf::sKeywords[] =
     {"binpath", NULL},
     {"apptype", NULL},
     {"startupfile", NULL},
-    {"appserverenv", NULL},
-    {"enablelve",  NULL},
-    {"cpuaffinity", NULL},
+    
     
 };
 
@@ -1130,11 +1127,7 @@ void plainconf::getIncludeFile(const char *curDir, const char *orgFile,
 //Example: co -u1.1 httpd_config.conf
 void plainconf::checkInFile(const char *path)
 {
-    if (MainServerConfig::getInstance().getDisableWebAdmin())
-        return ;
-    
-    struct stat sb0;
-    if (stat(path, &sb0) == -1)
+    if (access(path, 0) == -1)
         return ;
 
     //Backup file abd checkin and out
@@ -1142,40 +1135,36 @@ void plainconf::checkInFile(const char *path)
     strcpy(new_path, path);
     strcat(new_path, "0");
 
-    int ret;
-    struct stat sb;
     AutoStr2 buf;
-    if (stat(new_path, &sb) == -1 ||
-        (sb.st_mtime < sb0.st_mtime && sb0.st_size != sb.st_size))
-    {
-        buf.setStr("cp -f \"");
-        buf.append(path, strlen(path));
-        buf.append("\" \"", 3);
-        buf.append(new_path, strlen(new_path));
-        buf.append("\"", 1);
-        ret = system(buf.c_str());
-        if (ret != 0)
-        {
-            logToMem(LOG_LEVEL_INFO, "Failed to backup the conf file %s, ret %d.",
-                    path, ret);
-            return ;
-        }
-        
-        buf.setStr("ci -l -q -t-\"");
-        buf.append(new_path, strlen(new_path));
-        buf.append("\" -mUpdate \"", 12);
-        buf.append(new_path, strlen(new_path));
-        buf.append("\" >/dev/null 2>&1", 17);
-        ret = system(buf.c_str());
+    buf.setStr("cp \"");
+    buf.append(path, strlen(path));
+    buf.append("\" \"", 3);
+    buf.append(new_path, strlen(new_path));
+    buf.append("\"", 1);
+    int ret = system(buf.c_str());
 
-        if (ret == 0)
-            logToMem(LOG_LEVEL_INFO, "RCS checkin config file %s OK.", new_path);
-        else
-            logToMem(LOG_LEVEL_INFO,
-                    "Failed to RCS checkin conf file %s, ret %d, error(%s). "
-                    "Org command is %s.", new_path, ret, strerror(errno), buf.c_str());
+    if (ret != 0)
+    {
+        logToMem(LOG_LEVEL_INFO, "Failed to backup the conf file %s, ret %d.",
+                 path, ret);
+        return ;
     }
-    
+
+    buf.setStr("ci -l -q -t-\"");
+    buf.append(new_path, strlen(new_path));
+    buf.append("\" -mUpdate \"", 12);
+    buf.append(new_path, strlen(new_path));
+    buf.append("\" >/dev/null 2>&1", 17);
+    ret = system(buf.c_str());
+
+    if (ret == 0)
+        logToMem(LOG_LEVEL_INFO, "RCS checkin config file %s OK.", new_path);
+    else
+        logToMem(LOG_LEVEL_INFO,
+                 "Failed to RCS checkin conf file %s, ret %d, error(%s). "
+                 "Org command is %s.", new_path, ret, strerror(errno), buf.c_str());
+
+    unlink(new_path);
 }
 
 
@@ -1261,8 +1250,10 @@ void plainconf::loadConfFile(const char *path)
         char sMultiLineModeSign[MAX_MULLINE_SIGN_LENGTH] = {0};
         size_t  nMultiLineModeSignLen = 0;  //>0 is mulline mode
 
-        while (fgets(sLine, MAX_LINE_LENGTH, fp))
+        while (!feof(fp))
         {
+            sLine[0] = 0x00;
+            fgets(sLine, MAX_LINE_LENGTH, fp);
             ++lineNumber;
             p = sLine;
 
@@ -1298,6 +1289,7 @@ void plainconf::loadConfFile(const char *path)
                 continue;
 
             AutoStr2 pathInclude;
+
             if (isInclude(p, pathInclude))
             {
                 char achBuf[512] = {0};
@@ -1362,6 +1354,13 @@ void plainconf::loadConfFile(const char *path)
 XmlNode *plainconf::parseFile(const char *configFilePath,
                               const char *rootTag)
 {
+#ifdef TEST_OUTPUT_PLAIN_CONF
+    char *tmp = (char *)new char[5 * 1024 * 1024];
+
+    if (tmp)
+        delete []tmp;
+
+#endif
     XmlNode *rootNode = new XmlNode;
     const char *attr = NULL;
     rootNode->init(rootTag, &attr);
