@@ -53,19 +53,18 @@
 #define MAX_CACHE_CONTROL_LENGTH    128
 #define MAX_RESP_HEADERS_NUMBER     50
 #define MNAME                       cache
-#define ModuleNameStr               "Module:Cache"
+#define ModuleNameStr               "Module-Cache"
 #define CACHEMODULEKEY              "_lsi_module_cache_handler__"
 #define CACHEMODULEKEYLEN           (sizeof(CACHEMODULEKEY) - 1)
 #define CACHEMODULEROOT             "cachedata/"
 
-#define MODULE_VERSION_INFO         "1.60"
+#define MODULE_VERSION_INFO         "1.58"
 
 //The below info should be gotten from the configuration file
 #define max_file_len        4096
 #define VALMAXSIZE          4096
 #define MAX_HEADER_LEN      16384
-#define Z_BUF_SIZE          16384
-    
+
 /////////////////////////////////////////////////////////////////////////////
 extern lsi_module_t MNAME;
 
@@ -171,8 +170,7 @@ struct MyMData
     CacheHash       cePrivateHash;
     CacheKey        cacheKey;
     int16_t         hkptIndex;
-    unsigned char   hasCacheFrontend;
-    unsigned char   reqCompressType; //0, no, 1: gzip, 2:br
+    int16_t         hasCacheFrontend;
     XXH64_state_t   contentState;
     z_stream       *zstream;
     off_t           orgFileLength;
@@ -211,11 +209,10 @@ static lsi_config_key_t paramArray[] =
 
     {"no-vary",                 16, 0},//},16
     {"addEtag",                 17, 0},
-    {"purgeUri",                18, 0},
-    
     {NULL, 0, 0} //Must have NULL in the last item
 };
 
+
 //Update permission of the dest to the same of the src
 static void matchDirectoryPermissions(const char *src, const char *dest)
 {
@@ -447,7 +444,6 @@ static int parseLine(CacheConfig *pConfig, int param_id,
     case 13: //storagepath
     case 14:
     case 15:
-    case 18:
         return i; //return the index for next step parsing
 
     case 16:
@@ -549,9 +545,6 @@ static void *ParseConfig(module_param_info_t *param, int param_count,
             parseNoCacheUrl(pConfig, param[i].val, param[i].val_len, level, name);
         else if (ret == 14)
             parseNoCacheDomain(pConfig, param[i].val, param[i].val_len, level, name);
-        else if (ret == 18)
-            pConfig->setPurgeUri(param[i].val, param[i].val_len);
-
     }
 
     parseNoCacheUrlFinal(pConfig);
@@ -595,79 +588,6 @@ static int isUrlExclude(const lsi_session_t *session, CacheConfig *pConfig,
 }
 
 
-static int uninitZstream(z_stream *zstream, bool compress)
-{
-    if (compress)
-        deflateEnd(zstream);
-    else
-        inflateEnd(zstream);
-    delete zstream;
-    return 0;
-}
-
-
-/**
- * return 0 for OK, -1 for error
- */
-static int initZstream(z_stream *zstream, bool compress)
-{
-    zstream->opaque = Z_NULL;
-    zstream->zalloc = Z_NULL;
-    zstream->zfree = Z_NULL;
-    zstream->avail_in = 0;
-    zstream->next_in = Z_NULL;
-    if (compress)
-    {
-        if (deflateInit2(zstream, Z_BEST_COMPRESSION, Z_DEFLATED,
-                16 + MAX_WBITS, 8, Z_DEFAULT_STRATEGY) != Z_OK)
-        {
-            return -1;
-        }
-    }
-    else
-    {
-        if (inflateInit2(zstream, 32 + MAX_WBITS) != Z_OK)
-        {
-            return -1;
-        }
-    }
-
-    return 0;
-}
-
-
-static int compressbuf(z_stream *zstream, bool compress, unsigned char *buff,
-                    int buffLen, int fd, int eof)
-{
-    unsigned char buf[Z_BUF_SIZE];
-    zstream->next_in = buff;
-    zstream->avail_in = buffLen;
-    int ret = 0;
-    int z_ret;
-    
-    do
-    {
-        zstream->next_out = buf;
-        zstream->avail_out = Z_BUF_SIZE;
-
-        if (compress)
-            z_ret = deflate(zstream, eof ? Z_FINISH : Z_SYNC_FLUSH);
-        else
-            z_ret = inflate(zstream, eof ? Z_FINISH : Z_PARTIAL_FLUSH);
-        
-        if (z_ret == Z_STREAM_ERROR)
-            return LS_FAIL;
-        
-        if (z_ret == Z_BUF_ERROR)
-            z_ret = Z_OK;
-        
-        if (z_ret >= Z_OK)
-            ret += write(fd, buf, Z_BUF_SIZE - zstream->avail_out);
-    } while (z_ret != Z_STREAM_END);
-
-    return ret;
-}
-
 static int isDomainExclude(const lsi_session_t *session, CacheConfig *pConfig)
 {
     if (pConfig->getVHostMapExclude())
@@ -879,20 +799,18 @@ void calcCacheHash2(const lsi_session_t *session, CacheKey *pKey,
     }
     pHash->setKey(XXH64_digest(&state));
 
-    
-    
-    if (pKey->m_iCookiePrivate > 0)
-    {
-        XXH64_update(&state, "~", 1);
-        XXH64_update(&state, pKey->m_sCookie.c_str() + pKey->m_iCookieVary,
-                        pKey->m_iCookiePrivate);
-    }
     if (pKey->m_pIP)
     {
+        if (pKey->m_iCookiePrivate > 0)
+        {
+            XXH64_update(&state, "~", 1);
+            XXH64_update(&state, pKey->m_sCookie.c_str() + pKey->m_iCookieVary,
+                         pKey->m_iCookiePrivate);
+        }
         XXH64_update(&state, "@", 1);
         XXH64_update(&state, pKey->m_pIP, pKey->m_ipLen);
+        pPrivateHash->setKey(XXH64_digest(&state));
     }
-    pPrivateHash->setKey(XXH64_digest(&state));
 }
 
 
@@ -949,34 +867,6 @@ void buildCacheKey(const lsi_session_t *session, const char *uri, int uriLen,
     pKey->m_sCookie.setStr(pCookieBuf);
 }
 
-static void dumpCacheKey(const lsi_session_t *session, const CacheKey *pKey)
-{
-    g_api->log(session, LSI_LOG_DEBUG,
-           "[CACHE] CacheKey data: URI [%.*s], "
-           "QS [%.*s], Vary Cookie [%.*s], "
-           "Private Cookie [%.*s], IP [%s]\n",
-           pKey->m_iUriLen, pKey->m_pUri,
-           pKey->m_iQsLen,  pKey->m_pQs ? pKey->m_pQs : "",
-           pKey->m_iCookieVary, pKey->m_sCookie.c_str() ? pKey->m_sCookie.c_str() : "",
-           pKey->m_iCookiePrivate,
-           pKey->m_sCookie.c_str() ? pKey->m_sCookie.c_str() + pKey->m_iCookieVary : "",
-           pKey->m_pIP);
-}
-
-
-static void dumpCacheHash(const lsi_session_t *session, const char *desc,
-                          const CacheHash *pHash)
-{
-    g_api->log(session, LSI_LOG_DEBUG,
-           "[CACHE] %s, hash: [%02x%02x%02x%02x%02x%02x%02x%02x]\n",
-           desc,
-           pHash->getKey()[0], pHash->getKey()[1],
-           pHash->getKey()[2], pHash->getKey()[3],
-           pHash->getKey()[4], pHash->getKey()[5],
-           pHash->getKey()[6], pHash->getKey()[7]
-          );
-}
-
 
 short lookUpCache(lsi_param_t *rec, MyMData *myData, int no_vary,
                   const char *uri, int uriLen,
@@ -985,11 +875,8 @@ short lookUpCache(lsi_param_t *rec, MyMData *myData, int no_vary,
                   CacheConfig *pConfig, CacheEntry **pEntry, bool doPublic)
 {
     buildCacheKey(rec->session, uri, uriLen, no_vary, &myData->cacheKey);
-    dumpCacheKey(rec->session, &myData->cacheKey);
     calcCacheHash(rec->session, &myData->cacheKey, cePublicHash,
                   cePrivateHash);
-    dumpCacheHash(rec->session, "Public hash", cePublicHash);
-    dumpCacheHash(rec->session, "Private hash", cePrivateHash);
 
     long lastCacheFlush = (long)g_api->get_module_data(rec->session, &MNAME,
                           LSI_DATA_IP);
@@ -1046,7 +933,7 @@ int releaseMData(void *data)
         
         if (myData->pCacheVary)
             delete myData->pCacheVary;
-        memset(myData, 0, sizeof(MyMData));
+        
         delete myData;
     }
     return 0;
@@ -1204,6 +1091,7 @@ static int cancelCache(lsi_param_t *rec)
 static int deflateBufAndWriteToFile(MyMData *myData, unsigned char *pBuf,
                                     int len, int eof, int fd)
 {
+    #define Z_BUF_SIZE 16384
     unsigned char buf[Z_BUF_SIZE];
     int ret = 0;
     if (myData->zstream)
@@ -1346,19 +1234,6 @@ static int createEntry(lsi_param_t *rec)
     for (int i = 0; i < count; ++i)
         myData->cacheCtrl.parse((char *)iov[i].iov_base, iov[i].iov_len);
 
-    /**
-     * If no LSI_RSPHDR_LITESPEED_CACHE_CONTROL, then we can check
-     * expireInSeconds = 0 case and check the normal cache-contrl max-age
-     * and s-maxage
-     */
-    if (count == 0 && myData->cacheCtrl.getMaxAge() == 0)
-    {
-        count = g_api->get_resp_header(rec->session,
-                    LSI_RSPHDR_CACHE_CTRL, NULL, 0, iov, 3);
-        for (int i = 0; i < count; ++i)
-            myData->cacheCtrl.parse((char *)iov[i].iov_base, iov[i].iov_len);
-    }
-    
     if (myData->cacheCtrl.isCacheOff())
     {
         clearHooks(rec->session);
@@ -1366,8 +1241,6 @@ static int createEntry(lsi_param_t *rec)
                    "[%s]createEntry abort, code 1.\n", ModuleNameStr);
         return 0;
     }
-    
-    
 
     //For a HEAD request, do not save it
     if (myData->iMethod == HTTP_HEAD)
@@ -1488,10 +1361,6 @@ static int createEntry(lsi_param_t *rec)
         return 0;
     }
 
-    dumpCacheKey(rec->session, &myData->cacheKey);
-    dumpCacheHash(rec->session, "Create cache with hash ",
-                  &myData->pEntry->getHashKey());
-
     //Now we can store it
     myData->iCacheState = CE_STATE_WILLCACHE;
 
@@ -1529,7 +1398,7 @@ int cacheHeader(lsi_param_t *rec, MyMData *myData)
     
 #ifdef USE_RECV_REQ_HEADER_HOOK
     char cacheEnv[MAX_CACHE_CONTROL_LENGTH] = {0};
-    int cacheEnvLen = g_api->get_req_env(rec->session, "HAVE_REWITE", 11,
+    int cacheEnvLen = g_api->get_req_env(rec->session, "HAVE_REWRITE", 11,
                                          cacheEnv, MAX_CACHE_CONTROL_LENGTH);
     if (cacheEnvLen >= 1 && strncasecmp(cacheEnv, "1", 1) ==  0){
         myData->pEntry->setNeedDelay(1);
@@ -1539,7 +1408,7 @@ int cacheHeader(lsi_param_t *rec, MyMData *myData)
     getRespHeader(rec->session, LSI_RSPHDR_LAST_MODIFIED, &sLastMod,
                   &nLastModLen);
     if (sLastMod)
-        CeHeader.m_tmLastMod = DateTime::parseHttpTime(sLastMod, nLastModLen);
+        CeHeader.m_tmLastMod = DateTime::parseHttpTime(sLastMod);
 
 
     //Check if it is a static file caching
@@ -1605,18 +1474,32 @@ int cacheHeader(lsi_param_t *rec, MyMData *myData)
      * If already gzipped, no need to gzip 
      */
     int needGzip = (g_api->get_resp_buffer_compress_method(rec->session) == 0);
-
+    
     /**
-     * If the response not gzipped, and check if req need gzip,
-     * if not needed, do not gzip it.
+     * For ab test, no need to gzip only when it does not have gzip in encoding
      */
     if (needGzip)
     {
-        needGzip = (myData->reqCompressType == 1);
+#define AB_USERAGENT        "ApacheBench"
+#define AB_USERAGENT_LEN    (sizeof(AB_USERAGENT) - 1)
+        int uaLen;
+        const char * pUA = g_api->get_req_header_by_id(rec->session,
+                                                       LSI_HDR_USERAGENT,
+                                                       &uaLen);
+        if (pUA && uaLen > AB_USERAGENT_LEN &&
+            strncasecmp(pUA, AB_USERAGENT, AB_USERAGENT_LEN) == 0)
+        {
+            int encodingLen;
+            const char *encoding = g_api->get_req_header_by_id(rec->session,
+                                                         LSI_HDR_ACC_ENCODING,
+                                                         &encodingLen);
+            if (encodingLen < 4 || strcasestr(encoding, "gzip") == NULL)
+                needGzip = false;
+        }
     }
 
     /**
-     * If need to gzip but it is a small static file, no need
+     * If need to gzip but it is a a samll static file, no need
      * Or it is not compressible, no need
      */
     if (needGzip)
@@ -1643,29 +1526,18 @@ int cacheHeader(lsi_param_t *rec, MyMData *myData)
         sb.st_size > 0 && sb.st_size < 200)
         needGzip = false;
 
-    /***
-     * if it isn't a static file but has small size, no need to gzip
-     */
-    if (needGzip)
-    {
-        char *pVal = NULL;
-        int valLen;
-        getRespHeader(rec->session, LSI_RSPHDR_CONTENT_LENGTH, &pVal, &valLen);
-        if (pVal && valLen > 0)
-        {
-            int len = 0;
-            len = atoi(pVal);
-            if (len >= 0 && len < 200)
-                needGzip = false;
-        }
-    }
-
     if (needGzip)
     {
         myData->zstream = new z_stream;
         if (myData->zstream)
         {
-            if (initZstream(myData->zstream, 1))
+            myData->zstream->opaque = Z_NULL;
+            myData->zstream->zalloc = Z_NULL;
+            myData->zstream->zfree = Z_NULL;
+            myData->zstream->avail_in = 0;
+            myData->zstream->next_in = Z_NULL;
+            if (deflateInit2(myData->zstream, Z_BEST_COMPRESSION, Z_DEFLATED,
+                16 + MAX_WBITS, 8, Z_DEFAULT_STRATEGY) != Z_OK)
             {
                 delete myData->zstream;
                 myData->zstream = NULL;
@@ -1753,12 +1625,7 @@ int cacheTofile(lsi_param_t *rec)
     if (!myData)
         return 0;
 
-    if (myData->iCacheSendBody == 0) //uninit
-    {
-        myData->iCacheSendBody = 1; //need cache
-        cacheHeader(rec, myData);
-    }
-
+    cacheHeader(rec, myData);
     int fd = myData->pEntry->getFdStore();
 
     long iCahcedSize = 0;
@@ -2020,7 +1887,7 @@ MyMData *createMData(lsi_param_t *rec)
                                rec->session, &MNAME);
     int flag = getControlFlag(pConfig);
     myData->cacheCtrl.init(flag, pConfig->getDefaultAge(), pConfig->getMaxStale());
-    myData->pConfig = pConfig;
+    myData->pConfig = (CacheConfig *)g_api->get_config(rec->session, &MNAME);
     int uriLen = g_api->get_req_org_uri(rec->session, NULL, 0);
     if (uriLen > 0)
     {
@@ -2046,40 +1913,10 @@ MyMData *createMData(lsi_param_t *rec)
     return myData;
 }
 
-
-static int sessionBegin(lsi_param_t *rec)
-{
-    MyMData *myData = (MyMData *) g_api->get_module_data(rec->session, &MNAME,
-                      LSI_DATA_HTTP);
-    if (myData)
-    {
-        g_api->free_module_data(rec->session, &MNAME, LSI_DATA_HTTP, releaseMData);
-        g_api->log(rec->session, LSI_LOG_DEBUG,
-                   "[%s] sessionBegin released previous module data.\n",
-                   ModuleNameStr);
-    }
-    return 0;
-}
-
 static int checkAssignHandler(lsi_param_t *rec)
 {
-    char val[3] = {0};
-    if (g_api->get_req_env(rec->session, "staticcacheserve", 16, val, 1) > 0
-        && strncasecmp(val, "1", 1) ==  0)
-    {
-        int aHkpts[] = {LSI_HKPT_URI_MAP, LSI_HKPT_HTTP_END,
-                    LSI_HKPT_HANDLER_RESTART, LSI_HKPT_RCVD_RESP_HEADER};
-        g_api->enable_hook(rec->session, &MNAME, 0, aHkpts, 4);
-        
-        g_api->log(rec->session, LSI_LOG_DEBUG,
-                   "[%s] checkAssignHandler return since req served by internal cache.\n",
-                   ModuleNameStr);
-        return 0;
-    }
-    
     MyMData *myData = (MyMData *) g_api->get_module_data(rec->session, &MNAME,
                       LSI_DATA_HTTP);
-    
     CacheConfig *pConfig = (CacheConfig *)g_api->get_config(
                                rec->session, &MNAME);
     if (!pConfig)
@@ -2109,15 +1946,8 @@ static int checkAssignHandler(lsi_param_t *rec)
     int method = getHttpMethod(rec, httpMethod);
     if (method == HTTP_UNKNOWN || method == HTTP_POST)
     {
-        CacheConfig *pConfig = (CacheConfig *)g_api->get_config(
-                            rec->session, &MNAME);
-        int flag = getControlFlag(pConfig);
-        CacheCtrl cacheCtrl;
-        cacheCtrl.init(flag, pConfig->getDefaultAge(), pConfig->getMaxStale());
-        parseEnv(rec->session, cacheCtrl);
-
         //Do not store POST method for handling, only store the timestamp
-        if (method == HTTP_POST && cacheCtrl.isPrivateAutoFlush())
+        if (method == HTTP_POST)
         {
             g_api->set_module_data(rec->session, &MNAME, LSI_DATA_IP,
                                    (void *)(long)DateTime_s_curTime);
@@ -2140,6 +1970,23 @@ static int checkAssignHandler(lsi_param_t *rec)
         return bypassUrimapHook(rec, myData);
     }
 
+    CacheCtrl cacheCtrl;
+    int flag = getControlFlag(pConfig);
+    cacheCtrl.init(flag, pConfig->getDefaultAge(), pConfig->getMaxStale());
+    parseEnv(rec->session, cacheCtrl);
+
+    if (rec->ptr1 != NULL && rec->len1 > 0)
+        cacheCtrl.parse((const char *)rec->ptr1, rec->len1);
+
+    if (!pConfig->isSet(CACHE_IGNORE_REQ_CACHE_CTRL_HEADER))
+    {
+        int bufLen;
+        const char *buf = g_api->get_req_header_by_id(rec->session,
+                          LSI_HDR_CACHE_CTRL, &bufLen);
+        if (buf && bufLen > 0)
+            cacheCtrl.parse(buf, bufLen);
+    }
+
     if (method == HTTP_GET || method == HTTP_HEAD)
     {
         if (!pConfig->isCheckPublic() && !pConfig->isPrivateCheck())
@@ -2160,34 +2007,11 @@ static int checkAssignHandler(lsi_param_t *rec)
 
     myData->pConfig = pConfig;
     myData->iMethod = method;
-    CacheCtrl &cacheCtrl = myData->cacheCtrl;
-    parseEnv(rec->session, cacheCtrl);
-
-    if (rec->ptr1 != NULL && rec->len1 > 0)
-        cacheCtrl.parse((const char *)rec->ptr1, rec->len1);
-
-    if (!pConfig->isSet(CACHE_IGNORE_REQ_CACHE_CTRL_HEADER))
-    {
-        int bufLen;
-        const char *buf = g_api->get_req_header_by_id(rec->session,
-                          LSI_HDR_CACHE_CTRL, &bufLen);
-        if (buf && bufLen > 0)
-            cacheCtrl.parse(buf, bufLen);
-    }
 
     //Set to true but not the below just for not to re-check cache state or
     //re-store it
     //bool doPublic = cacheCtrl.isPublicCacheable() || myData->pConfig->isCheckPublic();
     bool doPublic = true;
-    int encodingLen;
-    const char *encoding = g_api->get_req_header_by_id(rec->session,
-                                                       LSI_HDR_ACC_ENCODING,
-                                                       &encodingLen);
-    myData->reqCompressType = (encodingLen >= 4 && strcasestr(encoding, "gzip"));
-    if (myData->reqCompressType == LSI_NO_COMPRESS &&
-        encodingLen >= 2 && strcasestr(encoding, "br"))
-        myData->reqCompressType = LSI_BR_COMPRESS;
-
     myData->iCacheState = lookUpCache(rec, myData,
                                    cacheCtrl.getFlags() & CacheCtrl::no_vary,
                                    myData->pOrgUri, strlen(myData->pOrgUri),
@@ -2220,6 +2044,12 @@ static int checkAssignHandler(lsi_param_t *rec)
         return bypassUrimapHook(rec, NULL);
     }
 
+
+    //need to  re-set the cacheCtrl and pConfig since it may be updated in diff level
+    myData->cacheCtrl = cacheCtrl;
+    myData->pConfig = pConfig;
+    
+    char val[3] = {0};
     if (g_api->get_req_env(rec->session, "LSCACHE_FRONTEND", 16, val, 2) > 0
         && strncasecmp(val, "1", 1) ==  0)
     {
@@ -2367,7 +2197,6 @@ int releaseIpCounter(void *data)
 
 static lsi_serverhook_t serverHooks[] =
 {
-    {LSI_HKPT_HTTP_BEGIN,       sessionBegin,       LSI_HOOK_FIRST,  LSI_FLAG_ENABLED},
 #ifdef USE_RECV_REQ_HEADER_HOOK
     {LSI_HKPT_RCVD_REQ_HEADER,  checkAssignHandler, LSI_HOOK_EARLY,     LSI_FLAG_ENABLED},
 #endif
@@ -2415,7 +2244,7 @@ int isModified(const lsi_session_t *session, CeHeader &CeHeader, char *etag,
 
     buf = g_api->get_req_header(session, "If-Modified-Since", 17, &len);
     if (!*buf && len >= RFC_1123_TIME_LEN &&
-        CeHeader.m_tmLastMod <= DateTime::parseHttpTime(buf, len))
+        CeHeader.m_tmLastMod <= DateTime::parseHttpTime(buf))
         return 0;
 
     return 1;
@@ -2581,173 +2410,9 @@ static void decref_and_free_data(MyMData *myData, const lsi_session_t *session)
     g_api->free_module_data(session, &MNAME, LSI_DATA_HTTP, releaseMData);
 }
 
-
-static void updateCacheEntry(CacheConfig *pConfig, CacheEntry *pEntry, int tmpfd,
-                             char *tmppath, int compressType, off_t length)
-{
-    //length change
-    pEntry->setPart2Len(length);
-
-    //Update compressType
-    pEntry->markReady(compressType);
-
-    //Update fd
-    close(pEntry->getFdStore());
-    pEntry->setFdStore(tmpfd);
-
-    //since the filepath is org path + .tmp, so just publish it to use it
-    pConfig->getStore()->publish(pEntry);
-}
-
-static void closeTmpFile(int fd, const char *path)
-{
-    close(fd);
-    unlink(path);
-}
-
-static void toggleGzipState(MyMData *myData, int needCompressType)
-{
-    if (needCompressType != LSI_NO_COMPRESS &&
-        needCompressType != LSI_GZIP_COMPRESS)
-        return ;
-
-    /***
-     * Because in child process, mydata maybe can not be accessed when it is 
-     * released, so save the config and entry now.
-     */
-    CacheConfig *pConfig = myData->pConfig;
-    CacheEntry *pEntry = myData->pEntry;
-    
-    /***
-     * Should not block the current processing
-     */
-    pid_t pid = fork();
-    if (pid < 0)
-    {
-        g_api->log(NULL, LSI_LOG_ERROR, "[%s]toggleGzipState fork failed.\n",
-               ModuleNameStr);
-        return ;
-    }
-
-    if (pid > 0)
-    {
-        g_api->log(NULL, LSI_LOG_DEBUG,
-               "[%s]toggleGzipState fork pid %d to processing.\n",
-               ModuleNameStr, pid);
-        return;
-    }
-    else //child process
-    {
-        char tmppath[4100] = {0};
-        int len = 4096;
-        pConfig->getStore()->getEntryFilePath(pEntry, tmppath, len);
-        strcat(tmppath, ".tmp");
-
-        /**
-         * If the the file exists more than 10 minutes, should be something wrong
-         * Even the state is updating, try to remove it 
-         */
-        struct stat sb;
-        if (stat(tmppath, &sb) != -1)
-        {
-            if((long)DateTime_s_curTime - (long)sb.st_ctime < 360)
-                exit (0);
-            else
-            {
-                g_api->log(NULL, LSI_LOG_DEBUG,
-                           "[%s]toggleGzipState processing too long %d seconds.\n",
-                           ModuleNameStr,
-                           (long)DateTime_s_curTime - (long)sb.st_ctime);
-                unlink(tmppath);
-            }
-        }
-
-        int tmpfd = ::open(tmppath, O_RDWR | O_CREAT | O_TRUNC | O_EXCL, 0760);
-        if (tmpfd == -1)
-        {
-            g_api->log(NULL, LSI_LOG_DEBUG,
-                           "[%s]toggleGzipState can not open file %s.\n",
-                           ModuleNameStr, tmppath);
-            exit (0);
-        }
-        
-        ::fcntl(tmpfd, F_SETFD, FD_CLOEXEC);
-
-        z_stream *zstream = new z_stream;
-        if (!zstream)
-        {
-            g_api->log(NULL, LSI_LOG_ERROR, "[%s]toggleGzipState alloc"
-                        " memory for zstream error.\n", ModuleNameStr);
-            closeTmpFile(tmpfd, tmppath);
-            exit (0);
-        }
-        
-        bool compress = (needCompressType == LSI_GZIP_COMPRESS);
-        if (initZstream(zstream, compress))
-        {
-            delete zstream;
-            closeTmpFile(tmpfd, tmppath);
-            g_api->log(NULL, LSI_LOG_ERROR, "[%s]toggleGzipState initZstream"
-                        " error.\n", ModuleNameStr);
-            exit (0);
-        }
-
-        int fd = pEntry->getFdStore();
-        int part1offset = pEntry->getPart1Offset();
-        int part2offset = pEntry->getPart2Offset();
-        off_t length = pEntry->getContentTotalLen() -
-                           (part2offset - part1offset);
-        
-        unsigned char *buff  = (unsigned char *)mmap((caddr_t)0,
-                                                     part2offset + length,
-                                                     PROT_READ, MAP_SHARED,
-                                                     fd, 0);
-        if (buff == (unsigned char *)(-1))
-        {
-            uninitZstream(zstream, compress);
-            closeTmpFile(tmpfd, tmppath);
-            g_api->log(NULL, LSI_LOG_ERROR, "[%s]toggleGzipState mmap"
-                        " error.\n", ModuleNameStr);
-            exit (0);
-        }
-
-
-        
-
-        /**
-         * Now set the updating flag
-         */
-        write(tmpfd, buff, part2offset);
-        buff+= part2offset;
-        
-        off_t ret = compressbuf(zstream, compress, buff, length, tmpfd, 1);
-        g_api->log(NULL, LSI_LOG_DEBUG,
-                   "[%s]toggleGzipState write %d bytes to file %s.\n",
-                   ModuleNameStr, ret, tmppath);
-
-        if (ret <= 0)
-        {
-            //failed
-            closeTmpFile(tmpfd, tmppath);
-            g_api->log(NULL, LSI_LOG_ERROR, "[%s]toggleGzipState compressbuf"
-                        " error.\n", ModuleNameStr);
-        }
-        else
-        {
-            updateCacheEntry(pConfig, pEntry, tmpfd, tmppath, needCompressType, ret);
-            g_api->log(NULL, LSI_LOG_DEBUG, "[%s]toggleGzipState updated"
-                        " the cache entry.\n", ModuleNameStr);
-        }
-        uninitZstream(zstream, compress);
-
-        munmap((caddr_t)buff, part2offset + length);
-        exit(0);
-    }
-}
-
-
 static int handlerProcess(const lsi_session_t *session)
 {
+    g_api->log(session, LSI_LOG_DEBUG, "[%s]handlerProcess.\n", ModuleNameStr);
     MyMData *myData = (MyMData *)g_api->get_module_data(session, &MNAME,
                       LSI_DATA_HTTP);
     if (!myData)
@@ -2762,26 +2427,13 @@ static int handlerProcess(const lsi_session_t *session)
 
     if (myData->iMethod == HTTP_PURGE || myData->iMethod == HTTP_REFRESH)
     {
-        /**
-         * 1, if the context is protected by realm, need to pass the http Authorization
-         * 2, if the context is not protected by realm, the IP must be defined as trust
-         * 3, if there is an entry, purge the entry
-         * 4, if no entry, if the purgeUri is defined, must match the uri
-         */
-        
-        char httpAuthEnv[3] = {0};
-        int httpAuthEnvLen = g_api->get_req_env(session, "HttpAuth", 8,
-                                                    httpAuthEnv, 2);
-        if (httpAuthEnvLen <= 0 || *httpAuthEnv != '1')
+        int len;
+        const char *pIP = g_api->get_client_ip(session, &len);
+        if (g_api->get_client_access_level(session) != LSI_ACL_TRUST &&
+            (!pIP || strncmp(pIP, "127.0.0.1", 9) != 0))
         {
-            int len;
-            const char *pIP = g_api->get_client_ip(session, &len);
-            if (g_api->get_client_access_level(session) != LSI_ACL_TRUST &&
-                (!pIP || strncmp(pIP, "127.0.0.1", 9) != 0))
-            {
-                decref_and_free_data(myData, session);
-                return 405;
-            }
+            decref_and_free_data(myData, session);
+            return 405;
         }
 
         if (myData->pEntry)
@@ -2800,43 +2452,11 @@ static int handlerProcess(const lsi_session_t *session)
             }
         }
         else
-        {
-            bool bPurgeTags = true;
-            char *pUri = myData->pConfig->getPurgeUri();
-            if (pUri)
-            {
-                char *pOrgUri = strchr(myData->pOrgUri, ':');
-                pOrgUri = strchr(pOrgUri, '/');
-                if (strcasecmp(pUri, pOrgUri) != 0)
-                    bPurgeTags = false;
-            }
-            
-            if (bPurgeTags)
-            {
-                int valLen = 0;
-                const char *pVal = g_api->get_req_header_by_id(session,
-                                                              LSI_HDR_LITESPEED_PURGE,
-                                                              &valLen);
-                if (pVal && valLen > 0)
-                {
-                    processPurge(session, pVal, valLen);
-                    g_api->set_resp_content_length(session, valLen + 24);
-                    g_api->append_resp_body(session, "Processed PURGE by \"", 20);
-                    g_api->append_resp_body(session, pVal, valLen);
-                    g_api->append_resp_body(session, "\".\r\n", 4);
-                }
-                else
-                    g_api->append_resp_body(session, "PURGE tag not defined.\n",
-                                        23);
-            }
-            else
-                g_api->append_resp_body(session, "PURGE uri not match.\n", 21);
-        }
-
+            g_api->append_resp_body(session, "No such entry.", 14);
 
         g_api->end_resp(session);
         decref_and_free_data(myData, session);
-        return 0;
+        return 200;
     }
 
 
@@ -2844,7 +2464,6 @@ static int handlerProcess(const lsi_session_t *session)
     int len;
     int fd = myData->pEntry->getFdStore();
     CeHeader &CeHeader = myData->pEntry->getHeader();
-    int compressType = myData->pEntry->getCompressType();
 
     int hitIdx = (myData->iCacheState == CE_STATE_HAS_PRIVATE_CACHE) ? 1 : 0;
 
@@ -2865,9 +2484,6 @@ static int handlerProcess(const lsi_session_t *session)
             if (buff == (char *)(-1))
             {
                 decref_and_free_data(myData, session);
-                g_api->log(session, LSI_LOG_ERROR,
-                           "[%s]handlerProcess return 500 due to cant alloc memory.\n",
-                           ModuleNameStr);
                 return 500;
             }
             pBuffOrg = buff;
@@ -2895,40 +2511,33 @@ static int handlerProcess(const lsi_session_t *session)
                     munmap((caddr_t)pBuffOrg, part2offset);
                 g_api->end_resp(session);
                 decref_and_free_data(myData, session);
-                g_api->log(session, LSI_LOG_DEBUG,
-                           "[%s]handlerProcess return 304.\n", ModuleNameStr);
                 return 0;
             }
 
-            
-            str.setStr(buff, CeHeader.m_lenETag);
-            pEtag = (char *)str.c_str();
-
-            char *pUpdate = pEtag + str.len() - 4;
-            if (*pUpdate++ == ';')
+            int compressType = myData->pEntry->getCompressType();
+            if (compressType)  //1 gz,  2 br
             {
-                if (compressType == 0)
+                str.setStr(buff, CeHeader.m_lenETag);
+                pEtag = (char *)str.c_str();
+
+                char *pUpdate = pEtag + str.len() - 4;
+                if (*pUpdate++ == ';')
                 {
-                    *pUpdate++ = ';';
-                    *pUpdate++ = ';';
-                }
-                else if (compressType == 1)
-                {
-                    *pUpdate++ = 'g';
-                    *pUpdate++ = 'z';
-                }
-                else if (compressType == 2)
-                {
-                    *pUpdate++ = 'b';
-                    *pUpdate++ = 'r';
+                    if (compressType == 1)
+                    {
+                        *pUpdate++ = 'g';
+                        *pUpdate++ = 'z';
+                    }
+                    else
+                    {
+                        *pUpdate++ = 'b';
+                        *pUpdate++ = 'r';
+                    }
                 }
             }
 
             g_api->set_resp_header(session, LSI_RSPHDR_ETAG, NULL, 0, pEtag,
                                    CeHeader.m_lenETag, LSI_HEADEROP_SET);
-            g_api->log(session, LSI_LOG_DEBUG,
-                       "[%s]handlerProcess add etag %s.\n",
-                       ModuleNameStr, pEtag);
         }
 
         buff += CeHeader.m_lenETag + CeHeader.m_lenStxFilePath;
@@ -2962,40 +2571,24 @@ static int handlerProcess(const lsi_session_t *session)
                            LSI_HEADEROP_SET);
 
     g_api->set_status_code(session, CeHeader.m_statusCode);
-    g_api->log(session, LSI_LOG_DEBUG,
-                       "[%s]handlerProcess set_status_code %d.\n",
-                       ModuleNameStr, CeHeader.m_statusCode);
 
-    //assert(strcasestr(myData->pOrgUri, "fonts/ProximaNova-Regular.woff") == NULL);
-    
     int ret  = 0;
     if (myData->iMethod == HTTP_GET)
     {
         off_t length = myData->pEntry->getContentTotalLen() -
                        (part2offset - part1offset);
 
-        if (compressType == LSI_NO_COMPRESS)
-        {
-            if (myData->reqCompressType == LSI_GZIP_COMPRESS)
-                myData->pEntry->incHits();
-            else if (myData->reqCompressType == compressType)
-                myData->pEntry->clearHits();
-        }
-        else if (compressType == LSI_GZIP_COMPRESS)
+
+        int compressType = myData->pEntry->getCompressType();
+        if (compressType == 1)
         {
             g_api->set_resp_header(session, LSI_RSPHDR_CONTENT_ENCODING,
                                    NULL, 0, "gzip", 4, LSI_HEADEROP_SET);
             g_api->log(session, LSI_LOG_DEBUG,
                        "[%s]set_resp_header [Content-Encoding: gzip].\n",
                        ModuleNameStr);
-
-            if (myData->reqCompressType == LSI_NO_COMPRESS)
-                myData->pEntry->incHits();
-            else if (myData->reqCompressType == compressType)
-                myData->pEntry->clearHits();
-
         }
-        else if (compressType == LSI_BR_COMPRESS)
+        else if (compressType == 2)
         {
             g_api->set_resp_header(session, LSI_RSPHDR_CONTENT_ENCODING,
                                    NULL, 0, "br", 2, LSI_HEADEROP_SET);
@@ -3005,31 +2598,12 @@ static int handlerProcess(const lsi_session_t *session)
         }
         g_api->set_resp_buffer_compress_method(session, compressType);
 
-
         g_api->set_resp_content_length(session, length);
         int fd = myData->pEntry->getFdStore();
-        
-        g_api->log(session, LSI_LOG_DEBUG,
-                   "[%s]handlerProcess fd %d, offset %d, length %ld\n",
-                   ModuleNameStr, fd, part2offset, length);
-
         if (g_api->send_file2(session, fd, part2offset, length) == 0)
             g_api->end_resp(session);
         else
             ret = 500;
-        
-        /**
-         * For testing, disable the code 
-         */
-        if (myData->pEntry->getHits() >= 10)
-        {
-            g_api->log(session, LSI_LOG_DEBUG,
-                       "[%s]handlerProcess check entry hit %d times, "
-                       "will change to compressType from %d to %d.\n",
-                       ModuleNameStr, myData->pEntry->getHits(),
-                       compressType, myData->reqCompressType);
-            toggleGzipState(myData, myData->reqCompressType);
-        }
     }
     else //HEAD
         g_api->end_resp(session);
@@ -3040,8 +2614,8 @@ static int handlerProcess(const lsi_session_t *session)
     return ret;
 }
 
-lsi_reqhdlr_t cache_handler = { handlerProcess, NULL, NULL, NULL };
-lsi_confparser_t cacheDealConfig = { ParseConfig, FreeConfig, paramArray };
+lsi_reqhdlr_t cache_handler = { handlerProcess, NULL, NULL, NULL, NULL, NULL, NULL };
+static lsi_confparser_t cacheDealConfig = { ParseConfig, FreeConfig, paramArray };
 LSMODULE_EXPORT lsi_module_t MNAME = { LSI_MODULE_SIGNATURE, init, &cache_handler,
                        &cacheDealConfig, MODULE_VERSION_INFO, serverHooks, {0}
                      };
