@@ -31,7 +31,6 @@ CacheEntry::CacheEntry()
     , m_needDelay(0)
     , m_startOffset(0)
     , m_fdStore(-1)
-    , m_iVaryFlag(0)
     , m_pWaitQue(NULL)
 {
 }
@@ -59,14 +58,14 @@ int CacheKey::getPrivateId(char *pBuf, char *pBufEnd)
     char *p = pBuf;
     if (m_ipLen <= 0)
         return -1;
-//     if (m_iCookiePrivate > 0)
-//     {
-//         if (p + m_iCookiePrivate + 1 > pBufEnd)
-//             return -1;
-//         *p++ = '~';
-//         memmove(p , m_sCookie.c_str() + m_iCookieVary, m_iCookiePrivate);
-//         p += m_iCookiePrivate;
-//     }
+    if (m_iCookiePrivate > 0)
+    {
+        if (p + m_iCookiePrivate + 1 > pBufEnd)
+            return -1;
+        *p++ = '~';
+        memmove(p , m_sCookie.c_str() + m_iCookieVary, m_iCookiePrivate);
+        p += m_iCookiePrivate;
+    }
     if (p + m_ipLen + 1 > pBufEnd)
         return -1;
     *p++ = '@';
@@ -103,6 +102,10 @@ int CacheEntry::setKey(const CacheHash &hash, CacheKey *pKey)
     char *pBuf = m_sKey.prealloc(len + 1);
     if (!pBuf)
         return -1;
+    
+    if (!pKey->m_pUri)
+        return -1;
+
     memmove(pBuf, pKey->m_pUri, pKey->m_iUriLen + 1);
     l = pKey->m_iUriLen;
     if (pKey->m_iQsLen > 0)
