@@ -58,15 +58,6 @@ static inline void appendNbo4Bytes(LoopBuf *pBuf, uint32_t val)
 }
 
 
-// static inline void append4Bytes(LoopBuf *pBuf, const char *val)
-// {
-//     pBuf->append(*val++);
-//     pBuf->append(*val++);
-//     pBuf->append(*val++);
-//     pBuf->append(*val);
-// }
-
-
 H2Connection::H2Connection()
     : m_bufInput(4096)
     , m_uiPushStreamId(2)
@@ -335,9 +326,9 @@ void H2Connection::printLogMsg(H2FrameHeader *pHeader)
             message = (const char *)m_bufInput.begin() + 8;
             messageLen = pHeader->getLength() - 8;
         }
-        LS_DBG_L(getLogger(),
+        LS_DBG_L(getStream()->getLogger(),
                  "[%s-%d] Received %s, size: %d, flag: 0x%hhx, Message: '%.*s'",
-                 getLogId(), pHeader->getStreamId(),
+                 getStream()->getLogId(), pHeader->getStreamId(),
                  getH2FrameName(pHeader->getType()), pHeader->getLength(),
                  pHeader->getFlags(), messageLen, message);
     }
@@ -858,11 +849,6 @@ int H2Connection::processPriority(uint32_t id)
         return H2_ERROR_PROTOCOL_ERROR;
     //Add one to the value to obtain a weight between 1 and 256.
     m_priority.m_weight = *(pSrc + 4) + 1;
-
-    LS_DBG_L(getLogger(),
-               "[%s-%d] stream priority, execlusive: %d, depend sid: %d, weight: %hd ",
-             getLogId(), id, (int)m_priority.m_exclusive, m_priority.m_dependStreamId, m_priority.m_weight);
-
     return 0;
 }
 
@@ -1084,9 +1070,9 @@ int H2Connection::decodeData(const unsigned char *pSrc,
 H2Stream *H2Connection::getNewStream(uint8_t ubH2_Flags)
 {
     H2Stream *pStream;
-    LS_DBG_H(getLogger(),
+    LS_DBG_H(getStream()->getLogger(),
              "[%s-%d] getNewStream(), stream map size: %d, shutdown streams: %d, flag: %d ",
-             getLogId(), m_uiLastStreamId, (int)m_mapStream.size(),
+             getStream()->getLogId(), m_uiLastStreamId, (int)m_mapStream.size(),
              m_uiShutdownStreams, (int)ubH2_Flags);
 
     if ((int)m_mapStream.size() - (int)m_uiShutdownStreams - m_iCurPushStreams 
@@ -1155,8 +1141,8 @@ void H2Connection::recycleStream(StreamMap::iterator it)
     if (pH2Stream->getHandler())
         pH2Stream->getHandler()->recycle();
 
-    LS_DBG_H(getLogger(), "[%s-%d] recycleStream(), stream map size: %zd ",
-             getLogId(), pH2Stream->getStreamID(), m_mapStream.size());
+    LS_DBG_H(pH2Stream, "recycleStream(), stream map size: %zd ",
+             m_mapStream.size());
     //H2StreamPool::recycle( pH2Stream );
     delete pH2Stream;
 }
@@ -1209,8 +1195,8 @@ int H2Connection::sendFrame8Bytes(H2FrameType type, uint32_t uiStreamId,
     appendCtrlFrameHeader(type, 8, 0, uiStreamId);
     appendNbo4Bytes(getBuf(), uiVal1);
     appendNbo4Bytes(getBuf(), uiVal2);
-    LS_DBG_H(getLogger(), "[%s-%d] send %s frame, stream: %d, value: %d",
-             getLogId(), uiStreamId, getH2FrameName(type), uiVal1, uiVal2);
+    LS_DBG_H(getStream()->getLogger(), "[%s-%d] send %s frame, stream: %d, value: %d",
+             getStream()->getLogId(), uiStreamId, getH2FrameName(type), uiVal1, uiVal2);
     return 0;
 }
 
@@ -1222,8 +1208,8 @@ int H2Connection::sendFrame4Bytes(H2FrameType type, uint32_t uiStreamId,
     appendCtrlFrameHeader(type, 4, 0, uiStreamId);
 
     appendNbo4Bytes(getBuf(), uiVal1);
-    LS_DBG_H(getLogger(), "[%s-%d] send %s frame, value: %d", getLogId(),
-             uiStreamId, getH2FrameName(type), uiVal1);
+    LS_DBG_H(getStream()->getLogger(), "[%s-%d] send %s frame, value: %d", 
+             getStream()->getLogId(), uiStreamId, getH2FrameName(type), uiVal1);
     return 0;
 }
 
@@ -1233,8 +1219,8 @@ int H2Connection::sendFrame0Bytes(H2FrameType type, unsigned char flags,
 {
     getBuf()->guarantee(9);
     appendCtrlFrameHeader(type, 0, flags, uiStreamId);
-    LS_DBG_H(getLogger(), "[%s-%d] send %s frame, with Flag: %d",
-             getLogId(), uiStreamId, getH2FrameName(type), flags);
+    LS_DBG_H(getStream()->getLogger(), "[%s-%d] send %s frame, with Flag: %d",
+             getStream()->getLogId(), uiStreamId, getH2FrameName(type), flags);
     return 0;
 }
 
@@ -1549,7 +1535,8 @@ int H2Connection::encodeHeaders(HttpRespHeaders *pRespHeaders,
                                      (char *)pIov->iov_base, pIov->iov_len, 0);
         }
     }
-    LS_DBG_H(getLogger(), "encodeHeaders():\r\n%.*s", str.len(), str.c_str());
+    LS_DBG_H(getStream()->getLogger(), "encodeHeaders():\r\n%.*s",
+             str.len(), str.c_str());
 
     return pCur - buf;
 }
@@ -1558,8 +1545,8 @@ int H2Connection::encodeHeaders(HttpRespHeaders *pRespHeaders,
 int H2Connection::sendRespHeaders(HttpRespHeaders *pRespHeaders,
                                   uint32_t uiStreamID, uint8_t flag)
 {
-    LS_DBG_H(getLogger(), "[%s-%d] sendRespHeaders()",
-             getLogId(), uiStreamID);
+    LS_DBG_H(getStream()->getLogger(), "[%s-%d] sendRespHeaders()",
+             getStream()->getLogId(), uiStreamID);
 
     unsigned char achHdrBuf[H2_TMP_HDR_BUFF_SIZE];
     int rc = encodeHeaders(pRespHeaders, achHdrBuf, H2_TMP_HDR_BUFF_SIZE);
@@ -1600,7 +1587,6 @@ int H2Connection::sendHeaderContFrame(uint32_t uiStreamID, uint8_t flag,
     return 0;
 }
 
-
 int H2Connection::sendPushPromise(uint32_t streamId, uint32_t promise_streamId, 
                                   ls_str_t* pUrl, ls_str_t* pHost, 
                                   ls_strpair_t *headers)
@@ -1704,8 +1690,8 @@ void H2Connection::add2PriorityQue(H2Stream *pH2Stream)
 {
     if (pH2Stream->next())
         pH2Stream->remove();
-    LS_DBG_H(getLogger(), "[%s-%d] add to priority queue: %d",
-             getLogId(), pH2Stream->getStreamID(), pH2Stream->getPriority());
+    LS_DBG_H(pH2Stream, "add to priority queue: %d",
+             pH2Stream->getPriority());
 
     m_priQue[pH2Stream->getPriority()].append(pH2Stream);
     m_iFlag |= H2_CONN_FLAG_WAIT_PROCESS;
@@ -1720,8 +1706,8 @@ int H2Connection::onWriteEx2()
     H2Stream *pH2Stream = NULL;
     int wantWrite = 0;
 
-    LS_DBG_H(getLogSession(),
-             "onWriteEx2() state: %d, output buffer size = %d, Data Out Window: %d",
+    LS_DBG_H(getStream()->getLogger(),
+             "onWriteEx() state: %d, output buffer size = %d, Data Out Window: %d",
              m_iState, getBuf()->size(), m_iCurDataOutWindow);
     if (getBuf()->size() > 4096)
     {
