@@ -15,7 +15,6 @@
 #include <lsr/ls_pool.h>
 #include <socket/ls_sock.h>
 #include <sslpp/ls_fdbuf_bio.h>
-#include <openssl/bio.h>
 
 #ifdef RUN_TEST
 #define DEBUGGING
@@ -39,7 +38,7 @@
 
 #endif
 
-const int RBIO_BUF_SIZE = 4096; // Initial size
+const int RBIO_BUF_SIZE = 2048; // Initial size
 #if OPENSSL_VERSION_NUMBER < 0x10100000
 BIO_METHOD  s_biom_s;
 #endif
@@ -78,7 +77,7 @@ void ls_fdbuf_bio_init(ls_fdbio_data *fdbio)
 static int bio_fd_free(BIO *a)
 {
     ls_fdbio_data *fdbio;
-    DEBUG_MESSAGE("[BIO] bio_fd_free: %p\n", a);
+    DEBUG_MESSAGE("[BIO: %d] bio_fd_free: %p\n", getpid(), a);
     if (a == NULL)
         return 0;
     fdbio = LS_FDBUF_FROM_BIO(a);
@@ -100,17 +99,17 @@ static int bio_fd_read(BIO *b, char *out, int outl)
     ls_fdbio_data *fdbio = LS_FDBUF_FROM_BIO(b);
     int fd = BIO_get_fd(b, 0);
     int total = 0;
-    DEBUG_MESSAGE("[BIO] bio_fd_read: %p, %d bytes on %d\n", b,
+    DEBUG_MESSAGE("[BIO: %d] bio_fd_read: %p, %d bytes on %d\n", getpid(), b, 
                   outl, fd);
     if ((out == NULL) || (!outl))
     {
-        INFO_MESSAGE("[BIO] bio_fd_read NO BUFFER!!\n");
+        INFO_MESSAGE("[BIO: %d] bio_fd_read NO BUFFER!!\n", getpid());
         err = ENOMEM;
         return -1;
     }
     if (fdbio->m_rbioClosed)
     {
-        DEBUG_MESSAGE("[BIO] bio_fd_read: CLOSED ON PREVIOUS READ\n");
+        DEBUG_MESSAGE("[BIO: %d] bio_fd_read: CLOSED ON PREVIOUS READ\n", getpid());
         errno = 0;
         return 0;
     }
@@ -122,15 +121,15 @@ static int bio_fd_read(BIO *b, char *out, int outl)
         if (buffered)
         {
             copy = (buffered > rd_remaining) ? rd_remaining : buffered;
-            DEBUG_MESSAGE("[BIO] bio_fd_read: Use buffered %d of %d\n",
-                          copy, rd_remaining);
+            DEBUG_MESSAGE("[BIO: %d] bio_fd_read: Use buffered %d of %d\n", 
+                          getpid(), copy, rd_remaining);
             memcpy(&out[total], &fdbio->m_rbioBuf[fdbio->m_rbioIndex], copy);
             fdbio->m_rbioIndex += copy;
             total += copy;
             if (total >= outl)
             {
-                DEBUG_MESSAGE("[BIO] bio_fd_read: GOT TOTAL %d\n",
-                              total);
+                DEBUG_MESSAGE("[BIO: %d] bio_fd_read: GOT TOTAL %d\n", 
+                              getpid(), total);
                 return total;
             }
             fdbio->m_rbioBuffered = 0;
@@ -139,7 +138,8 @@ static int bio_fd_read(BIO *b, char *out, int outl)
         }
         if ((rd_remaining < fdbio->m_rbioBufSz) && (fdbio->m_rbioBuf))
         {
-            DEBUG_MESSAGE("[BIO] bio_fd_read: Read into buffer\n");
+            DEBUG_MESSAGE("[BIO: %d] bio_fd_read: Read into buffer\n", 
+                          getpid());
             ret = ls_read(fd, fdbio->m_rbioBuf, fdbio->m_rbioBufSz);
             if (ret < fdbio->m_rbioBufSz)
                 fdbio->m_rbioWaitEvent = 1;
@@ -147,7 +147,8 @@ static int bio_fd_read(BIO *b, char *out, int outl)
         }
         else
         {
-            DEBUG_MESSAGE("[BIO] bio_fd_read: Read into data\n");
+            DEBUG_MESSAGE("[BIO: %d] bio_fd_read: Read into data\n", 
+                          getpid());
             ret = ls_read(fd, out + total, rd_remaining);
             if (ret < rd_remaining)
                 fdbio->m_rbioWaitEvent = 1;
@@ -155,7 +156,7 @@ static int bio_fd_read(BIO *b, char *out, int outl)
         }
         if (ret == 0)
         {
-            DEBUG_MESSAGE("[BIO] bio_fd_read: CLOSED\n");
+            DEBUG_MESSAGE("[BIO: %d] bio_fd_read: CLOSED\n", getpid());
             fdbio->m_rbioClosed = 1;
             errno = 0;
             return total;
@@ -165,13 +166,14 @@ static int bio_fd_read(BIO *b, char *out, int outl)
             errno = err;
             if (total)
             {
-                DEBUG_MESSAGE("[BIO] bio_fd_read: error but I have data\n");
+                DEBUG_MESSAGE("[BIO: %d] bio_fd_read: error but I have data\n", 
+                              getpid());
                 return total;
             }
             if ((SIMPLE_RETRY(err)) || (BIO_fd_should_retry(ret)))
             {
-                DEBUG_MESSAGE("[BIO] bio_fd_read: set retry read"
-                              " errno: %d\n", err);
+                DEBUG_MESSAGE("[BIO: %d] bio_fd_read: set retry read"
+                              " errno: %d\n", getpid(), err);
                 errno = err;
                 BIO_set_retry_read(b);
             }
@@ -181,12 +183,14 @@ static int bio_fd_read(BIO *b, char *out, int outl)
         {
             fdbio->m_rbioBuffered = buffered;
             fdbio->m_rbioIndex = 0;
-            DEBUG_MESSAGE("[BIO] bio_fd_read: Preserve read: %d\n", ret);
+            DEBUG_MESSAGE("[BIO: %d] bio_fd_read: Preserve read: %d\n", 
+                          getpid(), ret);
         }
         else
         {
             total += ret;
-            DEBUG_MESSAGE("[BIO] bio_fd_read: Read into data: %d\n", ret);
+            DEBUG_MESSAGE("[BIO: %d] bio_fd_read: Read into data: %d\n", 
+                          getpid(), ret);
         }
     }
     return total;
@@ -199,7 +203,8 @@ static int bio_fd_write(BIO *b, const char *in, int inl)
     int err = 0;
     int fd = BIO_get_fd(b, 0);
 
-    DEBUG_MESSAGE("[BIO] bio_fd_write: %p, %d bytes on %d\n", b, inl, fd);
+    DEBUG_MESSAGE("[BIO: %d] bio_fd_write: %p, %d bytes on %d\n", getpid(), b, 
+                  inl, fd);
     ret = ls_write(fd, (void *)in, inl);
     if ( ret > 0)
     {
@@ -209,16 +214,16 @@ static int bio_fd_write(BIO *b, const char *in, int inl)
     err = errno;
     if ((ret == -1) && (!(SIMPLE_RETRY(err))) && (!BIO_fd_should_retry(ret)))
     {
-        DEBUG_MESSAGE("[BIO] bio_fd_write: actual write failed, errno: %d\n",
-                      err);
+        DEBUG_MESSAGE("[BIO: %d] bio_fd_write: actual write failed, errno: %d\n",
+                      getpid(), err);
         return ret;
     }            
     BIO_clear_retry_flags(b);
     if (ret < 0) {
         if ((BIO_fd_should_retry(ret)) || (SIMPLE_RETRY(err)))
         {
-            DEBUG_MESSAGE("[BIO] bio_fd_write: %p, early return, errno: %d,"
-                          " ret: %d\n", b, err, ret);
+            DEBUG_MESSAGE("[BIO: %d] bio_fd_write: %p, early return, errno: %d,"
+                          " ret: %d\n", getpid(), b, err, ret);
             BIO_set_retry_write(b);
             errno = EAGAIN;
             //return bio_fd_write(b, in, inl);
@@ -226,7 +231,8 @@ static int bio_fd_write(BIO *b, const char *in, int inl)
         }
     }
     
-    DEBUG_MESSAGE("[BIO] bio_fd_write: %p, returning: %d\n", b, ret);
+    DEBUG_MESSAGE("[BIO: %d] bio_fd_write: %p, returning: %d\n", getpid(), b, 
+                  ret);
     errno = err;
     return ret;
 }
@@ -236,7 +242,7 @@ static int bio_fd_puts(BIO *bp, const char *str)
 {
     int n, ret;
     
-    DEBUG_MESSAGE("[BIO] bio_fd_puts: %p, %s\n", bp, str);
+    DEBUG_MESSAGE("[BIO: %d] bio_fd_puts: %p, %s\n", getpid(), bp, str);
 
     n = strlen(str);
     ret = bio_fd_write(bp, str, n);
@@ -250,7 +256,7 @@ static int bio_fd_gets(BIO *bp, char *buf, int size)
     char *ptr = buf;
     char *end = buf + size - 1;
     
-    DEBUG_MESSAGE("[BIO] bio_fd_gets: %p\n", bp);
+    DEBUG_MESSAGE("[BIO: %d] bio_fd_gets: %p\n", getpid(), bp);
 
     while (ptr < end && bio_fd_read(bp, ptr, 1) > 0) {
         if (*ptr++ == '\n')
@@ -329,7 +335,7 @@ static int setup_writes(ls_fdbio_data *fdbio)
 {
     if (!fdbio)
         return 0;
-    DEBUG_MESSAGE("[BIO] setup_writes\n");
+    DEBUG_MESSAGE("[BIO: %d] setup_writes\n", getpid());
     return 0;
 }
 
@@ -338,7 +344,7 @@ BIO *ls_fdbio_create(int fd, ls_fdbio_data *fdbio)
 {
     if (!s_biom)
     {
-        DEBUG_MESSAGE("[BIO] ls_fdbio_create METHOD\n");
+        DEBUG_MESSAGE("[BIO: %d] ls_fdbio_create METHOD\n", getpid());
     
         s_biom_fd_builtin = BIO_s_fd();
 #if OPENSSL_VERSION_NUMBER >= 0x10100000
@@ -346,7 +352,8 @@ BIO *ls_fdbio_create(int fd, ls_fdbio_data *fdbio)
             BIO_TYPE_FD | BIO_TYPE_SOURCE_SINK | BIO_TYPE_DESCRIPTOR, 
             "Litespeed BIO Method")))
         {
-            DEBUG_MESSAGE("[BIO] ERROR creating BIO_METHOD\n");
+            DEBUG_MESSAGE("[BIO: %d] ERROR creating BIO_METHOD\n", 
+                          getpid());
             return NULL;
         }
 #ifdef OPENSSL_IS_BORINGSSL
@@ -373,8 +380,7 @@ BIO *ls_fdbio_create(int fd, ls_fdbio_data *fdbio)
     if (!fdbio->m_rbioBufSz)
         fdbio->m_rbioBufSz = RBIO_BUF_SIZE;
     
-    if (!fdbio->m_rbioBuf
-        && !(fdbio->m_rbioBuf = (char *)ls_palloc(fdbio->m_rbioBufSz)))
+    if (!(fdbio->m_rbioBuf = (char *)ls_palloc(fdbio->m_rbioBufSz)))
     {
         DEBUG_MESSAGE("Insufficient memory allocating %d bytes\n",
                       fdbio->m_rbioBufSz);
@@ -387,8 +393,8 @@ BIO *ls_fdbio_create(int fd, ls_fdbio_data *fdbio)
     BIO *bio = BIO_new(s_biom);
     if (!bio)
     {
-        DEBUG_MESSAGE("[BIO: %p] ls_fdbio_create error creating rbio\n",
-                       fdbio);
+        DEBUG_MESSAGE("[BIO: %d:%p] ls_fdbio_create error creating rbio\n",
+                      getpid(), fdbio);
         // everything freed in the destructor
         return NULL;
     }
@@ -398,8 +404,8 @@ BIO *ls_fdbio_create(int fd, ls_fdbio_data *fdbio)
 #else
     BIO_set_app_data(bio, fdbio);
 #endif    
-    DEBUG_MESSAGE("[BIO] ls_fdbio_create bio: %p\n",
-                   bio);
+    DEBUG_MESSAGE("[BIO: %d] ls_fdbio_create bio: %p\n",
+                  getpid(), bio);
     
     setup_writes(fdbio);
     return bio;
