@@ -8,10 +8,6 @@
 
 #include <log4cxx/logger.h>
 #include <lsr/ls_pool.h>
-#include <assert.h>
-#if __cplusplus <= 199711L && !defined(static_assert)
-#define static_assert(a, b) _Static_assert(a, b)
-#endif
 #include <openssl/ssl.h>
 #include <openssl/bio.h>
 #include <openssl/err.h>
@@ -75,16 +71,8 @@ void SslConnection::setSSL(SSL *ssl)
     SSL_set_ex_data(ssl, s_iConnIdx, (void *)this);
 }
 
-
-SslConnection *SslConnection::get(const SSL *ssl)
-{
-    return (SslConnection *)SSL_get_ex_data(ssl, s_iConnIdx);
-}
-
-
 void SslConnection::release()
 {
-    DEBUG_MESSAGE("[SSL: %p] release\n", this);
     assert(m_ssl);
     if (m_iStatus != DISCONNECTED)
         shutdown(0);
@@ -102,13 +90,8 @@ int SslConnection::setfd(int fd)
     DEBUG_MESSAGE("[SSL: %p] setfd: %d\n", this, fd);
     if (m_ssl)
     {
-        if  (fd != -1 && m_bio.m_rbioBuf == NULL)
-        {
-            BIO * bio = ls_fdbio_create(fd, &m_bio);
-            SSL_set_bio(m_ssl, bio, bio);
-        }
-        else
-            BIO_set_fd(SSL_get_rbio(m_ssl), fd, 0);
+        BIO * bio = ls_fdbio_create(fd, &m_bio);
+        SSL_set_bio(m_ssl, bio, bio);
     }
     return 0;
 }
@@ -246,7 +229,6 @@ int SslConnection::flush()
 int SslConnection::shutdown(int bidirectional)
 {
     assert(m_ssl);
-    
     m_flag = 0;
     if (m_iStatus == ACCEPTING)
     {
@@ -286,22 +268,19 @@ void SslConnection::toAccept()
 int SslConnection::accept()
 {
     int ret;
-    DEBUG_MESSAGE("[SSL: %p] accept SSL: %p\n", this, m_ssl);
+    DEBUG_MESSAGE("[SSL: %p] accept\n", this);
     assert(m_ssl);
-    if (m_iStatus != ACCEPTING && m_iStatus != GOTCERT) {
+    if (m_iStatus != ACCEPTING) {
         DEBUG_MESSAGE("[SSL: %p] In accept but not in ACCEPTING status\n",
                       this);
         return -1;
     }
-    DEBUG_MESSAGE("[SSL: %p] Call SSL_do_handshake, ssl: %p, ctx: %p\n", this, 
-                  m_ssl, SSL_get_SSL_CTX(m_ssl));
-    setFlag(F_ASYNC_PK, 0);
     ret = SSL_do_handshake(m_ssl);
-    DEBUG_MESSAGE("[SSL: %p] SSL_accept SSL_do_handshake rc: %d\n", this, ret);
+    DEBUG_MESSAGE("[SSL: %p] SSL_accept rc: %d\n", this, ret);
     if (ret == 1)
     {
         DEBUG_MESSAGE("[SSL: %p] SSL_accept worked - move to connected"
-                      " status, version: 0x%x\n", this, SSL_version(m_ssl));
+                        " status\n", this);
         m_iStatus = CONNECTED;
         m_iWant = READ;
     }
@@ -313,6 +292,7 @@ int SslConnection::accept()
 }
 
 
+
 int SslConnection::checkError(int ret)
 {
     int err = SSL_get_error(m_ssl, ret);
@@ -342,17 +322,6 @@ int SslConnection::checkError(int ret)
         m_iStatus = WAITINGCERT;
         ERR_clear_error();
         return 0; // This will trigger a setSSLAgain(), which will disable read/write.
-#ifdef SSL_ASYNC_PK
-    case SSL_ERROR_WANT_PRIVATE_KEY_OPERATION:
-        DEBUG_MESSAGE("[SSL: %p] BORING requested SSL_do_handshake retry\n",
-                      this);
-        ERR_clear_error();
-        m_iWant = 0;
-        setFlag(F_ASYNC_PK, 1);
-        errno = EAGAIN;
-        return 0;
-#endif
-
     case SSL_ERROR_SSL:
         if (m_iWant == LAST_WRITE)
         {
@@ -370,8 +339,6 @@ int SslConnection::checkError(int ret)
                 break;
             }
         }
-
-        
     default:
         LS_DBG_H("SslError:%s\n", SslError(err).what());
         errno = EIO;
