@@ -6,12 +6,19 @@
 #ifndef SSLCONNECTION_H
 #define SSLCONNECTION_H
 #include <lsdef.h>
-#include <sslpp/ssldef.h>
 #include <sslpp/hiocrypto.h>
 #include <sslpp/ls_fdbuf_bio.h>
+#include <openssl/ssl.h>
+
+typedef struct bio_st  BIO;
+typedef struct x509_st X509;
+typedef struct ssl_cipher_st SSL_CIPHER;
+typedef struct ssl_st SSL;
+typedef struct ssl_ctx_st SSL_CTX;
+typedef struct ssl_session_st SSL_SESSION;
+
 
 class SslClientSessCache;
-
 class SslConnection : public HioCrypto
 {
 public:
@@ -37,15 +44,13 @@ public:
     {
         F_HANDSHAKE_DONE    = 1,
         F_DISABLE_HTTP2     = 2,
-        F_ASYNC_CERT        = 4,
-        F_ASYNC_PK          = 8
     };
 
     char wantRead() const   {   return m_iWant & READ;  }
     char wantWrite() const  {   return m_iWant & WRITE; }
     char lastRead() const   {   return m_iWant & LAST_READ; }
     char lastWrite() const  {   return m_iWant & LAST_WRITE; }
-    
+
     bool getFlag(int v) const   {   return m_flag & v;     }
     void setFlag(int f, int v)  {   m_flag = (m_flag & ~f) | (v ? f : 0);  }
 
@@ -57,10 +62,9 @@ public:
 
     void release();
     int setfd(int fd);
-    //int setfd(int rfd, int wfd);
+    int setfd(int rfd, int wfd);
 
     void toAccept();
-
     int accept();
     int connect();
     int read(char *pBuf, int len);
@@ -108,7 +112,8 @@ public:
     void enableRbio() {};
 
     static void initConnIdx();
-    static SslConnection *get(const SSL *ssl);
+    static SslConnection *get(const SSL *ssl)
+    {   return (SslConnection *)SSL_get_ex_data(ssl, s_iConnIdx);   }
 
     static int getCipherBits(const SSL_CIPHER *pCipher, int *algkeysize);
     static int isClientVerifyOptional(int i);
