@@ -10,16 +10,9 @@
 #include <sslpp/sslocspstapling.h>
 #include <sslpp/sslutil.h>
 #include <sslpp/sslcontextconfig.h>
-#include <sslpp/sslasyncpk.h>
-#include <sslpp/sslcertcomp.h>
 
 #include <log4cxx/logger.h>
 
-#include <assert.h>
-#if __cplusplus <= 199711L && !defined(static_assert)
-#define static_assert(a, b) _Static_assert(a, b)
-#endif
-
 #include <openssl/err.h>
 #include <openssl/rand.h>
 #include <openssl/ssl.h>
@@ -77,13 +70,6 @@ SslContext *SslContext::config(SslContext *pContext, const char *pZcDomainName,
         return NULL;
     }
 
-#ifdef SSL_ASYNC_PK
-    SslAsyncPk::enableApk(pContext->m_pCtx);
-#endif
-
-#ifdef SSLCERTCOMP
-    SslCertComp::enableCertComp(pContext->m_pCtx);
-#endif
     return pContext;
 }
 
@@ -223,14 +209,6 @@ SslContext *SslContext::config(SslContext *pContext, SslContextConfig *pConfig)
         pContext->configStapling(pConfig);
     }
 
-#ifdef SSL_ASYNC_PK
-    SslAsyncPk::enableApk(pContext->m_pCtx);
-#endif
-
-#ifdef SSLCERTCOMP
-    SslCertComp::enableCertComp(pContext->m_pCtx);
-#endif
-
 #ifdef _ENTERPRISE_
     if (pConfig->m_iClientVerify)
     {
@@ -418,7 +396,6 @@ int SslContext::init(int iMethod)
     SSL_METHOD *meth;
     if (initSSL())
         return -1;
-    
     m_iMethod = iMethod;
     m_iEnableSpdy = 0;
     m_iEnableOcsp = 0;
@@ -426,7 +403,6 @@ int SslContext::init(int iMethod)
     m_pCtx = SSL_CTX_new(meth);
     if (m_pCtx)
     {
-        LS_DBG_L("[SslCertComp] Create SSL_CTX: %p\n", m_pCtx);
         SslUtil::initCtx(m_pCtx, iMethod, m_iRenegProtect);
         //initDH( NULL );
         //initECDH();
@@ -461,20 +437,14 @@ SslContext::~SslContext()
 
 void SslContext::release()
 {
-#ifdef SSLCERTCOMP
-    SslCertComp::disableCertCompDecomp(m_pCtx);
-#endif        
-    if (m_pCtx != NULL && m_pCtx != SSL_CTX_PENDING)
+    if (m_pCtx != NULL)
     {
         SSL_CTX *pCtx = m_pCtx;
         m_pCtx = NULL;
         SSL_CTX_free(pCtx);
     }
     if (m_pStapling)
-    {
         delete m_pStapling;
-        m_pStapling = NULL;
-    }
 }
 
 
@@ -619,12 +589,15 @@ int SslContext::setPrivateKeyFile(const char *pFile, int type)
     return 1;
 }
 
-bool SslContext::checkPrivateKey()
+/*Ron
+int SslContext::checkPrivateKey()
 {
     if (m_pCtx)
         return SSL_CTX_check_private_key(m_pCtx) == 1;
-    return false;
+    else
+        return false;
 }
+*/
 
 int SslContext::setCipherList(const char *pList)
 {
@@ -976,16 +949,10 @@ int SslContext::addCRL(const char *pCRLFile, const char *pCRLPath)
 #endif
 
 
-/* This will neeed to be updated as the ID versions change.  Eventually
- * it will become simply "h3"
- */
-#define H3_ALPN "\x05h3-18"
-#define H3_ALSZ (sizeof(H3_ALPN) - 1)
-
 /**
  * We support h2-16, but if set to this value, firefox will not choose h2-16, so we have to use h2-14.
  */
-static const char *NEXT_PROTO_STRING[16] =
+static const char *NEXT_PROTO_STRING[8] =
 {
     "\x08http/1.1",
     "\x06spdy/2\x08http/1.1",
@@ -995,20 +962,11 @@ static const char *NEXT_PROTO_STRING[16] =
     "\x02h2\x06spdy/2\x08http/1.1",
     "\x02h2\x08spdy/3.1\x06spdy/3\x08http/1.1",
     "\x02h2\x08spdy/3.1\x06spdy/3\x06spdy/2\x08http/1.1",
-    H3_ALPN "\x08http/1.1",
-    H3_ALPN "\x06spdy/2\x08http/1.1",
-    H3_ALPN "\x08spdy/3.1\x06spdy/3\x08http/1.1",
-    H3_ALPN "\x08spdy/3.1\x06spdy/3\x06spdy/2\x08http/1.1",
-    H3_ALPN "\x02h2\x08http/1.1",
-    H3_ALPN "\x02h2\x06spdy/2\x08http/1.1",
-    H3_ALPN "\x02h2\x08spdy/3.1\x06spdy/3\x08http/1.1",
-    H3_ALPN "\x02h2\x08spdy/3.1\x06spdy/3\x06spdy/2\x08http/1.1",
 };
 
-static unsigned int NEXT_PROTO_STRING_LEN[16] =
+static unsigned int NEXT_PROTO_STRING_LEN[8] =
 {
     9, 16, 25, 32, 12, 19, 28, 35,
-    9+H3_ALSZ, 16+H3_ALSZ, 25+H3_ALSZ, 32+H3_ALSZ, 12+H3_ALSZ, 19+H3_ALSZ, 28+H3_ALSZ, 35+H3_ALSZ,
 };
 
 //static const char NEXT_PROTO_STRING[] = "\x06spdy/2\x08http/1.1\x08http/1.0";
@@ -1032,14 +990,11 @@ static int SSLConntext_alpn_select_cb(SSL *pSSL, const unsigned char **out,
 {
     SslContext *pCtx = (SslContext *)arg;
     SslConnection *pConn = SslConnection::get(pSSL);
-    if (pConn && pConn->getFlag(SslConnection::F_DISABLE_HTTP2))
+    if (pConn->getFlag(SslConnection::F_DISABLE_HTTP2))
         return SSL_TLSEXT_ERR_NOACK;
-    unsigned char alpn_idx = pCtx->getEnableSpdy();
-    if (pConn)
-        alpn_idx &= ~8; // No HTTP/3 on TCP connection
     if (SSL_select_next_proto((unsigned char **) out, outlen,
-                              (const unsigned char *)NEXT_PROTO_STRING[ alpn_idx ],
-                              NEXT_PROTO_STRING_LEN[ alpn_idx ],
+                              (const unsigned char *)NEXT_PROTO_STRING[ pCtx->getEnableSpdy() ],
+                              NEXT_PROTO_STRING_LEN[ pCtx->getEnableSpdy() ],
                               in, inlen)
         != OPENSSL_NPN_NEGOTIATED)
         return SSL_TLSEXT_ERR_NOACK;
@@ -1058,7 +1013,7 @@ void SslContext::setAlpnCb(SSL_CTX *ctx, void *arg)
 
 int SslContext::enableSpdy(int level)
 {
-    m_iEnableSpdy = (level & 15);
+    m_iEnableSpdy = (level & 7);
     if (m_iEnableSpdy == 0)
         return 0;
 #ifdef TLSEXT_TYPE_application_layer_protocol_negotiation
