@@ -10,14 +10,6 @@
 #include <sslpp/sslsesscache.h>
 #include <sslpp/sslticket.h>
 
-#include <assert.h>
-#if __cplusplus <= 199711L && !defined(static_assert)
-#define static_assert(a, b) _Static_assert(a, b)
-#endif
-
-#include <openssl/ssl.h>
-#include <openssl/x509v3.h>
-
 #include <lsdef.h>
 #include <log4cxx/logger.h>
 
@@ -41,14 +33,14 @@ const char *SslUtil::s_pDefaultCAFile = NULL;
 const char *SslUtil::s_pDefaultCAPath = NULL;
 
 static int defaultAsyncCert(asyncCertDoneCb cb, void *pParam,
-                            const char *pDomain, int iDomainLen)
+                            const char *pDomain, int iDomainLen, bool isSsl)
 {
     return -1;
 }
 
 
 asyncCertFunc SslUtil::removeAsyncCertLookup = defaultAsyncCert;
-asyncCertFunc SslUtil::addAsyncCertLookup = NULL;
+asyncCertFunc SslUtil::addAsyncCertLookup = defaultAsyncCert;
 
 static const int s_iSystems = 4;
 static const char *s_aSystemFiles[] =
@@ -449,40 +441,34 @@ int SslUtil::digestIdContext(SSL_CTX *pCtx, const void *pDigest,
 /*
  * return: -1 if cert NULL, 0 on fail, 1 on success
  */
-int SslUtil::loadCert(SSL_CTX *pCtx, const void *pCert, int iCertLen,
-                      int loadChain)
+int SslUtil::loadCert(SSL_CTX *pCtx, void *pCert, int iCertLen)
 {
     BIO *in;
     X509 *cert = NULL;
-    int ret = -1;
+    int ret;
     unsigned int digestlen;
     unsigned char digest[EVP_MAX_MD_SIZE];
 
     in = BIO_new_mem_buf(pCert, iCertLen);
     cert = PEM_read_bio_X509(in, NULL, 0, NULL);
-    if (cert)
-    {
-        if (( ret = SSL_CTX_use_certificate(pCtx, cert)) == 1 )
-        {
-            if ( X509_digest(cert, EVP_sha1(), digest, &digestlen) == 0)
-                LS_DBG_L("Creating cert digest failed");
-            else if (digestIdContext(pCtx, digest, digestlen) != LS_OK)
-                LS_DBG_L("Digest id context failed");
-        }
-        X509_free(cert);
-    }
-    if (ret && loadChain)
-    {
-        setCertificateChain(pCtx, in);
-    }
     BIO_free(in);
+    if (!cert)
+        return -1;
+    if (( ret = SSL_CTX_use_certificate(pCtx, cert)) == 1 )
+    {
+        if ( X509_digest(cert, EVP_sha1(), digest, &digestlen) == 0)
+            LS_DBG_L("Creating cert digest failed");
+        else if (digestIdContext(pCtx, digest, digestlen) != LS_OK)
+            LS_DBG_L("Digest id context failed");
+    }
+    X509_free(cert);
     return ret;
 }
 
 /*
  * return: -1 if key NULL, 0 if SSL_CTX_use_PrivateKey fails, > 1 on success (len per EVP_PKEY_bits)
  */
-int SslUtil::loadPrivateKey(SSL_CTX *pCtx, const void *pKey, int iKeyLen)
+int SslUtil::loadPrivateKey(SSL_CTX *pCtx, void *pKey, int iKeyLen)
 {
     BIO *in;
     EVP_PKEY *key = NULL;
@@ -674,8 +660,6 @@ int SslUtil::setCertificateChain(SSL_CTX *pCtx, BIO * bio)
 static void SslConnection_ssl_info_cb(const SSL *pSSL, int where, int ret)
 {
     SslConnection *pConnection = SslConnection::get(pSSL);
-    if (!pConnection)
-        return;
     if ((where & SSL_CB_HANDSHAKE_START)
         && pConnection->getFlag(SslConnection::F_HANDSHAKE_DONE)
 #if OPENSSL_VERSION_NUMBER > 0x10101000L
@@ -855,9 +839,7 @@ void SslUtil::updateProtocol(SSL_CTX *pCtx, int method)
     {
         SSL_CTX_set_max_proto_version(pCtx, TLS1_3_VERSION);
 #ifdef OPENSSL_IS_BORINGSSL
-#if defined(TLS1_3_DRAFT23_VERSION) || defined(TLS1_3_DRAFT28_VERSION)
         SSL_CTX_set_tls13_variant(pCtx, tls13_all);
-#endif
 #endif
     }
 #endif
@@ -901,111 +883,4 @@ void SslUtil::disableSessionTickets(SSL_CTX *pCtx)
 }
 
 
-int SslUtil::getSkid(SSL_CTX *pCtx, char *skid_buf, int buf_len)
-{
-    X509 *px509 = SSL_CTX_get0_certificate(pCtx);
-    int idx = X509_get_ext_by_NID(px509, NID_subject_key_identifier, -1);
-
-    X509_EXTENSION *pExt = X509_get_ext(px509, idx);
-
-    if (NULL == pExt)
-        return LS_FAIL;
-
-    const X509V3_EXT_METHOD *method;
-
-    if (!(method = X509V3_EXT_get(pExt)))
-        return LS_FAIL;
-    ASN1_OCTET_STRING *skid;
-
-//     const unsigned char *p;
-//     p = pExt->value->data;
-//
-//     skid = (ASN1_OCTET_STRING *) ASN1_item_d2i(NULL, &p, pExt->value->length,
-//                                                     ASN1_ITEM_ptr(method->it));
-
-    skid = X509_EXTENSION_get_data(pExt);
-
-    static const char hex[] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F' };
-
-    if (skid->length * 3 > buf_len)
-        return LS_FAIL;
-    char * bp = skid_buf;
-    for (int idx =0; idx < skid->length; idx++)
-    {
-        *bp++ = hex[skid->data[idx] >> 4];
-        *bp++ = hex[skid->data[idx] & 0xf];
-        *bp++ = ':';
-    }
-    *--bp = '\0';
-    return bp - skid_buf;
-}
-
-
-int SslUtil::lookupCertSerial(X509 *pCert, char *pBuf, int len)
-{
-    BIO *bio;
-    int n;
-
-    if ((bio = BIO_new(BIO_s_mem())) == NULL)
-        return -1;
-    i2a_ASN1_INTEGER(bio, X509_get_serialNumber(pCert));
-    //n = BIO_pending(bio);
-    n = BIO_read(bio, pBuf, len);
-    pBuf[n] = '\0';
-    BIO_free(bio);
-    return n;
-}
-
-#include <pthread.h>
-
-/* This array will store all of the mutexes available to OpenSSL. */
-static pthread_mutex_t *mutex_buf = NULL;
-
-static void locking_function(int mode, int n, const char *file, int line)
-{
-  if(mode & CRYPTO_LOCK)
-    pthread_mutex_lock(&mutex_buf[n]);
-  else
-    pthread_mutex_unlock(&mutex_buf[n]);
-}
-
-
-static unsigned long id_function(void)
-{
-  return ((unsigned long)pthread_self());
-}
-
-
-int thread_setup(void)
-{
-  int i;
-
-  mutex_buf = (pthread_mutex_t *)malloc(CRYPTO_num_locks()
-                                        * sizeof(pthread_mutex_t));
-  if(!mutex_buf)
-    return 0;
-  for(i = 0;  i < CRYPTO_num_locks();  i++)
-    pthread_mutex_init(&mutex_buf[i], NULL);
-  CRYPTO_set_id_callback(id_function);
-  CRYPTO_set_locking_callback(locking_function);
-  return 1;
-}
-
-
-int thread_cleanup(void)
-{
-  int i;
-
-  if(!mutex_buf)
-    return 0;
-  CRYPTO_set_id_callback(NULL);
-  CRYPTO_set_locking_callback(NULL);
-  for(i = 0;  i < CRYPTO_num_locks();  i++)
-    pthread_mutex_destroy(&mutex_buf[i]);
-  free(mutex_buf);
-  mutex_buf = NULL;
-  return 1;
-}
-
-
 
