@@ -31,9 +31,10 @@ public:
     DateTime();
     ~DateTime();
 
-    static time_t parseHttpTime(const char *s, int len);
+    static time_t parseHttpTime(const char *s);
     static char  *getRFCTime(time_t t, char *buf);
     static char  *getLogTime(time_t lTime, char *pBuf, int bGMT = 0);
+
 };
 
 #endif
