@@ -29,11 +29,6 @@
 #include <util/ssnprintf.h>
 #include "stringtool.h"
 
-#include <assert.h>
-#if __cplusplus <= 199711L && !defined(static_assert)
-#define static_assert(a, b) _Static_assert(a, b)
-#endif
-
 #include <openssl/ssl.h>
 #include <openssl/x509_vfy.h>
 
