@@ -34,50 +34,46 @@ struct escapeMatchInfo_t
 
 escapeMatchInfo_t tests[] =
 {
-    {" !!!  123 ", " !!!  123 "},
-    {"   123 ", "   123 "},
-    
-     {"   123 \\", "   123 \\"},
-     {"   123 \\\\", "   123 \\\\"},
-     
-     {"   123 \\\"", "   123 \""},
-     
-     
-    
-    {"\'   123 \'", "   123 "},
+    {" !!!  123 ", " !!!  123 "},   // 0
+    {"   123 ", "   123 "},         // 1
+    {"   123 \\", "   123 \\"},     // 2
+    {"   123 \\\\", "   123 \\\\"}, // 3
+    {"   123 \\\"", "   123 \""},   // 4
+
+    {"'   123 '", "   123 "},
     {"`   123 `", "   123 "},
     {"\"   123 \"", "   123 "},
-    
-    {"\'   123 \'", "   123 "},
+
+    {"'   123 '", "   123 "},
     {"`   123 `", "   123 "},
     {"\"   123 \"", "   123 "},
-    
-    {"\' \"  123 \'", " \"  123 "},
+
+    {"' \"  123 '", " \"  123 "},
     {"` \"  123 `", " \"  123 "},
     {"\" `  123 \"", " `  123 "},
-    
-    {"\' \\\"  123 \'", " \\\"  123 "},
+
+    {"' \\\"  123 '", " \\\"  123 "},
     {"` \\\"  123 `", " \\\"  123 "},
     {"\" \\`  123 \"", " \\`  123 "},
-    
-    {"\\' \"  123 \'", "\\ \"  123 "},
+
+    {"\\' \"  123 '", "\\ \"  123 "},
     {"\\` \"  123 `", "\\ \"  123 "},
     {"\\\" `  123 \"", "\\ `  123 "},
-    
-    {"\' \\\'  123 \'", " \'  123 "},
+
+    {"' \\'  123 '", " '  123 "},
     {"` \\`  123 `", " `  123 "},
     {"\" \\\"  123 \"", " \"  123 "},
-    
-    
+
+
     //Special cases
-    {"`  \\`  `   \\\" \"123 \\\"  ff \"  \\\' \'123 \\\'  ff \'    ",
+    {"`  \\`  `   \\\" \"123 \\\"  ff \"  \\' '123 \\'  ff '    ",
         "  `     \\ 123 \\  ff   \\ 123 \\  ff     " },
 
-    {"`  \\`  `   \\\"\\\' \"123 \\\"  ff \"  \\\' \'123 \\\'  ff \'    \\",
-        "  `     \\\\\' 123 \\  ff   \\ 123 \\  ff     \\" },
-        
-    {"\\\\\\\` 123 \\\\\\\` 112 \\r\\n \\t \\\" 444 \`",
-        "\\\\\\ 123 \\\\\` 112 \\r\\n \\t \\\" 444 " },
+    {"`  \\`  `   \\\"\\' \"123 \\\"  ff \"  \\' '123 \\'  ff '    \\",
+        "  `     \\\\' 123 \\  ff   \\ 123 \\  ff     \\" },
+
+    {"\\\\\\` 123 \\\\\\` 112 \\r\\n \\t \\\" 444 `",
+        "\\\\\\ 123 \\\\` 112 \\r\\n \\t \\\" 444 " },
 
     //  [` 123 \\` 345 `] ====> [ 123 \` 345 ]
     {"` 123 \\\\` 345 `", " 123 \\` 345 "},
@@ -94,7 +90,7 @@ TEST(TEST_MODULECONF)
     for (i=0; i<sizeof(tests)/sizeof(escapeMatchInfo_t); ++i)
     {
         ret = ModuleConfig::escapeParamVal(tests[i].src, strlen(tests[i].src), str);
-        printf("i %d %d.\n", (int)i, (int)strlen(tests[i].dst));
+        printf("i %lu %lu.\n", i, strlen(tests[i].dst));
         CHECK(ret == strlen(tests[i].dst));
         CHECK(memcmp(str, tests[i].dst, ret) ==0);
         
