@@ -30,14 +30,15 @@
 #include <util/vmembuf.h>
 #include <fcntl.h>
 
-//TEST(httpfetchTest_Test)
-void VOID_TEST()//httpfetchTest_Test)
+TEST(httpfetchTest_Test)
+//void VOID_TEST()//httpfetchTest_Test)
 {
     printf("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
     printf("THIS TEST CAN ONLY TEST BY DEBUG with breakpoints\n");
     printf("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 
     Multiplexer *mult = MultiplexerFactory::getMultiplexer();
+    void *p = NULL;
     HttpFetch *pHttpFetch = new HttpFetch;
     //pHttpFetch->setResProcessor(NULL, p);
     //pHttpFetch->setTimeout(100);
